(function($) {
    'use strict';

    var portfolio = {};
    cdbTheme.modules.portfolio = portfolio;
	
    portfolio.cdbThemeWindowLoad = cdbThemeWindowLoad;
	
    $(window).load(cdbThemeWindowLoad);
	
	/*
	 All functions to be called on $(window).load() should be in this function
	 */
	function cdbThemeWindowLoad() {
		portfolioDetailsSticky().init();
        portfolioHoverFollowMousePointer();
	}
	
	var portfolioDetailsSticky = function () {
		var info = $('.portfolio-details-sticky .portfolio-single-content .portfolio-single-sticky-column');
		
		if (info.length) {
			var infoHolder = info.parent(),
				infoHolderOffset = infoHolder.offset().top,
				infoHolderHeight = infoHolder.height(),
				mediaHolder = $('.portfolio-single-gallery-wrap'),
				mediaHolderHeight = mediaHolder.height(),
				header = $('.header-appear, .main-fixed-header'),
				headerHeight = (header.length) ? header.height() : 0,
				constant = 30; //30 to prevent mispositioned
		}
		
		var infoHolderPosition = function () {
			if (info.length && mediaHolderHeight >= infoHolderHeight) {
				if (cdbTheme.scroll >= infoHolderOffset - headerHeight - theme_global_vars.vars.cdb_admin_bar - constant) {
					var marginTop = cdbTheme.scroll - infoHolderOffset + theme_global_vars.vars.cdb_admin_bar + headerHeight + constant;
					// if scroll is initially positioned below mediaHolderHeight
					if (marginTop + infoHolderHeight > mediaHolderHeight) {
						marginTop = mediaHolderHeight - infoHolderHeight + constant;
					}
					info.stop().css({
						top: marginTop
					});
				}
			}
		};
		
		var recalculateInfoHolderPosition = function () {
			if (info.length && mediaHolderHeight >= infoHolderHeight) {
				//Calculate header height if header appears
				if (cdbTheme.scroll > 0 && header.length) {
					headerHeight = header.height();
				}
				
				if (cdbTheme.scroll >= infoHolderOffset - headerHeight - theme_global_vars.vars.cdb_admin_bar - constant) {
					if (cdbTheme.scroll + headerHeight + theme_global_vars.vars.cdb_admin_bar + constant + infoHolderHeight < infoHolderOffset + mediaHolderHeight) {
						info.stop().css({
							top: (cdbTheme.scroll - infoHolderOffset + theme_global_vars.vars.cdb_admin_bar + headerHeight + constant)
						});
						//Reset header height
						headerHeight = 0;
					} else {
						info.stop().css({
							top: mediaHolderHeight - infoHolderHeight
						});
					}
				} else {
					info.stop().css({
						top: 0
					});
				}
			}
		};
		
		return {
			init: function () {
				infoHolderPosition();
				$(window).scroll(function () {
					recalculateInfoHolderPosition();
				});
			}
		};
	};

    function portfolioHoverFollowMousePointer() {
        var portList = $('.style-float-details');

        if (portList.length) {
            cdbTheme.body.append('<div class="portfolio-caption-float-wrap">' +
                '<div class="portfolio-caption-float">' +
                '<span class="p-caption-categories"></span>' +
                '<span class="p-caption-title">Title</span>' +
                '</div>' +
                '</div>');

            var followInfoHolder = $('.portfolio-caption-float-wrap'),
                followInfoCategory = followInfoHolder.find('.p-caption-categories'),
                followInfoTitle = followInfoHolder.find('.p-caption-title');

            portList.each(function () {
                var thisPortList = $(this);

                if(thisPortList.hasClass('portfolio-caption-dark')) {
                    followInfoHolder.addClass('portfolio-caption-dark-info');
                }

                //info element position
                thisPortList.on('mousemove', function (e) {
                    followInfoHolder.css({
                        top: e.clientY,
                        left: e.clientX
                    });
                });

                //show/hide info element
                thisPortList.find('.portfolio-item').on('mouseenter', function () {
                    var thisArticleItem = $(this),
                        thisArticleItemTitle = thisArticleItem.find('.portfolio-item-title'),
                        thisArticleItemCategories = thisArticleItem.find('.portfolio-cat');

                    if(thisArticleItemCategories.length) {
                        thisArticleItemCategories.each(function(){
                            var thisArticleItemCategory = $(this);
                            followInfoCategory.append('<span class="portfolio-caption-category">' + thisArticleItemCategory.text() + '</span>');
                        });
                    }

                    if(thisArticleItemTitle.length) {
                        followInfoTitle.text(thisArticleItemTitle.text());
                    }

                    if (!followInfoHolder.hasClass('active')) {
                        followInfoHolder.addClass('active');
                    }

                }).on('mouseleave', function () {
                    if (followInfoHolder.hasClass('active')) {
                        followInfoHolder.removeClass('active');
                    }
                    $('.portfolio-caption-category').remove();
                });

                //check if info element is below or above the targeted portfolio list
                $(window).scroll(function(){
                    if (followInfoHolder.hasClass('active')) {
                        if (followInfoHolder.offset().top < thisPortList.offset().top || followInfoHolder.offset().top > thisPortList.offset().top + thisPortList.outerHeight()) {
                            followInfoHolder.removeClass('active');
                        }
                    }
                });
            });
        }
    }

})(jQuery);
(function($) {
    'use strict';
	
	var accordions = {};
	cdbTheme.modules.accordions = accordions;
	
	accordions.codebeanAccordions = codebeanAccordions;
	
	
	accordions.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		codebeanAccordions();
	}
	
	/**
	 * Init accordions shortcode
	 */
	function codebeanAccordions(){
		var accordion = $('.accordion-wrap');
		
		if(accordion.length){
			accordion.each(function(){
				var thisAccordion = $(this);

				if(thisAccordion.hasClass('type-accordion')){
					thisAccordion.accordion({
						animate: "swing",
						collapsible: true,
						active: 0,
						icons: "",
						heightStyle: "content"
					});
				}

				if(thisAccordion.hasClass('type-toggle')){
					var toggleAccordion = $(this),
						toggleAccordionTitle = toggleAccordion.find('.title-wrap'),
						toggleAccordionContent = toggleAccordionTitle.next();

					toggleAccordion.addClass("accordion ui-accordion ui-accordion-icons ui-widget ui-helper-reset");
					toggleAccordionTitle.addClass("ui-accordion-header ui-state-default ui-corner-top ui-corner-bottom");
					toggleAccordionContent.addClass("ui-accordion-content ui-helper-reset ui-widget-content ui-corner-bottom").hide();

					toggleAccordionTitle.each(function(){
						var thisTitle = $(this);
						
						thisTitle.hover(function(){
							thisTitle.toggleClass("ui-state-hover");
						});

						thisTitle.on('click',function(){
							thisTitle.toggleClass('ui-accordion-header-active ui-state-active ui-state-default ui-corner-bottom');
							thisTitle.next().toggleClass('ui-accordion-content-active').slideToggle(400);
						});
					});
				}
			});
		}
	}

})(jQuery);
(function($) {
	'use strict';
	
	var animationHolder = {};
	cdbTheme.modules.animationHolder = animationHolder;
	
	animationHolder.animationBox = animationBox;
	
	
	animationHolder.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		animationBox();
	}
	
	/*
	 *	Init animation holder shortcode
	 */
	function animationBox(){
		var elements = $('.zoomIn, .fadeInDown, .fadeIn, .fadeInLeft, .fadeInRight, .fadeInUp, .fadeInDown, .flipIn, .rotateX, .rotateZ, .translateY, .cdb-fade-in, .leftRotateX'),
			animationClass,
			animationData,
			animationDelay;
		
		if(elements.length){
			elements.each(function(){
				var thisElement = $(this);
				
				thisElement.appear(function() {
					animationData = thisElement.data('animation-type');
					animationDelay = parseInt(thisElement.data('animation-delay'));
					
					if(typeof animationData !== 'undefined' && animationData !== '') {
						animationClass = animationData;
						var newClass = 'in-view';
						
						setTimeout(function(){
							thisElement.addClass(newClass);
						},animationDelay);
					}
				},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
})(jQuery);
(function ($) {
	'use strict';

	var button = {};
	cdbTheme.modules.button = button;

	button.codeBeanButton = codeBeanButton;


	button.cdbThemeDocumentReady = cdbThemeDocumentReady;

	$(document).ready(cdbThemeDocumentReady);

	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		codeBeanButton().init();
	}

	/**
	 * Button object that initializes whole button functionality
	 * @type {Function}
	 */
	var codeBeanButton = function () {
		//all buttons on the page
		var buttons = $('.btn');

		/**
		 * Initializes button hover color
		 * @param button current button
		 */
		var buttonHoverColor = function (button) {
			if (typeof button.data('hover-color') !== 'undefined') {
				var changeButtonColor = function (event) {
					event.data.button.css('color', event.data.color);
				};

				var originalColor = button.css('color');
				var hoverColor = button.data('hover-color');

				button.on('mouseenter', { button: button, color: hoverColor }, changeButtonColor);
				button.on('mouseleave', { button: button, color: originalColor }, changeButtonColor);
			}
		};

		/**
		 * Initializes button hover background color
		 * @param button current button
		 */
		var buttonHoverBgColor = function (button) {
			if (typeof button.data('hover-bg-color') !== 'undefined') {
				var changeButtonBg = function (event) {
					event.data.button.css('background-color', event.data.color);
				};

				var originalBgColor = button.css('background-color');
				var hoverBgColor = button.data('hover-bg-color');

				button.on('mouseenter', { button: button, color: hoverBgColor }, changeButtonBg);
				button.on('mouseleave', { button: button, color: originalBgColor }, changeButtonBg);
			}
		};

		/**
		 * Initializes button border color
		 * @param button
		 */
		var buttonHoverBorderColor = function (button) {
			if (typeof button.data('hover-border-color') !== 'undefined') {
				var changeBorderColor = function (event) {
					event.data.button.css('border-color', event.data.color);
				};

				var originalBorderColor = button.css('borderTopColor'); //take one of the four sides
				var hoverBorderColor = button.data('hover-border-color');

				button.on('mouseenter', { button: button, color: hoverBorderColor }, changeBorderColor);
				button.on('mouseleave', { button: button, color: originalBorderColor }, changeBorderColor);
			}
		};

		return {
			init: function () {
				if (buttons.length) {
					buttons.not('.btn-solid').each(function () {
						buttonHoverColor($(this));
						buttonHoverBgColor($(this));
						buttonHoverBorderColor($(this));
					});
				}
			}
		};
	};

})(jQuery);
(function($) {
    'use strict';

    var cascadingimages = {};
    cdbTheme.modules.cascadingimages = cascadingimages;

    cascadingimages.cdbThemeDocumentReady = cdbThemeDocumentReady;
    cascadingimages.cascadingImages = cascadingImages;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        cascadingImages();
    }

    /**
     * Floating Images Calcs
     */
    function cascadingImages() {
        var fiShortcodes = $('.cdb-cascading-images');

        if (fiShortcodes.length) {
            var getProps = function(image) {
                image
                    .data('c', image.prop('naturalWidth')/image.prop('naturalHeight'))
                    .data('w', image.attr('data-width') ? parseInt(image.attr('data-width')) : 100)
                    .data('x', image.attr('data-x') ? image.attr('data-x') : 0)
                    .data('y', image.attr('data-y') ? image.attr('data-y') : 0);
            };
        
            var setSizes = function(image, holder) {
                image.css({
                    'width': image.data('w')/100*holder.width(),
                    'height': image.data('w')/100*holder.width()/image.data('c')
                });
            };
        
            var holderCalcs = function(holder, inner, mainImg, auxImg) {
                var mainW = mainImg.data('w')/100*holder.width(),
                    mainH = mainW/mainImg.data('c'),
                    auxY = parseInt(auxImg.data('y')),
                    auxX = parseInt(auxImg.data('x')),
                    auxWCorr = auxImg.width() + Math.abs(auxX)*mainImg.width()/100,
                    auxHCorr = auxImg.height() + Math.abs(auxY)*mainImg.height()/100;
        
                var widthVal =  mainW > auxWCorr ? mainW : auxWCorr,
                    heightVal = mainH > auxHCorr ? mainH : auxHCorr;

                inner.css({
                    'height': heightVal,
                    'width': widthVal
                });

                if (auxY > 0) {
                    mainImg.css({'top': 0});
                    auxImg.css({'top': auxY/100*mainH});
                } else {
                    mainImg.css({'bottom': 0});
                    auxImg.css({'bottom': Math.abs(auxY)/100*mainH});
                }
                if (auxX > 0) {
                    mainImg.css({'left': 0});
                    auxImg.css({'left': auxX/100*mainW});
                } else {
                    mainImg.css({'right': 0});
                    auxImg.css({'right': Math.abs(auxX)/100*mainW});
                }
            };
        
            fiShortcodes.each(function() {
                var holder = $(this),
                    inner = holder.find('.inner'),
                    mainImg = holder.find('.primary-image'),
                    auxImg = holder.find('.secondary-image');
            
                holder.waitForImages(function(){
                    getProps(mainImg);
                    getProps(auxImg);
                    setSizes(mainImg, holder);
                    setSizes(auxImg, holder);
                    holderCalcs(holder, inner, mainImg, auxImg);
                });
        
                $(window).on('resize', function() {
                    setSizes(mainImg, holder);
                    setSizes(auxImg, holder);
                    holderCalcs(holder, inner, mainImg, auxImg);
                });
            });
        }
    }
})(jQuery);

(function($) {
	'use strict';
	
	var countdown = {};
	cdbTheme.modules.countdown = countdown;
	
	countdown.codebeanCountDown = codebeanCountDown;
	
	
	countdown.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		codebeanCountDown();
	}

    var countDownInView = function(el) {
        setTimeout(function(){
            el.appear(function(){
                el.addClass('in-view');
            },{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
        },30);
    };
	
	/**
	 * Countdown Shortcode
	 */
	function codebeanCountDown() {
		var countdowns = $('.cdb-countdown-wrap');
		
		if (countdowns.length) {
			countdowns.each(function(){
                var _this = $(this),
                    date = _this.data('date'),
                    onfinishHtml = _this.data('finish-text'),
                    html = _this.find('.dfd-countdown-html').html();

                _this.find('.dfd-countdown-html').remove();

                countDownInView(_this);

                _this.countdown(date).on('update.countdown', function (event) {
                    $(this).html(event.strftime(html));
                }).on('finish.countdown', function () {
                    $(this).html(onfinishHtml);
                });
			});
		}
	}
	
})(jQuery);
(function($) {
	'use strict';
	
	var counter = {};
	cdbTheme.modules.counter = counter;
	
	counter.counterElement = counterElement;
	
	
	counter.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		counterElement();
	}
	
	/**
	 * Counter Shortcode
	 */
	function counterElement() {
		var counterHolder = $('.stat-counter');
		
		if (counterHolder.length) {
			counterHolder.each(function() {
				var thisCounterHolder = $(this),
					thisCounter = thisCounterHolder.find('.fact-number');
				
				thisCounterHolder.appear(function() {
					thisCounterHolder.css('opacity', '1');
					
					//Counter zero type
					if (thisCounter.hasClass('default-counter')) {
						var max = parseFloat(thisCounter.text());
						thisCounter.countTo({
							from: 0,
							to: max,
							speed: 1500,
							refreshInterval: 100
						});
					} else {
						thisCounter.absoluteCounter({
							speed: 2000,
							fadeInDelay: 1000
						});
					}
				},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
})(jQuery);
(function ($) {
	'use strict';
	
	var customFont = {};
	cdbTheme.modules.customFont = customFont;
	
	customFont.customHeadingFontSizes = customHeadingFontSizes;
	customFont.customHeadingAutoType = customHeadingAutoType;
	
	
	customFont.cdbThemeDocumentReady = cdbThemeDocumentReady;
	customFont.cdbThemeWindowLoad = cdbThemeWindowLoad;
	
	$(document).ready(cdbThemeDocumentReady);
	$(window).load(cdbThemeWindowLoad);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		customHeadingFontSizes();
	}
	
	/*
	 All functions to be called on $(window).load() should be in this function
	 */
	function cdbThemeWindowLoad() {
		customHeadingAutoType();
	}
	
	/*
	 **	Custom Font resizing style
	 */
	function customHeadingFontSizes() {
		var holder = $('.custom-heading');
		
		if (holder.length) {
			holder.each(function () {
				var thisItem = $(this),
					itemClass = '',
					smallLaptopStyle = '',
					ipadLandscapeStyle = '',
					ipadPortraitStyle = '',
					mobileLandscapeStyle = '',
					style = '',
					responsiveStyle = '';
				
				if (typeof thisItem.data('selector') !== 'undefined' && thisItem.data('selector') !== false) {
					itemClass = thisItem.data('selector');
				}
				
				if (typeof thisItem.data('font-size-1366') !== 'undefined' && thisItem.data('font-size-1366') !== false) {
					smallLaptopStyle += 'font-size: ' + thisItem.data('font-size-1366') + ' !important;';
				}
				if (typeof thisItem.data('font-size-1024') !== 'undefined' && thisItem.data('font-size-1024') !== false) {
					ipadLandscapeStyle += 'font-size: ' + thisItem.data('font-size-1024') + ' !important;';
				}
				if (typeof thisItem.data('font-size-768') !== 'undefined' && thisItem.data('font-size-768') !== false) {
					ipadPortraitStyle += 'font-size: ' + thisItem.data('font-size-768') + ' !important;';
				}
				if (typeof thisItem.data('font-size-680') !== 'undefined' && thisItem.data('font-size-680') !== false) {
					mobileLandscapeStyle += 'font-size: ' + thisItem.data('font-size-680') + ' !important;';
				}
				
				if (typeof thisItem.data('line-height-1366') !== 'undefined' && thisItem.data('line-height-1366') !== false) {
					smallLaptopStyle += 'line-height: ' + thisItem.data('line-height-1366') + ' !important;';
				}
				if (typeof thisItem.data('line-height-1024') !== 'undefined' && thisItem.data('line-height-1024') !== false) {
					ipadLandscapeStyle += 'line-height: ' + thisItem.data('line-height-1024') + ' !important;';
				}
				if (typeof thisItem.data('line-height-768') !== 'undefined' && thisItem.data('line-height-768') !== false) {
					ipadPortraitStyle += 'line-height: ' + thisItem.data('line-height-768') + ' !important;';
				}
				if (typeof thisItem.data('line-height-680') !== 'undefined' && thisItem.data('line-height-680') !== false) {
					mobileLandscapeStyle += 'line-height: ' + thisItem.data('line-height-680') + ' !important;';
				}
				
				if (smallLaptopStyle.length || ipadLandscapeStyle.length || ipadPortraitStyle.length || mobileLandscapeStyle.length) {
					
					if (smallLaptopStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1366px) {.custom-heading." + itemClass + " { " + smallLaptopStyle + " } }";
					}
					if (ipadLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1024px) {.custom-heading." + itemClass + " { " + ipadLandscapeStyle + " } }";
					}
					if (ipadPortraitStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 768px) {.custom-heading." + itemClass + " { " + ipadPortraitStyle + " } }";
					}
					if (mobileLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 680px) {.custom-heading." + itemClass + " { " + mobileLandscapeStyle + " } }";
					}
				}
				
				if (responsiveStyle.length) {
					style = '<style type="text/css">' + responsiveStyle + '</style>';
				}
				
				if (style.length) {
					$('head').append(style);
				}
			});
		}
	}
	
	/*
	 * Init Type out functionality for Custom Font shortcode
	 */
	function customHeadingAutoType() {
		var autotype_text = $('.autotype-entries');
		
		if (autotype_text.length) {
			autotype_text.each(function () {
				
				//vars
				var thisTyped = $(this),
					typedWrap = thisTyped.parent('.autotype-wrap'),
					customFontHolder = typedWrap.parent('.custom-heading'),
					str = [],
					string_1 = thisTyped.find('.autotype-entry-1').text(),
					string_2 = thisTyped.find('.autotype-entry-2').text(),
					string_3 = thisTyped.find('.autotype-entry-3').text(),
					string_4 = thisTyped.find('.autotype-entry-4').text();
				
				if (string_1.length) {
					str.push(string_1);
				}
				
				if (string_2.length) {
					str.push(string_2);
				}
				
				if (string_3.length) {
					str.push(string_3);
				}
				
				if (string_4.length) {
					str.push(string_4);
				}
				
				customFontHolder.appear(function () {
					thisTyped.typed({
						strings: str,
						typeSpeed: 90,
						backDelay: 700,
						loop: true,
						contentType: 'text',
						loopCount: false,
						cursorChar: '_'
					});
				}, {accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
})(jQuery);
(function($) {
    'use strict';

    var fullscreenCarousel = {};
    cdbTheme.modules.fullscreenCarousel = fullscreenCarousel;

    fullscreenCarousel.fullScreenCarousel = fullScreenCarousel;

    fullscreenCarousel.cdbThemeDocumentReady = cdbThemeDocumentReady;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        fullScreenCarousel();
    }

    /**
     * Init Fullscreen Carousel shortcode
     */
    function fullScreenCarousel() {
        var fullscreenCarousels = $('.fullscreen-carousel-wrap');

        if (fullscreenCarousels.length) {
            fullscreenCarousels.each(function(){
                var fullscreenCarousel = $(this),
                    items = fullscreenCarousel.find('.carousel-item'),
                    images = fullscreenCarousel.find('.carousel-background'),
                    nextTrigger = fullscreenCarousel.find('.carousel-next-trigger'),
                    mouseXBuffer;

                //fullscreen calcs
                var fullscreenCalcs = function() {
                    var heightVal = cdbTheme.windowHeight - fullscreenCarousel.offset().top;

                    if (cdbTheme.body.hasClass('site-borders-on')) {
                        var passepartoutSize = parseInt($('.site-wrapper').css('padding-top'));

                        heightVal -= passepartoutSize;
                    }

                    fullscreenCarousel.css('height', heightVal);
                }

                //item classes setup
                var prepItems = function() {
                    items.first().addClass('active').find('> div').css('transition','none');
                    fullscreenCarousel.css('visibility','visible');
                    setTimeout(function(){
                        items.filter('.active').next().addClass('next-item');
                    }, 200);
                }

                //slideshow logic start
                var startAnimating = function() {
                    fullscreenCarousel.addClass('is-loading');
                }

                var endAnimating = function() {
                    updateNav();

                    items.filter('.active').one(cdbTheme.transitionEnd,function(){
                        fullscreenCarousel.removeClass('is-loading');
                    });
                }

                var changeItem = function() {
                    startAnimating(); //before change

                    var nextIndex;

                    //loop
                    if (items.filter('.active').data('index') < items.length) {
                        nextIndex = items.filter('.active').next().data('index') - 1;
                    } else {
                        nextIndex = 0;
                    }

                    items.find('> div').removeAttr('style');
                    items.removeClass('previous-item');
                    items.filter('.active').addClass('previous-item');
                    items.removeClass('active next-item');
                    items.eq(nextIndex).addClass('active');
                    if (nextIndex < items.length - 1) {
                        items.filter('.active').next().addClass('next-item');
                    } else {
                        items.first().addClass('next-item');
                    }

                    endAnimating(); //after change
                }
                //slideshow logic end

                //change on click
                var slideshowTrigger = function() {
                    nextTrigger.on('click', function(e){
                        if (!fullscreenCarousel.hasClass('is-loading')) {
                            changeItem();         
                        }           
                    });

                    nextTrigger.on('mouseenter', function(){
                        fullscreenCarousel.addClass('hovered');
                    }).on('mouseleave', function(){
                        fullscreenCarousel.removeClass('hovered');
                    });
                }

                //change on scroll
                var slideshowScroll = function() {
                    if (fullscreenCarousel.hasClass('slide-on-scroll') && !cdbTheme.htmlEl.hasClass('touch')) {
                        var delta = 0;

                        fullscreenCarousel.mousewheel(function(e) {
                            e.preventDefault();

                            if (!fullscreenCarousel.hasClass('is-loading')) {
                                if (e.deltaY < 0) {
                                    delta = -1;
                                } else {
                                    delta = 1;
                                }

                                if (delta == -1 ) {
                                    changeItem();
                                }
                            }
                        });

                        fullscreenCarousel.on('wheel', function() { return false; });
                    }
                }

                //update indicators
                var updateNav = function() {
                    if (fullscreenCarousel.hasClass('indicators-active')) {
                        var bullets = fullscreenCarousel.find('.carousel-indicator'),
                            activeIndex = items.filter('.active').data('index') - 1;

                        bullets.removeClass('active');
                        bullets.eq(activeIndex).addClass('active');
                    }
                }

                //init
                fullscreenCarousel.waitForImages(function(){
                    fullscreenCalcs();
                    prepItems();
                    slideshowTrigger();
                    slideshowScroll();
                    updateNav();
                });

                $(window).resize(function(){
                    fullscreenCalcs();
                });
            });
        }
    }
})(jQuery);

(function($) {
	'use strict';
	
	var googleMap = {};
	cdbTheme.modules.googleMap = googleMap;
	
	googleMap.showGoogleMap = showGoogleMap;
	
	
	googleMap.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		showGoogleMap();
	}
	
	/*
	 **	Show Google Map
	 */
	function showGoogleMap(){
		var googleMap = $('.google-map-inner');
		
		if(googleMap.length){
			googleMap.each(function(){
				var element = $(this);
				
				var snazzyMapStyle = false;
				var snazzyMapCode  = '';
				if(typeof element.data('predefined-map-style') !== 'undefined' && element.data('predefined-map-style') === 'yes') {
					snazzyMapStyle = true;
					var snazzyMapHolder = element.parent().find('.predefined-map-style'),
						snazzyMapCodes  = snazzyMapHolder.val();
					
					if( snazzyMapHolder.length && snazzyMapCodes.length ) {
						snazzyMapCode = JSON.parse( snazzyMapCodes.replace(/`{`/g, '[').replace(/`}`/g, ']').replace(/``/g, '"').replace(/`/g, '') );
					}
				}
				
				var customMapStyle;
				if(typeof element.data('custom-map-style') !== 'undefined') {
					customMapStyle = element.data('custom-map-style');
				}
				
				var colorOverlay;
				if(typeof element.data('color-overlay') !== 'undefined' && element.data('color-overlay') !== false) {
					colorOverlay = element.data('color-overlay');
				}
				
				var saturation;
				if(typeof element.data('saturation') !== 'undefined' && element.data('saturation') !== false) {
					saturation = element.data('saturation');
				}
				
				var lightness;
				if(typeof element.data('lightness') !== 'undefined' && element.data('lightness') !== false) {
					lightness = element.data('lightness');
				}
				
				var zoom;
				if(typeof element.data('zoom') !== 'undefined' && element.data('zoom') !== false) {
					zoom = element.data('zoom');
				}
				
				var pin;
				if(typeof element.data('map-marker') !== 'undefined' && element.data('map-marker') !== false) {
					pin = element.data('map-marker');
				}
				
				var mapHeight;
				if(typeof element.data('height') !== 'undefined' && element.data('height') !== false) {
					mapHeight = element.data('height');
				}
				
				var uniqueId;
				if(typeof element.data('unique-id') !== 'undefined' && element.data('unique-id') !== false) {
					uniqueId = element.data('unique-id');
				}
				
				var scrollWheel;
				if(typeof element.data('scroll-wheel') !== 'undefined') {
					scrollWheel = element.data('scroll-wheel');
				}
				var addresses;
				if(typeof element.data('location') !== 'undefined' && element.data('location') !== false) {
					addresses = element.data('location');
				}
				
				var map = "map_"+ uniqueId;
				var geocoder = "geocoder_"+ uniqueId;
				var holderId = "cdb-map-"+ uniqueId;
				
				googleMapInitialize(snazzyMapStyle, snazzyMapCode, customMapStyle, colorOverlay, saturation, lightness, scrollWheel, zoom, holderId, mapHeight, pin,  map, geocoder, addresses);
			});
		}
	}
	
	/*
	 **	Init Google Map
	 */
	function googleMapInitialize(snazzyMapStyle, snazzyMapCode, customMapStyle, color, saturation, lightness, wheel, zoom, holderId, height, pin,  map, geocoder, data){
		
		if(typeof google !== 'object') {
			return;
		}
		
		var mapStyles = [];
		if(snazzyMapStyle && snazzyMapCode.length) {
			mapStyles = snazzyMapCode;
		} else {
			mapStyles = [
				{
					stylers: [
						{hue: color },
						{saturation: saturation},
						{lightness: lightness},
						{gamma: 1}
					]
				}
			];
		}
		
		var googleMapStyleId;
		
		if(snazzyMapStyle || customMapStyle === 'yes'){
			googleMapStyleId = 'custom-style';
		} else {
			googleMapStyleId = google.maps.MapTypeId.ROADMAP;
		}
		
		wheel = wheel === 'yes';
		
		var qoogleMapType = new google.maps.StyledMapType(mapStyles, {name: "Google Map"});
		
		geocoder = new google.maps.Geocoder();
		var latlng = new google.maps.LatLng(-34.397, 150.644);
		
		if (!isNaN(height)){
			height = height + 'px';
		}
		
		var myOptions = {
			zoom: zoom,
			scrollwheel: wheel,
			center: latlng,
			zoomControl: true,
			zoomControlOptions: {
				style: google.maps.ZoomControlStyle.SMALL,
				position: google.maps.ControlPosition.RIGHT_CENTER
			},
			scaleControl: false,
			scaleControlOptions: {
				position: google.maps.ControlPosition.LEFT_CENTER
			},
			streetViewControl: false,
			streetViewControlOptions: {
				position: google.maps.ControlPosition.LEFT_CENTER
			},
			panControl: false,
			panControlOptions: {
				position: google.maps.ControlPosition.LEFT_CENTER
			},
			mapTypeControl: false,
			mapTypeControlOptions: {
				mapTypeIds: [google.maps.MapTypeId.ROADMAP, 'custom-style'],
				style: google.maps.MapTypeControlStyle.HORIZONTAL_BAR,
				position: google.maps.ControlPosition.LEFT_CENTER
			},
			mapTypeId: googleMapStyleId
		};
		
		map = new google.maps.Map(document.getElementById(holderId), myOptions);
		map.mapTypes.set('custom-style', qoogleMapType);
		
		var index;
		
		for (index = 0; index < data.length; ++index) {
			googleMapLocation(data[index], pin, map, geocoder);
		}
		
		var holderElement = document.getElementById(holderId);
		holderElement.style.height = height;
	}
	
	/*
	 **	Init Google Map Addresses
	 */
	function googleMapLocation(data, pin, map, geocoder){
		if (data === '') {
			return;
		}
		
		var contentString = '<div id="content">'+
			'<div id="siteNotice">'+
			'</div>'+
			'<div id="bodyContent">'+
			'<p>'+data+'</p>'+
			'</div>'+
			'</div>';
		
		var infowindow = new google.maps.InfoWindow({
			content: contentString
		});
		
		geocoder.geocode( { 'address': data}, function(results, status) {
			if (status === google.maps.GeocoderStatus.OK) {
				map.setCenter(results[0].geometry.location);
				var marker = new google.maps.Marker({
					map: map,
					position: results[0].geometry.location,
                    animation: google.maps.Animation.DROP,
					icon:  pin,
					title: data.store_title,
                    optimized: false
				});
				google.maps.event.addListener(marker, 'click', function() {
					infowindow.open(map,marker);
				});
				
				google.maps.event.addDomListener(window, 'resize', function() {
					map.setCenter(results[0].geometry.location);
				});
			}
		});
	}
	
})(jQuery);
(function($) {
	'use strict';
	
	var icon = {};
	cdbTheme.modules.icon = icon;
	
	icon.codeBeanIcon = codeBeanIcon;
	
	
	icon.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		codeBeanIcon().init();
	}
	
	/**
	 * Object that represents icon shortcode
	 * @returns {{init: Function}} function that initializes icon's functionality
	 */
	var codeBeanIcon = function() {
		var icons = $('.cdb-icon-shortcode');
		
		/**
		 * Function that triggers icon animation and icon animation delay
		 */
		var iconAnimation = function(icon) {
			if(icon.hasClass('cdb-icon-animation')) {
				icon.appear(function() {
					icon.parent('.icon-animate').addClass('icon-in-view');
				}, {accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			}
		};
		
		/**
		 * Function that triggers icon hover color functionality
		 */
		var iconHoverColor = function(icon) {
			if(typeof icon.data('hover-color') !== 'undefined') {
				var changeIconColor = function(event) {
					event.data.icon.css('color', event.data.color);
				};
				
				var iconElement = icon.find('.cdb-icon-element');
				var hoverColor = icon.data('hover-color');
				var originalColor = iconElement.css('color');
				
				if(hoverColor !== '') {
					icon.on('mouseenter', {icon: iconElement, color: hoverColor}, changeIconColor);
					icon.on('mouseleave', {icon: iconElement, color: originalColor}, changeIconColor);
				}
			}
		};
		
		/**
		 * Function that triggers icon holder background color hover functionality
		 */
		var iconHolderBackgroundHover = function(icon) {
			if(typeof icon.data('hover-background-color') !== 'undefined') {
				var changeIconBgColor = function(event) {
					event.data.icon.css('background-color', event.data.color);
				};
				
				var hoverBackgroundColor = icon.data('hover-background-color');
				var originalBackgroundColor = icon.css('background-color');
				
				if(hoverBackgroundColor !== '') {
					icon.on('mouseenter', {icon: icon, color: hoverBackgroundColor}, changeIconBgColor);
					icon.on('mouseleave', {icon: icon, color: originalBackgroundColor}, changeIconBgColor);
				}
			}
		};
		
		/**
		 * Function that initializes icon holder border hover functionality
		 */
		var iconHolderBorderHover = function(icon) {
			if(typeof icon.data('hover-border-color') !== 'undefined') {
				var changeIconBorder = function(event) {
					event.data.icon.css('border-color', event.data.color);
				};
				
				var hoverBorderColor = icon.data('hover-border-color');
				var originalBorderColor = icon.css('borderTopColor');
				
				if(hoverBorderColor !== '') {
					icon.on('mouseenter', {icon: icon, color: hoverBorderColor}, changeIconBorder);
					icon.on('mouseleave', {icon: icon, color: originalBorderColor}, changeIconBorder);
				}
			}
		};
		
		return {
			init: function() {
				if(icons.length) {
					icons.each(function() {
						iconAnimation($(this));
						iconHoverColor($(this));
						iconHolderBackgroundHover($(this));
						iconHolderBorderHover($(this));
					});
				}
			}
		};
	};
	
})(jQuery);
(function($) {
	'use strict';
	
	var iconListItem = {};
	cdbTheme.modules.iconListItem = iconListItem;
	
	iconListItem.cdbIconList = cdbIconList;
	
	
	iconListItem.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		cdbIconList().init();
	}
	
	/**
	 * Button object that initializes icon list with animation
	 * @type {Function}
	 */
	var cdbIconList = function() {
		var iconList = $('.animate-list');
		
		/**
		 * Initializes icon list animation
		 * @param list current slider
		 */
		var iconListInit = function(list) {
			setTimeout(function(){
				list.appear(function(){
					list.addClass('in-view');
				},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			},30);
		};
		
		return {
			init: function() {
				if(iconList.length) {
					iconList.each(function() {
						iconListInit($(this));
					});
				}
			}
		};
	};
	
})(jQuery);
(function($) {
    'use strict';

    var tripleFrameImageHighlight = {};
    cdbTheme.modules.tripleFrameImageHighlight = tripleFrameImageHighlight;

    tripleFrameImageHighlight.cdbThemeDocumentReady = cdbThemeDocumentReady;
    tripleFrameImageHighlight.frameImageSlider = frameImageSlider;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        frameImageSlider();
    }

    /**
     * Image Frame Slider
     */
    function frameImageSlider() {
        var tfihShortcodes = $('.frame-slider');

        if (tfihShortcodes.length) {
            var initClasses = function(c, l, r) {
                c.addClass('center');
                l.addClass('left');
                r.addClass('right');
            }

            var resetIndexes = function(c, l, r) {
                c.css('z-index', 30);
                l.css('z-index', 20);
                r.css('z-index', 20);
            }

            var setTriggerSize = function(holder,inner) {
                holder.find('div[class*="trigger"]').width(Math.round(inner.position().left));
            }

            var setPositioning = function(holder, inner) {
                var left = holder.find('.left'),
                    right = holder.find('.right'),
                    centered = holder.find('.center');

                var xOffset = inner.position().left;

                left.css({
                    'visibility': 'visible',
                    'transform-origin': '0% 50%',
                    'transform': 'matrix(.68,0,0,.68,-'+xOffset+',0)'
                });
                right.css({
                    'visibility': 'visible',
                    'transform-origin': '100% 50%',
                    'transform': 'matrix(.68,0,0,.68,'+xOffset+',0)'
                });
                centered.css({
                    'transform': 'matrix(1, 0, 0, 1, 0, 0)'
                });
            }

            var rotateAnimation = function(holder, inner, direction) {
                holder.data('animating', true);

                if (direction == 'left') {
                    var toFront = holder.find('.left'),
                        toBack = holder.find('.center'),
                        toPrep = holder.find('.right');

                    toPrep.removeClass('right').addClass('left');
                    toBack.removeClass('center').addClass('right');
                    toFront.removeClass('left').addClass('center');
                } else {
                    var toFront = holder.find('.right'),
                        toBack = holder.find('.center'),
                        toPrep = holder.find('.left');

                    toPrep.removeClass('left').addClass('right');
                    toBack.removeClass('center').addClass('left');
                    toFront.removeClass('right').addClass('center');
                }

                toPrep.css({
                    'z-index': 15,
                    'transform-origin': '0% 50%',
                    'transition': 'transform .5s, transform-origin .5s'
                });
                toBack.css({
                    'z-index': 25,
                    'transform-origin': '100% 50%',
                    'transition': 'transform 1s ease .2s, \
                                    transform-origin 1s ease .2s'
                });
                toFront.css({
                    'z-index': 20,
                    'transform-origin': '50% 50%',
                    'transition': 'transform .75s ease .5s, \
                                    transform-origin .75s ease .5s'
                });

                holder.find('a').css('pointer-events', 'none');
                setTimeout(function() {
                    holder.find('a').css('pointer-events', 'auto');
                    resetIndexes(toFront, toPrep, toBack);
                }, 500);

                toFront.one(cdbTheme.transitionEnd, function() {
                    holder.data('animating', false);
                    clearInterval(holder.data('autoplay'));
                    holder.data('autoplay', setInterval(function() {
                        navigate(holder, inner);
                    }, 3000));
                })
            }

            var navigate = function(holder, inner, event) {
                var direction,
                    linkActive = false;

                if (typeof event !== 'undefined') {
                    switch(event.target.className) {
                        case 'frame-slider-left-trigger':
                            direction = 'left';
                            break;
                        case 'frame-slider-right-trigger':
                            direction = 'right';
                            break;
                        case 'frame-slider-link':
                            linkActive = true;
                            holder.data('animating', false);
                            clearInterval(holder.data('autoplay'));
                            break;
                    }
                } else {
                    direction = 'right';
                }

                if (!linkActive) {
                    rotateAnimation(holder, inner, direction)
                    setPositioning(holder, inner);
                }
            }

            tfihShortcodes.each(function() {
                var holder = $(this),
                    inner = holder.find('.frame-slider-inner'),
                    centeredH = holder.find('.frame-slider-centered'),
                    leftH = holder.find('.frame-slider-left'),
                    rightH = holder.find('.frame-slider-right');

                //state
                holder
                    .data('animating', false)
                    .data('autoplay', false);

                initClasses(centeredH, leftH, rightH);
                resetIndexes(centeredH, leftH, rightH);
                setTriggerSize(holder, inner);

                holder.waitForImages(function() {
                    holder.appear(function() {
                        holder.css('visibility', 'visible');
                        setPositioning(holder, inner);
                        holder.data('autoplay', setInterval(function() {
                            navigate(holder, inner);
                        }, 3000));
                    }, {accX: 0, accY: theme_global_vars.vars.appear_element_amount});
                });

                holder.on('click', function(event) {
                    if (!holder.data('animating')) {
                        clearInterval(holder.data('autoplay'));
                        navigate(holder, inner, event);
                    }
                });

                if (holder.parent().hasClass('frame-slider-has-navigation')) {
                    var left = holder.parent().find('.nav-left'),
                        right = holder.parent().find('.nav-right');

                    left.on('click', function() {
                        if (!holder.data('animating')) {
                            rotateAnimation(holder, inner, 'left')
                            setPositioning(holder, inner);
                        }
                    });

                    right.on('click', function() {
                        if (!holder.data('animating')) {
                            rotateAnimation(holder, inner, 'right')
                            setPositioning(holder, inner);
                        }
                    });
                }

                $(window).on('resize', function() {
                    setPositioning(holder, inner);
                    setTriggerSize(holder, inner);
                    inner.find('>div').css('transition', 'none');
                })
            });
        }
    }
})(jQuery);

(function($) {
    'use strict';
    
    var imageMarquee = {};
    cdbTheme.modules.imageMarquee = imageMarquee;
    
    imageMarquee.imageHorizontalFreeScroll = imageHorizontalFreeScroll;
    
    imageMarquee.cdbThemeDocumentReady = cdbThemeDocumentReady;
    
    $(document).ready(cdbThemeDocumentReady);
    
    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        imageHorizontalFreeScroll();
    }
    
    /**
     * Init Text Marquee effect
     */
    function imageHorizontalFreeScroll() {
        var imageMarqueeShortcodes = $('.freescroll-viewport');

        if (imageMarqueeShortcodes.length) {
            imageMarqueeShortcodes.each(function(){
                var imageMarqueeShortcode = $(this),
                    marqueeElements = imageMarqueeShortcode.find('.the-img'),
                    originalItem = marqueeElements.filter('.initialized-img'),
                    auxItem = marqueeElements.filter('.duplicated-img');

                var marqueeEffect = function () {
	                requestAnimationFrame();
	                
                    var delta = 1, //pixel movement
                        speedCoeff = 0.8, // below 1 to slow down, above 1 to speed up
                        marqueeWidth = originalItem.width();

                    auxItem.css('width', marqueeWidth); //same width as the initial marquee element
                    auxItem.css('left', marqueeWidth); //set to the right of the initial marquee element

                    //movement loop
                    marqueeElements.each(function(i){
                        var marqueeElement = $(this),
                            currentPos = 0;

                        var infiniteFreeScrollEffect = function() {
                            currentPos -= delta;

                            //move marquee element
                            if (marqueeElement.position().left <= -marqueeWidth) {
                                marqueeElement.css('left', parseInt(marqueeWidth - delta));
                                currentPos = 0;
                            }

                            marqueeElement.css('transform','translate3d('+speedCoeff*currentPos+'px,0,0)');
	
	                        requestNextAnimationFrame(infiniteFreeScrollEffect);

                            $(window).resize(function(){
                                marqueeWidth = originalItem.width();
                                currentPos = 0;
                                originalItem.css('left',0); // reset
                    			auxItem.css('width', marqueeWidth); //same width as the initial marquee element
                                auxItem.css('left', marqueeWidth); //set to the right of the inital marquee element
                            });
                        }; 
                            
                        infiniteFreeScrollEffect();
                    });
                };

                imageMarqueeShortcode.waitForImages(function(){
	                marqueeEffect();
	            });
            });
        }
    }
    
    /*
     * Request Animation Frame shim
     */
	function requestAnimationFrame() {
		window.requestNextAnimationFrame =
			(function () {
				var originalWebkitRequestAnimationFrame,
					wrapper,
					callback,
					geckoVersion = 0,
					userAgent = navigator.userAgent,
					index = 0,
					self = this;
				
				// Workaround for Chrome 10 bug where Chrome
				// does not pass the time to the animation function
				
				if (window.webkitRequestAnimationFrame) {
					// Define the wrapper
					
					wrapper = function (time) {
						if (time === undefined) {
							time = +new Date();
						}
						
						self.callback(time);
					};
					
					// Make the switch
					
					originalWebkitRequestAnimationFrame = window.webkitRequestAnimationFrame;
					
					window.webkitRequestAnimationFrame = function (callback, element) {
						self.callback = callback;
						
						// Browser calls the wrapper and wrapper calls the callback
						
						originalWebkitRequestAnimationFrame(wrapper, element);
					};
				}
				
				// Workaround for Gecko 2.0, which has a bug in
				// mozRequestAnimationFrame() that restricts animations
				// to 30-40 fps.
				
				if (window.mozRequestAnimationFrame) {
					// Check the Gecko version. Gecko is used by browsers
					// other than Firefox. Gecko 2.0 corresponds to
					// Firefox 4.0.
					
					index = userAgent.indexOf('rv:');
					
					if (userAgent.indexOf('Gecko') != -1) {
						geckoVersion = userAgent.substr(index + 3, 3);
						
						if (geckoVersion === '2.0') {
							// Forces the return statement to fall through
							// to the setTimeout() function.
							
							window.mozRequestAnimationFrame = undefined;
						}
					}
				}
				
				return window.requestAnimationFrame   ||
					window.webkitRequestAnimationFrame ||
					window.mozRequestAnimationFrame    ||
					window.oRequestAnimationFrame      ||
					window.msRequestAnimationFrame     ||
					
					function (callback, element) {
						var start,
							finish;
						
						window.setTimeout( function () {
							start = +new Date();
							callback(start);
							finish = +new Date();
							
							self.timeout = 1000 / 60 - (finish - start);
							
						}, self.timeout);
					};
				}
			)();
	}

})(jQuery);
(function($) {
	'use strict';
	
	var itemShowcase = {};
	cdbTheme.modules.itemShowcase = itemShowcase;
	
	itemShowcase.servicesShowcase = servicesShowcase;
	
	
	itemShowcase.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		servicesShowcase();
	}
	
	/**
	 * Init item showcase shortcode
	 */
	function servicesShowcase() {
		var itemShowcase = $('.services-showcase');
		
		if (itemShowcase.length) {
			itemShowcase.each(function(){
				var thisItemShowcase = $(this),
					leftItems = thisItemShowcase.find('.left'),
					rightItems = thisItemShowcase.find('.right'),
					itemImage = thisItemShowcase.find('.service-image-wrap');
				
				//logic
				leftItems.wrapAll( "<div class='service-unit-wrapper left-aligned' />");
				rightItems.wrapAll( "<div class='service-unit-wrapper right-aligned' />");
				thisItemShowcase.animate({opacity:1},200);
				
				setTimeout(function(){
					thisItemShowcase.appear(function(){
						itemImage.addClass('in-view');
						thisItemShowcase.on('webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend',
							function(e) {
								if(cdbTheme.windowWidth > 1200) {
									itemAppear('.left-aligned .service-unit');
									itemAppear('.right-aligned .service-unit');
								} else {
									itemAppear('.service-unit');
								}
							});
					},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
				},100);
				
				//appear animation trigger
				function itemAppear(itemCSSClass) {
					thisItemShowcase.find(itemCSSClass).each(function(i){
						var thisListItem = $(this);
						setTimeout(function(){
							thisListItem.addClass('in-view');
						}, i*150);
					});
				}
			});
		}
	}
	
})(jQuery);
(function($) {
	'use strict';
	
	var pieChart = {};
	cdbTheme.modules.pieChart = pieChart;
	
	pieChart.cdbPieChart = cdbPieChart;
	
	
	pieChart.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		cdbPieChart();
	}
	
	/**
	 * Init Pie Chart shortcode
	 */
	function cdbPieChart() {
		var pieChartHolder = $('.cdb-piecharts');
		
		if (pieChartHolder.length) {
			pieChartHolder.each(function () {
				var thisPieChartHolder = $(this),
                    pieChartHolderInner = thisPieChartHolder.find('.inner-circle'),
					pieChart = pieChartHolderInner.children('.piechart-number'),
					barColor = '#2b2b2b',
					trackColor = '#f7f7f7',
					lineWidth = 4,
					size = 170;
				
				if(typeof pieChart.data('size') !== 'undefined' && pieChart.data('size') !== '') {
					size = pieChart.data('size');
				}
				
				if(typeof pieChart.data('bar-color') !== 'undefined' && pieChart.data('bar-color') !== '') {
					barColor = pieChart.data('bar-color');
				}
				
				if(typeof pieChart.data('track-color') !== 'undefined' && pieChart.data('track-color') !== '') {
					trackColor = pieChart.data('track-color');
				}
				
				pieChart.appear(function() {
					initToCounterPieChart(pieChart);
					thisPieChartHolder.css('opacity', '1');
					
					pieChart.easyPieChart({
						barColor: barColor,
						trackColor: trackColor,
						scaleColor: false,
						lineCap: 'butt',
						lineWidth: lineWidth,
						animate: 1500,
						size: size
					});
				},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
	/*
	 **	Counter for pie chart number from zero to defined number
	 */
	function initToCounterPieChart(pieChart){
		var counter = pieChart.find('.piechart-value'),
			max = parseFloat(counter.text());
		
		counter.countTo({
			from: 0,
			to: max,
			speed: 1500,
			refreshInterval: 50
		});
	}
	
})(jQuery);
(function($) {
	'use strict';
	
	var process = {};
	cdbTheme.modules.process = process;
	
	process.processSteps = processSteps;
	
	
	process.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		processSteps();
	}
	
	/**
	 * Inti process shortcode on appear
	 */
	function processSteps() {
		var holder = $('.process-wrapper');
		
		if(holder.length) {
			holder.each(function(){
				var thisHolder = $(this);
				
				thisHolder.appear(function(){
					thisHolder.addClass('in-view');
				},{accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
})(jQuery);
(function($) {
	'use strict';
	
	var progressBar = {};
	cdbTheme.modules.progressBar = progressBar;
	
	progressBar.progressBars = progressBars;
	
	
	progressBar.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		progressBars();
	}
	
	/*
	 **	Horizontal progress bars shortcode
	 */
	function progressBars() {
		var progressBar = $('.cdb-progressbar ');
		
		if (progressBar.length) {
			progressBar.each(function () {
				var thisBar = $(this),
					thisBarContent = thisBar.find('.meter'),
					progressBar = thisBar.find('.progressbar-value'),
					percentage = thisBarContent.data('percentage');
				
				thisBar.appear(function () {
					progressBarNumberCounter(progressBar, percentage);
					
					thisBarContent.css('width', '0%').animate({'width': percentage + '%'}, 2000);
					
					if (thisBar.hasClass('number-animated')) {
						progressBar.css('left', '0%').animate({'left': percentage + '%'}, 2000);
					}
				});
			});
		}
	}
	
	/*
	 **	Counter for horizontal progress bars percent from zero to defined percent
	 */
	function progressBarNumberCounter(progressBar, percentageValue){
		var percentage = parseFloat(percentageValue);
		
		if(progressBar.length) {
			progressBar.each(function() {
				var thisPercent = $(this);
				thisPercent.css('opacity', '1');
				
				thisPercent.countTo({
					from: 0,
					to: percentage,
					speed: 2000,
					refreshInterval: 50
				});
			});
		}
	}
	
})(jQuery);
(function($) {
    'use strict';

    var rotateBoxes = {};
    cdbTheme.modules.rotateBoxes = rotateBoxes;

    rotateBoxes.cdbThemeDocumentReady = cdbThemeDocumentReady;
    rotateBoxes.rotateBoxOnTouch = rotateBoxOnTouch;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        rotateBoxOnTouch();
    }

    /**
     * Init info box animation
     */
    function rotateBoxOnTouch(){
        var items = $('.rotate-boxes-wrap .rotate-box-item');

        if(items.length && cdbTheme.htmlEl.hasClass('touch')){
            items.each(function() {
                var _this = $(this);

                _this.on('click', function(){
                    $(this).toggleClass('touch-animate');
                });
            });
        }
    }

})(jQuery);
(function($) {
	'use strict';
	
	var tabs = {};
	cdbTheme.modules.tabs = tabs;
	
	tabs.codeBeanTabs = codeBeanTabs;
	
	
	tabs.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		codeBeanTabs();
	}
	
	/*
	 **	Init tabs shortcode
	 */
	function codeBeanTabs(){
		var tabs = $('.cdb-tabs');
		
		if(tabs.length){
			tabs.each(function(){
				var thisTabs = $(this);
				
				thisTabs.children('.cdb-tab-panel').each(function(index){
					index = index + 1;
					var that = $(this),
						link = that.attr('id'),
						navItem = that.parent().find('.cdb-tabs-nav li:nth-child('+index+') a'),
						navLink = navItem.attr('href');
					
					link = '#'+link;

					if(link.indexOf(navLink) > -1) {
						navItem.attr('href',link);
					}
				});
				
				thisTabs.tabs();

                $('.cdb-tabs a.external-link').unbind('click');
			});
		}
	}
	
})(jQuery);
(function($) {
    'use strict';
    
    var TextScrolling = {};
    cdbTheme.modules.TextScrolling = TextScrolling;
    
    TextScrolling.textScrollingInitialize = textScrollingInitialize;
	TextScrolling.resizeTextScrolling = resizeTextScrolling;
    
    TextScrolling.cdbThemeDocumentReady = cdbThemeDocumentReady;
    
    $(document).ready(cdbThemeDocumentReady);
    
    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        resizeTextScrolling();
        textScrollingInitialize();
    }
    
    /**
     * Init Text Marquee effect
     */
    function textScrollingInitialize() {
        var TextScrollingShortcodes = $('.text-scrolling');

        if (TextScrollingShortcodes.length) {
            TextScrollingShortcodes.each(function(){
                var TextScrollingShortcode = $(this),
                    marqueeElements = TextScrollingShortcode.find('.text-scrolling-unit'),
                    originalText = marqueeElements.filter('.initialized-text'),
                    auxText = marqueeElements.filter('.duplicated-text');

                var calcWidth = function(element) {
                    var width;

                    if (TextScrollingShortcode.outerWidth() > element.outerWidth()) {
                        width = TextScrollingShortcode.outerWidth();
                    } else {
                        width = element.outerWidth();
                    }

                    return width;
                };

                var marqueeEffect = function () {
	                requestAnimationFrame();
	                
                    var delta = 1, //pixel movement
                        speedCoeff = 1.6, // below 1 to slow down, above 1 to speed up
                        marqueeWidth = calcWidth(originalText);
                    marqueeElements.css({'width':marqueeWidth}); // set the same width to both elements
                    auxText.css('left', marqueeWidth); //set to the right of the initial marquee element

                    //movement loop
                    marqueeElements.each(function(i){
                        var marqueeElement = $(this),
                            currentPos = 0;

                        var infiniteFreeScrollEffect = function() {
                            currentPos -= delta;

                            //move marquee element
                            if (marqueeElement.position().left <= -marqueeWidth) {
                                marqueeElement.css('left', parseInt(marqueeWidth - delta));
                                currentPos = 0;
                            }

                            marqueeElement.css('transform','translate3d('+speedCoeff*currentPos+'px,0,0)');

	                        requestNextAnimationFrame(infiniteFreeScrollEffect);

                            $(window).resize(function(){
                                marqueeWidth = calcWidth(originalText);
                                currentPos = 0;
                                originalText.css('left',0);
                                auxText.css('left', marqueeWidth); //set to the right of the inital marquee element
                            });
                        }; 
                            
                        infiniteFreeScrollEffect();
                    });
                };

                marqueeEffect();
            });
        }
    }
    
    /*
     * Request Animation Frame shim
     */
	function requestAnimationFrame() {
		window.requestNextAnimationFrame =
			(function () {
				var originalWebkitRequestAnimationFrame,
					wrapper,
					callback,
					geckoVersion = 0,
					userAgent = navigator.userAgent,
					index = 0,
					self = this;
				
				// Workaround for Chrome 10 bug where Chrome
				// does not pass the time to the animation function
				
				if (window.webkitRequestAnimationFrame) {
					// Define the wrapper
					
					wrapper = function (time) {
						if (time === undefined) {
							time = +new Date();
						}
						
						self.callback(time);
					};
					
					// Make the switch
					
					originalWebkitRequestAnimationFrame = window.webkitRequestAnimationFrame;
					
					window.webkitRequestAnimationFrame = function (callback, element) {
						self.callback = callback;
						
						// Browser calls the wrapper and wrapper calls the callback
						originalWebkitRequestAnimationFrame(wrapper, element);
					};
				}
				
				// Workaround for Gecko 2.0, which has a bug in
				// mozRequestAnimationFrame() that restricts animations
				// to 30-40 fps.
				
				if (window.mozRequestAnimationFrame) {
					// Check the Gecko version. Gecko is used by browsers
					// other than Firefox. Gecko 2.0 corresponds to
					// Firefox 4.0.
					
					index = userAgent.indexOf('rv:');
					
					if (userAgent.indexOf('Gecko') !== -1) {
						geckoVersion = userAgent.substr(index + 3, 3);
						
						if (geckoVersion === '2.0') {
							// Forces the return statement to fall through
							// to the setTimeout() function.
							
							window.mozRequestAnimationFrame = undefined;
						}
					}
				}
				
				return window.requestAnimationFrame   ||
					window.webkitRequestAnimationFrame ||
					window.mozRequestAnimationFrame    ||
					window.oRequestAnimationFrame      ||
					window.msRequestAnimationFrame     ||
					
					function (callback, element) {
						var start,
							finish;
						
						window.setTimeout( function () {
							start = +new Date();
							callback(start);
							finish = +new Date();
							
							self.timeout = 1000 / 60 - (finish - start);
							
						}, self.timeout);
					};
				}
			)();
	}

	/*
	 **	Text Marquee resizing style
	 */
	function resizeTextScrolling() {
		var holder = $('.text-scrolling');

		if (holder.length) {
			holder.each(function () {
				var thisItem = $(this),
					itemClass = '',
					smallLaptopStyle = '',
					ipadLandscapeStyle = '',
					ipadPortraitStyle = '',
					mobileLandscapeStyle = '',
					style = '',
					responsiveStyle = '';

				if (typeof thisItem.data('unique-class') !== 'undefined' && thisItem.data('unique-class') !== false) {
					itemClass = thisItem.data('unique-class');
				}

				if (typeof thisItem.data('font-size-1366') !== 'undefined' && thisItem.data('font-size-1366') !== false) {
					smallLaptopStyle += 'font-size: ' + thisItem.data('font-size-1366') + ' !important;';
				}
				if (typeof thisItem.data('font-size-1024') !== 'undefined' && thisItem.data('font-size-1024') !== false) {
					ipadLandscapeStyle += 'font-size: ' + thisItem.data('font-size-1024') + ' !important;';
				}
				if (typeof thisItem.data('font-size-768') !== 'undefined' && thisItem.data('font-size-768') !== false) {
					ipadPortraitStyle += 'font-size: ' + thisItem.data('font-size-768') + ' !important;';
				}
				if (typeof thisItem.data('font-size-680') !== 'undefined' && thisItem.data('font-size-680') !== false) {
					mobileLandscapeStyle += 'font-size: ' + thisItem.data('font-size-680') + ' !important;';
				}

				if (typeof thisItem.data('line-height-1366') !== 'undefined' && thisItem.data('line-height-1366') !== false) {
					smallLaptopStyle += 'line-height: ' + thisItem.data('line-height-1366') + ' !important;';
				}
				if (typeof thisItem.data('line-height-1024') !== 'undefined' && thisItem.data('line-height-1024') !== false) {
					ipadLandscapeStyle += 'line-height: ' + thisItem.data('line-height-1024') + ' !important;';
				}
				if (typeof thisItem.data('line-height-768') !== 'undefined' && thisItem.data('line-height-768') !== false) {
					ipadPortraitStyle += 'line-height: ' + thisItem.data('line-height-768') + ' !important;';
				}
				if (typeof thisItem.data('line-height-680') !== 'undefined' && thisItem.data('line-height-680') !== false) {
					mobileLandscapeStyle += 'line-height: ' + thisItem.data('line-height-680') + ' !important;';
				}

				if (smallLaptopStyle.length || ipadLandscapeStyle.length || ipadPortraitStyle.length || mobileLandscapeStyle.length) {

					if (smallLaptopStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1366px) {.text-scrolling." + itemClass + " { " + smallLaptopStyle + " } }";
					}
					if (ipadLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1024px) {.text-scrolling." + itemClass + " { " + ipadLandscapeStyle + " } }";
					}
					if (ipadPortraitStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 768px) {.text-scrolling." + itemClass + " { " + ipadPortraitStyle + " } }";
					}
					if (mobileLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 680px) {.text-scrolling." + itemClass + " { " + mobileLandscapeStyle + " } }";
					}
				}

				if (responsiveStyle.length) {
					style = '<style type="text/css">' + responsiveStyle + '</style>';
				}

				if (style.length) {
					$('head').append(style);
				}
			});
		}
	}

})(jQuery);
(function($) {
	'use strict';
	
	var vSplitSlider = {};
	cdbTheme.modules.vSplitSlider = vSplitSlider;
	
	vSplitSlider.splitSliderInitialize = splitSliderInitialize;
	
	
	vSplitSlider.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		splitSliderInitialize();
	}
	
	/*
	 **	Vertical Split Slider
	 */
	function splitSliderInitialize() {
		var slider = $('.sl-slider-wrapper'),
			progressBarFlag = true;
		
		if (slider.length) {
			if (cdbTheme.body.hasClass('sl-slider-active')) {
				cdbTheme.body.removeClass('sl-slider-active');
				$.fn.multiscroll.destroy();
			}
			
			slider.height(cdbTheme.windowHeight).animate({opacity: 1}, 300);
			
			var defaultHeaderStyle = '';
			if (cdbTheme.body.hasClass('light-header')) {
				defaultHeaderStyle = 'light';
			} else if (cdbTheme.body.hasClass('dark-header')) {
				defaultHeaderStyle = 'dark';
			}
			
			slider.multiscroll({
				scrollingSpeed: 700,
				easing: 'easeInOutQuart',
				navigation: true,
				useAnchorsOnLoad: false,
				sectionSelector: '.sl-slider-content',
				leftSelector: '.sl-slider-left-wrapper',
				rightSelector: '.sl-slider-right-wrapper',
				afterRender: function () {
					slSliderHeaderSwitchMode($('.sl-slider-left-wrapper .sl-slider-content:first-child').data('header-style'), defaultHeaderStyle);

					cdbTheme.body.addClass('sl-slider-active');
					
					var contactForm7 = $('div.wpcf7 > form');
					if (contactForm7.length) {
						contactForm7.each(function(){
							var thisForm = $(this);
							
							thisForm.find('.wpcf7-submit').off().on('click', function(e){
								e.preventDefault();
								wpcf7.submit(thisForm);
							});
						});
					}
					
					//prepare html for smaller screens - start //
					var vSplitSliderResponsive = $('<div class="sl-slider-responsive"></div>'),
						leftSide = slider.find('.sl-slider-left-wrapper > div'),
						rightSide = slider.find('.sl-slider-right-wrapper > div');
					
					slider.after(vSplitSliderResponsive);
					
					for (var i = 0; i < leftSide.length; i++) {
						vSplitSliderResponsive.append($(leftSide[i]).clone(true));
						vSplitSliderResponsive.append($(rightSide[leftSide.length - 1 - i]).clone(true));
					}
					
					//prepare google maps clones
					var googleMapHolder = $('.sl-slider-responsive .codebean-google-map');
					if (googleMapHolder.length) {
						googleMapHolder.each(function () {
							var map = $(this);
							map.empty();
							var num = Math.floor((Math.random() * 100000) + 1);
							map.attr('id', 'cdb-map-' + num);
							map.data('unique-id', num);
						});
					}
					
					if (typeof cdbTheme.modules.animationHolder.animationBox === "function") {
						cdbTheme.modules.animationHolder.animationBox();
					}
					
					if (typeof cdbTheme.modules.button.codeBeanButton === "function") {
						cdbTheme.modules.button.codeBeanButton().init();
					}
					
					if (typeof cdbTheme.modules.elementsHolder.contentBoxResponsiveStyles === "function") {
						cdbTheme.modules.elementsHolder.contentBoxResponsiveStyles();
					}
					
					if (typeof cdbTheme.modules.googleMap.showGoogleMap === "function") {
						cdbTheme.modules.googleMap.showGoogleMap();
					}
					
					if (typeof cdbTheme.modules.icon.codeBeanIcon === "function") {
						cdbTheme.modules.icon.codeBeanIcon().init();
					}
					
					if (progressBarFlag && typeof cdbTheme.modules.progressBar.progressBars === "function" && ($('.sl-slider-left-wrapper .sl-slider-content.active').find('.progress-bar').length || $('.sl-slider-right-wrapper .sl-slider-content.active').find('.progress-bar').length)) {
						cdbTheme.modules.progressBar.progressBars();
						progressBarFlag = false;
					}
				},
				onLeave: function (index, nextIndex) {

					if (progressBarFlag && typeof cdbTheme.modules.progressBar.progressBars === "function" && ($('.sl-slider-left-wrapper .sl-slider-content.active').find('.progress-bar').length || $('.sl-slider-right-wrapper .sl-slider-content.active').find('.progress-bar').length)) {
						setTimeout(function(){
							cdbTheme.modules.progressBar.progressBars();
						},700);

						progressBarFlag = false;
					}

					animationOnScroll(slider, nextIndex);
					slSliderHeaderSwitchMode($($('.sl-slider-left-wrapper .sl-slider-content')[nextIndex - 1]).data('header-style'), defaultHeaderStyle);
				}
			});
			
			if (cdbTheme.windowWidth <= 1024) {
				$.fn.multiscroll.destroy();
				cdbTheme.modules.progressBar.progressBars();
				progressBarFlag = false;
			} else {
				$.fn.multiscroll.build();
			}
			
			$(window).resize(function () {
				if (cdbTheme.windowWidth <= 1024) {
					$.fn.multiscroll.destroy();
					cdbTheme.modules.progressBar.progressBars();
					progressBarFlag = false;

				} else {
					$.fn.multiscroll.build();
				}
			});
		}
	}
	
	function animationOnScroll(slider, nextIndex) {
		
		if (slider.hasClass('sl-slider-true-on-scroll')) {
			
			if (nextIndex > 1 && !slider.hasClass('sl-slider-scrolled')) {
				slider.addClass('sl-slider-scrolled');
			} else if (nextIndex === 1 && slider.hasClass('sl-slider-scrolled')) {
				slider.removeClass('sl-slider-scrolled');
			}
		}
	}
	
	/*
	 **	Check slides on load and slide change for header style changing
	 */
	function slSliderHeaderSwitchMode(section_header_style, default_header_style) {
		if (section_header_style !== undefined && section_header_style !== '') {
			cdbTheme.body.removeClass('light-header dark-header').addClass( section_header_style + '-header');
		} else if (default_header_style !== '') {
			cdbTheme.body.removeClass('light-header dark-header').addClass( default_header_style + '-header');
		} else {
			cdbTheme.body.removeClass('light-header dark-header');
		}
	}
	
})(jQuery);
(function($) {
    'use strict';

    var portfolioFullScreen = {};
    cdbTheme.modules.portfolioFullScreen = portfolioFullScreen;

    portfolioFullScreen.cdbThemeWindowLoad = cdbThemeWindowLoad;

    $(window).load(cdbThemeWindowLoad);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        portfolioFullScreenSlider();
    }

    /**
     * Initializes swiper slide for portfolio vertical slider
     */
    function portfolioFullScreenSlider() {

        var portfolioVertical = $('.portfolio-vertical-slider'),
            params = {
            nextButton: '.swiper-button-next',
            prevButton: '.swiper-button-prev',
            speed: 1000,
            pagination: '.swiper-pagination',
            paginationClickable: true,
            paginationType : 'fraction',
            paginationFractionRender: function (swiper, currentClassName, totalClassName) {
                return '<span class="' + currentClassName + '"></span>' +
                    ' - ' +
                    '<span class="' + totalClassName + '"></span>';
            },
            loop: true,
            effect: 'fade',
            dynamicMainBullets: 3,
            direction: 'vertical',
            keyboardControl: true,
            mousewheelControl: true,
            onInit: function(e) {
                var i = e.activeIndex,
                    color = e.slides.eq(i).data('color');
                if (!cdbTheme.body.hasClass(color)) {
                    cdbTheme.body.removeClass('color-scheme-light color-scheme-dark').addClass(color);
                }
                cdbTheme.window.on('orientationchange', function() {
                    e.update();
                });
            },
            onSlideChangeStart: function(e) {
                var color = $('.swiper-slide-active').data('color');

                cdbTheme.body.removeClass('color-scheme-light color-scheme-dark').addClass(color);
            }
        };

        if (portfolioVertical.length) {
            portfolioVertical.each(function () {
               var swiperSlider = new Swiper( portfolioVertical, params );
            });
        }

    }

})(jQuery);
(function($) {
    'use strict';

    var portfolioList = {};
    cdbTheme.modules.portfolioList = portfolioList;

    portfolioList.cdbThemeWindowLoad = cdbThemeWindowLoad;
    portfolioList.cdbThemeWindowScroll = cdbThemeWindowScroll;

    $(window).load(cdbThemeWindowLoad);
    $(window).scroll(cdbThemeWindowScroll);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        portfolioFilters();
        portfolioItemsAnim();
	    portfolioPagination().init();
    }

    /*
     All functions to be called on $(window).scroll() should be in this function
     */
    function cdbThemeWindowScroll() {
	    portfolioPagination().scroll();
    }

    /**
     * Initializes portfolio list article animation
     */
    function portfolioItemsAnim(){
        var portList = $('.cdb-portfolio-grid.with-animation');

        if(portList.length){
            portList.each(function(){
                var thisPortList = $(this).children('.portfolio-wrap-inner');

                thisPortList.children('article').each(function(l) {
                    var thisArticle = $(this);

                    thisArticle.appear(function() {
                        thisArticle.addClass('show-item');

                        setTimeout(function(){
                            thisArticle.addClass('is-visible');
                        }, 1000);
                    },{accX: 0, accY: 0});
                });
            });
        }
    }

    /**
     * Initializes portfolio masonry filter
     */
    function portfolioFilters(){
        var filterHolder = $('.cdb-portfolio-grid .portfolio-filters-wrap');

        if(filterHolder.length){
            filterHolder.each(function(){
                var thisFilterHolder = $(this),
                    thisPortListHolder = thisFilterHolder.closest('.cdb-portfolio-grid'),
                    thisPortListInner = thisPortListHolder.find('.portfolio-wrap-inner'),
                    portListHasLoadMore = thisPortListHolder.hasClass('pagination-type-load-more') ? true : false;

                thisFilterHolder.find('.p-filter:first').addClass('active');
	            
	            if(thisPortListHolder.hasClass('portfolio-gallery')) {
		            thisPortListInner.isotope();
	            }

                thisFilterHolder.find('.p-filter').on('click', function(){
                    var thisFilter = $(this),
                        filterValue = thisFilter.attr('data-filter'),
                        filterClassName = filterValue.length ? filterValue.substring(1) : '',
	                    portListHasArticles = thisPortListInner.children().hasClass(filterClassName) ? true : false;

                    thisFilter.parent().children('.p-filter').removeClass('active');
                    thisFilter.addClass('active');
	
	                if(portListHasLoadMore && !portListHasArticles && filterValue.length) {
		                loadMorePortfolioFilter(thisPortListHolder, filterValue, filterClassName);
	                } else {
		                filterValue = filterValue.length === 0 ? '*' : filterValue;
                   
                        thisFilterHolder.parent().children('.portfolio-wrap-inner').isotope({ filter: filterValue });
	                    cdbTheme.modules.common.parallaxInitialize();
                    }
                });
            });
        }
    }

    /**
     * Initializes load more items if portfolio masonry filter item is empty
     */
    function loadMorePortfolioFilter($portfolioList, $filterValue, $filterClassName) {
        var thisPortList = $portfolioList,
            thisPortListInner = thisPortList.find('.portfolio-wrap-inner'),
            filterValue = $filterValue,
            filterClassName = $filterClassName,
            maxNumPages = 0;

        if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
            maxNumPages = thisPortList.data('max-num-pages');
        }

        var	loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisPortList),
            nextPage = loadMoreDatta.nextPage,
	        ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'caledon_addon_portfolio_ajax_load_more'),
            loadingItem = thisPortList.find('.portfolio-loader');

        if(nextPage <= maxNumPages) {
            loadingItem.addClass('show filter-trigger');
            thisPortListInner.css('opacity', '0');

            $.ajax({
                type: 'POST',
                data: ajaxData,
                url: theme_global_vars.vars.ajax_url,
                success: function (data) {
                    nextPage++;
                    thisPortList.data('next-page', nextPage);
                    var response = $.parseJSON(data),
                        responseHtml = response.html;

                    thisPortList.waitForImages(function () {
                        thisPortListInner.append(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
                        var portListHasArticles = !!thisPortListInner.children().hasClass(filterClassName);

                        if(portListHasArticles) {
                            setTimeout(function() {
	                            cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
                                thisPortListInner.isotope('layout').isotope({filter: filterValue});
                                loadingItem.removeClass('show filter-trigger');

                                setTimeout(function() {
                                    thisPortListInner.css('opacity', '1');
                                    portfolioItemsAnim();
	                                cdbTheme.modules.common.parallaxInitialize();
                                }, 150);
                            }, 400);
                        } else {
                            loadingItem.removeClass('show filter-trigger');
                            loadMorePortfolioFilter(thisPortList, filterValue, filterClassName);
                        }
                    });
                }
            });
        }
    }
	
	/**
	 * Initializes portfolio pagination functions
	 */
	function portfolioPagination(){
		var portList = $('.cdb-portfolio-grid');
		
		var initStandardPagination = function(thisPortList) {
			var standardLink = thisPortList.find('.portfolio-default-pagination li');
			
			if(standardLink.length) {
				standardLink.each(function(){
					var thisLink = $(this).children('a'),
						pagedLink = 1;
					
					thisLink.on('click', function(e) {
						e.preventDefault();
						e.stopPropagation();
						
						if (typeof thisLink.data('paged') !== 'undefined' && thisLink.data('paged') !== false) {
							pagedLink = thisLink.data('paged');
						}
						
						initMainPagFunctionality(thisPortList, pagedLink);
					});
				});
			}
		};
		
		var initLoadMorePagination = function(thisPortList) {
			var loadMoreButton = thisPortList.find('.portfolio-load-more a');
			
			loadMoreButton.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				
				initMainPagFunctionality(thisPortList);
			});
		};
		
		var initInifiteScrollPagination = function(thisPortList) {
			var portListHeight = thisPortList.outerHeight(),
				portListTopOffest = thisPortList.offset().top,
				portListPosition = portListHeight + portListTopOffest - theme_global_vars.vars.cdb_admin_bar;
			
			if(!thisPortList.hasClass('portfolio-infinite-start') && cdbTheme.scroll + cdbTheme.windowHeight > portListPosition) {
				initMainPagFunctionality(thisPortList);
			}
		};
		
		var initMainPagFunctionality = function(thisPortList, pagedLink) {
			var thisPortListInner = thisPortList.find('.portfolio-wrap-inner'),
				nextPage,
				maxNumPages;
			
			if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
				maxNumPages = thisPortList.data('max-num-pages');
			}
			
			if(thisPortList.hasClass('pagination-type-standard')) {
				thisPortList.data('next-page', pagedLink);
			}
			
			if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
				thisPortList.addClass('portfolio-infinite-start');
			}
			
			var loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisPortList),
				loadingItem = thisPortList.find('.portfolio-loader');
			
			nextPage = loadMoreDatta.nextPage;
			
			if(nextPage <= maxNumPages || maxNumPages === 0){
				if(thisPortList.hasClass('pagination-type-standard')) {
					loadingItem.addClass('show standard-pagination-trigger');
					thisPortList.addClass('pagination-type-standard-animate');
				} else {
					loadingItem.addClass('show');
				}
				
				var ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'caledon_addon_portfolio_ajax_load_more');
				
				$.ajax({
					type: 'POST',
					data: ajaxData,
					url: theme_global_vars.vars.ajax_url,
					success: function (data) {
						if(!thisPortList.hasClass('pagination-type-standard')) {
							nextPage++;
						}
						
						thisPortList.data('next-page', nextPage);
						
						var response = $.parseJSON(data),
							responseHtml =  response.html;
						
						if(thisPortList.hasClass('pagination-type-standard')) {
							defaultPaginationPageSwitch(thisPortList, maxNumPages, nextPage);
							
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('portfolio-masonry')){
									isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else if (thisPortList.hasClass('portfolio-gallery') && thisPortList.hasClass('has-filters')) {
									isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
									galleryHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								}
							});
						} else {
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('portfolio-masonry')){
								    if(pagedLink === 1) {
                                        isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    } else {
                                        isotopeAddNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    }
								} else if (thisPortList.hasClass('portfolio-gallery') && thisPortList.hasClass('has-filters') && pagedLink !== 1) {
									isotopeAddNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
								    if (pagedLink === 1) {
                                        galleryHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    } else {
                                        galleryAddNewContent(thisPortListInner, loadingItem, responseHtml);
                                    }
								}
							});
						}
						
						if(thisPortList.hasClass('portfolio-infinite-start')) {
							thisPortList.removeClass('portfolio-infinite-start');
						}
					}
				});
			}
			
			if(nextPage === maxNumPages){
				thisPortList.find('.portfolio-load-more-container').hide();
			}
		};
		
		var defaultPaginationPageSwitch = function(thisPortList, maxNumPages, nextPage) {
			var standardPagHolder = thisPortList.find('.portfolio-default-pagination'),
				standardPagNumericItem = standardPagHolder.find('li.page-num'),
				standardPagPrevItem = standardPagHolder.find('li.previous-page a'),
				standardPagNextItem = standardPagHolder.find('li.next-page a');
			
			standardPagNumericItem.removeClass('active');
			standardPagNumericItem.eq(nextPage-1).addClass('active');
			
			standardPagPrevItem.data('paged', nextPage-1);
			standardPagNextItem.data('paged', nextPage+1);
			
			if(nextPage > 1) {
				standardPagPrevItem.css({'opacity': '1'});
			} else {
				standardPagPrevItem.css({'opacity': '0'});
			}
			
			if(nextPage === maxNumPages) {
				standardPagNextItem.css({'opacity': '0'});
			} else {
				standardPagNextItem.css({'opacity': '1'});
			}
		};
		
		var isotopeHtmlNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.find('article').remove();
            thisPortListInner.append(responseHtml);
			cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('show standard-pagination-trigger');
			thisPortList.removeClass('pagination-type-standard-animate');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				portfolioItemsAnim();
				cdbTheme.modules.common.parallaxInitialize();
				cdbTheme.modules.common.prettyPhotoInit();
			}, 600);
		};
		
		var galleryHtmlNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('show standard-pagination-trigger');
			thisPortList.removeClass('pagination-type-standard-animate');
			thisPortListInner.html(responseHtml);
			portfolioItemsAnim();
			cdbTheme.modules.common.parallaxInitialize();
			cdbTheme.modules.common.prettyPhotoInit();
		};
		
		var isotopeAddNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.append(responseHtml);
			cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('show');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				portfolioItemsAnim();
				cdbTheme.modules.common.parallaxInitialize();
				cdbTheme.modules.common.prettyPhotoInit();
			}, 600);
		};
		
		var galleryAddNewContent = function(thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('show');
			thisPortListInner.append(responseHtml);
			portfolioItemsAnim();
			cdbTheme.modules.common.parallaxInitialize();
			cdbTheme.modules.common.prettyPhotoInit();
		};
		
		return {
			init: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('pagination-type-standard')) {
							initStandardPagination(thisPortList);
						}
						
						if(thisPortList.hasClass('pagination-type-load-more')) {
							initLoadMorePagination(thisPortList);
						}
						
						if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
			scroll: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
            getMainPagFunction: function(thisPortList, paged) {
                initMainPagFunctionality(thisPortList, paged);
            }
		};
	}

})(jQuery);
(function($) {
    'use strict';

    var portfolioSection = {};
    cdbTheme.modules.portfolioSection = portfolioSection;

    portfolioSection.cdbThemeWindowLoad = cdbThemeWindowLoad;

    $(window).load(cdbThemeWindowLoad);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        portfolioSectionHover();
    }

    /**
     * Portfolio Section Change Background Image on Hover
     */
    function portfolioSectionHover(){
        var portfolioSections = $('.portfolio-bg-list-wrap');

        if (portfolioSections.length){
            portfolioSections.each(function () {
                var thisSection = $(this),
                    articles = thisSection.find('.portfolio-bg-list-item'),
                    articlesLink = thisSection.find('.portfolio-bg-list-link'),
                    articlesImages = thisSection.find('.portfolio-list-background-container .portfolio-list-background-inner');


                articles.eq(0).addClass('hovered');
                articlesImages.eq(0).addClass('hovered');

                //remove first click when on touch devices - go to link on second click
                if(cdbTheme.htmlEl.hasClass('touch')){
                    articlesLink.eq(0).addClass('active');

                    articlesLink.each(function () {
                        var link = $(this);

                        link.on('click', function(e){
                            if (!link.hasClass('active')) {
                                e.preventDefault();
                                articlesLink.removeClass('active');
                                link.addClass('active');
                            }

                        });
                    });
                }

                articles.each(function(e){
                    var thisArticle = $(this);

                    thisArticle.on('mouseover', function () {

                        var imageHolder = articlesImages.eq(e);

                        if (!thisArticle.hasClass('hovered')){
                            thisArticle.siblings().removeClass('hovered');
                            imageHolder.siblings().removeClass('hovered');

                            thisArticle.addClass('hovered');
                            imageHolder.addClass('hovered');
                        }
                    });
                });

            });
        }
    }

})(jQuery);


(function ($) {
    'use strict';

    var testimonialsCarousel = {};
    cdbTheme.modules.testimonialsCarousel = testimonialsCarousel;

    testimonialsCarousel.codeBeanTestimonials = codeBeanTestimonialsCarousel;


    testimonialsCarousel.cdbThemeWindowLoad = cdbThemeWindowLoad;

    $(window).load(cdbThemeWindowLoad);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        codeBeanTestimonialsCarousel();
    }

    /**
     * Init testimonials shortcode elegant type
     */
    function codeBeanTestimonialsCarousel(){
        var testimonial = $('.testimonial-wrap.testimonial-carousel');

        if(testimonial.length){
            testimonial.each(function(){
                var thisTestimonials = $(this),
                    mainTestimonialsSlider = thisTestimonials.find('.testimonial-main'),
                    imagePagSlider = thisTestimonials.children('.testimonial-photo-nav'),
                    loop = true,
                    autoplay = true,
                    sliderSpeed = 5000,
                    sliderSpeedAnimation = 600,
                    mouseDrag = false;

                if (mainTestimonialsSlider.data('enable-loop') === 'no') {
                    loop = false;
                }
                if (mainTestimonialsSlider.data('enable-autoplay') === 'no') {
                    autoplay = false;
                }
                if (typeof mainTestimonialsSlider.data('slider-speed') !== 'undefined' && mainTestimonialsSlider.data('slider-speed') !== false) {
                    sliderSpeed = mainTestimonialsSlider.data('slider-speed');
                }
                if (typeof mainTestimonialsSlider.data('slider-speed-animation') !== 'undefined' && mainTestimonialsSlider.data('slider-speed-animation') !== false) {
                    sliderSpeedAnimation = mainTestimonialsSlider.data('slider-speed-animation');
                }
                if(cdbTheme.windowWidth < 680){
                    mouseDrag = true;
                }

                if (mainTestimonialsSlider.length && imagePagSlider.length) {
                    var text = mainTestimonialsSlider.owlCarousel({
                        items: 1,
                        loop: loop,
                        autoplay: autoplay,
                        autoplayTimeout: sliderSpeed,
                        smartSpeed: sliderSpeedAnimation,
                        autoplayHoverPause: false,
                        dots: false,
                        nav: false,
                        mouseDrag: false,
                        touchDrag: mouseDrag,
						navText: [
							'<span class="carousel-prev-icon lnr lnr-arrow-left cdb-icon-element"></span>',
							'<span class="carousel-next-icon lnr lnr-arrow-right cdb-icon-element"></span>'
						],
                        onInitialize: function () {
                            mainTestimonialsSlider.css('visibility', 'visible');
                        }
                    });

                    var image = imagePagSlider.owlCarousel({
                        loop: loop,
                        autoplay: autoplay,
                        autoplayTimeout: sliderSpeed,
                        smartSpeed: sliderSpeedAnimation,
                        autoplayHoverPause: false,
                        center: true,
                        dots: false,
                        nav: false,
                        mouseDrag: false,
                        touchDrag: false,
                        responsive: {
                            1025: {
                                items: 5
                            },
                            0: {
                                items: 3
                            }
                        },
                        onInitialize: function () {
                            imagePagSlider.css('visibility', 'visible');
                            thisTestimonials.css('opacity', '1');
                        }
                    });

                    imagePagSlider.find('.owl-item').on('click touchpress', function (e) {
                        e.preventDefault();

                        var thisItem = $(this),
                            itemIndex = thisItem.index(),
                            numberOfClones = imagePagSlider.find('.owl-item.cloned').length,
                            modifiedItems = itemIndex - numberOfClones / 2 >= 0 ? itemIndex - numberOfClones / 2 : itemIndex;

                        image.trigger('to.owl.carousel', modifiedItems);
                        text.trigger('to.owl.carousel', modifiedItems);
                    });

                }
            });
        }
    }

})(jQuery);
(function($) {
    'use strict';

    var testimonialsImagePagination = {};
    cdbTheme.modules.testimonialsImagePagination = testimonialsImagePagination;

    testimonialsImagePagination.cdbThemeDocumentReady = cdbThemeDocumentReady;

    $(document).ready(cdbThemeDocumentReady);

    /* 
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        testimonialPhotoPagination();
    }

    /**
     * Init Owl Carousel
     */
    function testimonialPhotoPagination() {
        var sliders = $('.testimonial-image-pagination-inner');

        if (sliders.length) {
            sliders.each(function() {
                var slider = $(this),
                    slideItemsNumber = slider.children().length,
                    loop = true,
                    autoplay = true,
                    autoplayHoverPause = false,
                    sliderSpeed = 3500,
                    sliderSpeedAnimation = 500,
                    margin = 0,
                    stagePadding = 0,
                    center = false,
                    autoWidth = false,
                    animateInClass = false, // keyframe css animation
                    animateOutClass = false, // keyframe css animation
                    navigation = true,
                    pagination = false,
                    drag = true,
                    sliderDataHolder = slider;

                if (sliderDataHolder.data('enable-loop') === 'no') {
                    loop = false;
                }
                if (typeof sliderDataHolder.data('slider-speed') !== 'undefined' && sliderDataHolder.data('slider-speed') !== false) {
                    sliderSpeed = sliderDataHolder.data('slider-speed');
                }
                if (typeof sliderDataHolder.data('slider-speed-animation') !== 'undefined' && sliderDataHolder.data('slider-speed-animation') !== false) {
                    sliderSpeedAnimation = sliderDataHolder.data('slider-speed-animation');
                }
                if (sliderDataHolder.data('enable-auto-width') === 'yes') {
                    autoWidth = true;
                }
                if (typeof sliderDataHolder.data('slider-animate-in') !== 'undefined' && sliderDataHolder.data('slider-animate-in') !== false) {
                    animateInClass = sliderDataHolder.data('slider-animate-in');
                }
                if (typeof sliderDataHolder.data('slider-animate-out') !== 'undefined' && sliderDataHolder.data('slider-animate-out') !== false) {
                    animateOutClass = sliderDataHolder.data('slider-animate-out');
                }
                if (sliderDataHolder.data('enable-navigation') === 'no') {
                    navigation = false;
                }
                if (sliderDataHolder.data('enable-pagination') === 'yes') {
                    pagination = true;
                }

                if (navigation && pagination) {
                    slider.addClass('caledon-slider-has-both-nav');
                }

                if (pagination) {
                    var dotsContainer = '#testimonial-pagination';
                    $('.testimonial-page-item').on('click', function () {
                        slider.trigger('to.owl.carousel', [$(this).index(), 300]);
                    });
                }

                if (slideItemsNumber <= 1) {
                    loop = false;
                    autoplay = false;
                    navigation = false;
                    pagination = false;
                }

                slider.waitForImages(function () {
                    $(this).owlCarousel({
                        items: 1,
                        loop: loop,
                        autoplay: autoplay,
                        autoplayHoverPause: autoplayHoverPause,
                        autoplayTimeout: sliderSpeed,
                        smartSpeed: sliderSpeedAnimation,
                        margin: margin,
                        stagePadding: stagePadding,
                        center: center,
                        autoWidth: autoWidth,
                        animateIn: animateInClass,
                        animateOut: animateOutClass,
                        dots: pagination,
                        dotsContainer: dotsContainer,
                        nav: navigation,
                        drag: drag,
                        callbacks: true,
                        navText: [
                            '<span class="carousel-prev-icon lnr lnr-arrow-left cdb-icon-element"></span>',
                            '<span class="carousel-next-icon lnr lnr-arrow-right cdb-icon-element"></span>'
                        ],
                        onInitialize: function () {
                            slider.css('visibility', 'visible');
                        },
                        onDrag: function (e) {
                            if (cdbTheme.body.hasClass('smooth-page-shifts-fadeout')) {
                                var sliderIsMoving = e.isTrigger > 0;

                                if (sliderIsMoving) {
                                    slider.addClass('caledon-slider-is-moving');
                                }
                            }
                        },
                        onDragged: function () {
                            if (cdbTheme.body.hasClass('smooth-page-shifts-fadeout') && slider.hasClass('caledon-slider-is-moving')) {

                                setTimeout(function () {
                                    slider.removeClass('caledon-slider-is-moving');
                                }, 500);
                            }
                        }
                    });

                });
            });
        }
    }
    
})(jQuery);