<?php

if ( ! function_exists( 'caledon_addon_map_portfolio_meta' ) ) {
	function caledon_addon_map_portfolio_meta() {
		global $codebean_global_framework;
		
		$caledon_pages = array();
		$pages      = get_pages();
		foreach ( $pages as $page ) {
			$caledon_pages[ $page->ID ] = $page->post_title;
		}
		
		//Portfolio Images
		
		$caledon_portfolio_images = new CodeBeanClassMetaBox( 'portfolio-item', esc_html__( 'Portfolio Images (multiple upload)', 'caledon-addon' ), '', '', 'portfolio_images' );
		$codebean_global_framework->cdbMetaBoxes->addMetaBox( 'portfolio_images', $caledon_portfolio_images );
		
		$caledon_portfolio_image_gallery = new CodeBeanClassMultipleImages( 'portfolio-image-gallery', esc_html__( 'Portfolio Images', 'caledon-addon' ), esc_html__( 'Choose your portfolio images', 'caledon-addon' ) );
		$caledon_portfolio_images->addChild( 'portfolio-image-gallery', $caledon_portfolio_image_gallery );
		
		//Portfolio Single Upload Images/Videos 
		
		$caledon_portfolio_images_videos = codebean_create_meta_box(
			array(
				'scope' => array( 'portfolio-item' ),
				'title' => esc_html__( 'Portfolio Images/Videos (single upload)', 'caledon-addon' ),
				'name'  => 'cdb_portfolio_images_videos'
			)
		);
		codebean_add_repeater_field(
			array(
				'name'        => 'cdb_portfolio_single_upload',
				'parent'      => $caledon_portfolio_images_videos,
				'button_text' => esc_html__( 'Add Image/Video', 'caledon-addon' ),
				'fields'      => array(
					array(
						'type'        => 'select',
						'name'        => 'file_type',
						'label'       => esc_html__( 'File Type', 'caledon-addon' ),
						'options' => array(
							'image' => esc_html__('Image','caledon-addon'),
							'video' => esc_html__('Video','caledon-addon'),
						)
					),
					array(
						'type'        => 'image',
						'name'        => 'single_image',
						'label'       => esc_html__( 'Image', 'caledon-addon' ),
						'dependency' => array(
							'show' => array(
								'file_type'  => 'image'
							)
						)
					),
					array(
						'type'        => 'select',
						'name'        => 'video_type',
						'label'       => esc_html__( 'Video Type', 'caledon-addon' ),
						'options'	  => array(
							'youtube' => esc_html__('YouTube', 'caledon-addon'),
							'vimeo' => esc_html__('Vimeo', 'caledon-addon'),
							'self' => esc_html__('Self Hosted', 'caledon-addon'),
						),
						'dependency' => array(
							'show' => array(
								'file_type'  => 'video'
							)
						)
					),
					array(
						'type'        => 'text',
						'name'        => 'video_id',
						'label'       => esc_html__( 'Video ID', 'caledon-addon' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => array('youtube','vimeo')
							)
						)
					),
					array(
						'type'        => 'text',
						'name'        => 'video_mp4',
						'label'       => esc_html__( 'Video mp4', 'caledon-addon' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => 'self'
							)
						)
					),
					array(
						'type'        => 'image',
						'name'        => 'video_cover_image',
						'label'       => esc_html__( 'Video Cover Image', 'caledon-addon' ),
						'dependency' => array(
							'show' => array(
								'file_type' => 'video',
								'video_type'  => 'self'
							)
						)
					)
				)
			)
		);
		
		//Portfolio Additional Sidebar Items
		
		$caledon_additional_sidebar_items = codebean_create_meta_box(
			array(
				'scope' => array( 'portfolio-item' ),
				'title' => esc_html__( 'Additional Portfolio Sidebar Items', 'caledon-addon' ),
				'name'  => 'portfolio_properties'
			)
		);

		codebean_add_repeater_field(
			array(
				'name'        => 'cdb_portfolio_properties',
				'parent'      => $caledon_additional_sidebar_items,
				'button_text' => esc_html__( 'Add New Item', 'caledon-addon' ),
				'fields'      => array(
					array(
						'type'        => 'text',
						'name'        => 'item_title',
						'label'       => esc_html__( 'Item Title', 'caledon-addon' ),
					),
					array(
						'type'        => 'text',
						'name'        => 'item_text',
						'label'       => esc_html__( 'Item Text', 'caledon-addon' )
					),
					array(
						'type'        => 'text',
						'name'        => 'item_url',
						'label'       => esc_html__( 'Enter Full URL for Item Text Link', 'caledon-addon' )
					)
				)
			)
		);
	}
	
	add_action( 'codebean_action_meta_boxes_map', 'caledon_addon_map_portfolio_meta', 40 );
}