(function($) {
    'use strict';

    var portfolio = {};
    cdbTheme.modules.portfolio = portfolio;
	
    portfolio.cdbThemeWindowLoad = cdbThemeWindowLoad;
	
    $(window).load(cdbThemeWindowLoad);
	
	/*
	 All functions to be called on $(window).load() should be in this function
	 */
	function cdbThemeWindowLoad() {
		portfolioDetailsSticky().init();
        portfolioHoverFollowMousePointer();
	}
	
	var portfolioDetailsSticky = function () {
		var info = $('.portfolio-details-sticky .portfolio-single-content .portfolio-single-sticky-column');
		
		if (info.length) {
			var infoHolder = info.parent(),
				infoHolderOffset = infoHolder.offset().top,
				infoHolderHeight = infoHolder.height(),
				mediaHolder = $('.portfolio-single-gallery-wrap'),
				mediaHolderHeight = mediaHolder.height(),
				header = $('.header-appear, .main-fixed-header'),
				headerHeight = (header.length) ? header.height() : 0,
				constant = 30; //30 to prevent mispositioned
		}
		
		var infoHolderPosition = function () {
			if (info.length && mediaHolderHeight >= infoHolderHeight) {
				if (cdbTheme.scroll >= infoHolderOffset - headerHeight - theme_global_vars.vars.cdb_admin_bar - constant) {
					var marginTop = cdbTheme.scroll - infoHolderOffset + theme_global_vars.vars.cdb_admin_bar + headerHeight + constant;
					// if scroll is initially positioned below mediaHolderHeight
					if (marginTop + infoHolderHeight > mediaHolderHeight) {
						marginTop = mediaHolderHeight - infoHolderHeight + constant;
					}
					info.stop().css({
						top: marginTop
					});
				}
			}
		};
		
		var recalculateInfoHolderPosition = function () {
			if (info.length && mediaHolderHeight >= infoHolderHeight) {
				//Calculate header height if header appears
				if (cdbTheme.scroll > 0 && header.length) {
					headerHeight = header.height();
				}
				
				if (cdbTheme.scroll >= infoHolderOffset - headerHeight - theme_global_vars.vars.cdb_admin_bar - constant) {
					if (cdbTheme.scroll + headerHeight + theme_global_vars.vars.cdb_admin_bar + constant + infoHolderHeight < infoHolderOffset + mediaHolderHeight) {
						info.stop().css({
							top: (cdbTheme.scroll - infoHolderOffset + theme_global_vars.vars.cdb_admin_bar + headerHeight + constant)
						});
						//Reset header height
						headerHeight = 0;
					} else {
						info.stop().css({
							top: mediaHolderHeight - infoHolderHeight
						});
					}
				} else {
					info.stop().css({
						top: 0
					});
				}
			}
		};
		
		return {
			init: function () {
				infoHolderPosition();
				$(window).scroll(function () {
					recalculateInfoHolderPosition();
				});
			}
		};
	};

    function portfolioHoverFollowMousePointer() {
        var portList = $('.style-float-details');

        if (portList.length) {
            cdbTheme.body.append('<div class="portfolio-caption-float-wrap">' +
                '<div class="portfolio-caption-float">' +
                '<span class="p-caption-categories"></span>' +
                '<span class="p-caption-title">Title</span>' +
                '</div>' +
                '</div>');

            var followInfoHolder = $('.portfolio-caption-float-wrap'),
                followInfoCategory = followInfoHolder.find('.p-caption-categories'),
                followInfoTitle = followInfoHolder.find('.p-caption-title');

            portList.each(function () {
                var thisPortList = $(this);

                if(thisPortList.hasClass('portfolio-caption-dark')) {
                    followInfoHolder.addClass('portfolio-caption-dark-info');
                }

                //info element position
                thisPortList.on('mousemove', function (e) {
                    followInfoHolder.css({
                        top: e.clientY,
                        left: e.clientX
                    });
                });

                //show/hide info element
                thisPortList.find('.portfolio-item').on('mouseenter', function () {
                    var thisArticleItem = $(this),
                        thisArticleItemTitle = thisArticleItem.find('.portfolio-item-title'),
                        thisArticleItemCategories = thisArticleItem.find('.portfolio-cat');

                    if(thisArticleItemCategories.length) {
                        thisArticleItemCategories.each(function(){
                            var thisArticleItemCategory = $(this);
                            followInfoCategory.append('<span class="portfolio-caption-category">' + thisArticleItemCategory.text() + '</span>');
                        });
                    }

                    if(thisArticleItemTitle.length) {
                        followInfoTitle.text(thisArticleItemTitle.text());
                    }

                    if (!followInfoHolder.hasClass('active')) {
                        followInfoHolder.addClass('active');
                    }

                }).on('mouseleave', function () {
                    if (followInfoHolder.hasClass('active')) {
                        followInfoHolder.removeClass('active');
                    }
                    $('.portfolio-caption-category').remove();
                });

                //check if info element is below or above the targeted portfolio list
                $(window).scroll(function(){
                    if (followInfoHolder.hasClass('active')) {
                        if (followInfoHolder.offset().top < thisPortList.offset().top || followInfoHolder.offset().top > thisPortList.offset().top + thisPortList.outerHeight()) {
                            followInfoHolder.removeClass('active');
                        }
                    }
                });
            });
        }
    }

})(jQuery);