<?php

namespace CaledonAddon\CPT\Shortcodes\PortfolioCategoryList;

use CaledonAddon\Lib;

class PortfolioCategoryList implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'codebean_portfolio_category_list';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map( array(
					'name'     => esc_html__( 'Portfolio Category List', 'caledon-addon' ),
					'base'     => $this->getBase(),
					'category' => esc_html__( 'by Caledon', 'caledon-addon' ),
					'params'   => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_number_of_columns_array( true, array( 'one' ) ) ),
							'description' => esc_html__( 'Default value is Three', 'caledon-addon' ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'columns_gutter',
							'heading'     => esc_html__( 'Space Between Items', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_columns_gutter_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'number_of_items',
							'heading'     => esc_html__( 'Number of Items Per Page', 'caledon-addon' ),
							'description' => esc_html__( 'Set number of items for your portfolio category list. Default value is 6', 'caledon-addon' ),
							'value'       => '-1'
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'orderby',
							'heading'     => esc_html__( 'Order By', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_query_order_by_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'order',
							'heading'     => esc_html__( 'Order', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_query_order_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'aspect_ratio',
							'heading'     => esc_html__( 'Image Proportions', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Original', 'caledon-addon' )  => 'full',
								esc_html__( 'Square', 'caledon-addon' )    => 'square',
								esc_html__( 'Landscape', 'caledon-addon' ) => 'landscape',
								esc_html__( 'Portrait', 'caledon-addon' )  => 'portrait',
								esc_html__( 'Medium', 'caledon-addon' )    => 'medium',
								esc_html__( 'Large', 'caledon-addon' )     => 'large'
							),
							'description' => esc_html__( 'Set image proportions for your portfolio category list', 'caledon-addon' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'title_tag',
							'heading'    => esc_html__( 'Title Tag', 'caledon-addon' ),
							'value'      => array_flip( codebean_get_title_tag( true ) )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'number_of_columns'   => 'three',
			'columns_gutter' => 'normal',
			'number_of_items'     => '6',
			'orderby'             => 'date',
			'order'               => 'ASC',
			'aspect_ratio'   => 'full',
			'title_tag'           => 'h3'
		);
		$params = shortcode_atts( $args, $atts );
		
		$query_array              = $this->getQueryArray( $params );
		$params['query_results']  = get_terms( $query_array );
		$params['holder_classes'] = $this->getHolderClasses( $params, $args );
		$params['image_size']     = $this->getImageSize( $params );
		$params['title_tag']      = ! empty( $params['title_tag'] ) ? $params['title_tag'] : $args['title_tag'];
		
		$html = caledon_addon_get_cpt_shortcode_module_template_part( 'portfolio', 'portfolio-category-list', 'portfolio-category-holder', '', $params );
		
		return $html;
	}
	
	public function getQueryArray( $params ) {
		$query_array = array(
			'taxonomy'   => 'portfolio-category',
			'number'     => $params['number_of_items'],
			'orderby'    => $params['orderby'],
			'order'      => $params['order'],
			'hide_empty' => true
		);
		
		return $query_array;
	}
	
	public function getHolderClasses( $params, $args ) {
		$classes = array();
		
		$classes[] = ! empty( $params['number_of_columns'] ) ? 'cdb-' . $params['number_of_columns'] . '-cols' : 'cdb-' . $args['number_of_columns'] . '-cols';
		$classes[] = ! empty( $params['columns_gutter'] ) ? 'cdb-' . $params['columns_gutter'] . '-col-gap' : 'cdb-' . $args['columns_gutter'] . '-col-gap';
		
		return implode( ' ', $classes );
	}
	
	public function getImageSize( $params ) {
		$thumb_size = 'full';
		
		if ( ! empty( $params['aspect_ratio'] ) ) {
			$image_size = $params['aspect_ratio'];
			
			switch ( $image_size ) {
				case 'landscape':
					$thumb_size = 'caledon_landscape_size';
					break;
				case 'portrait':
					$thumb_size = 'caledon_portrait_size';
					break;
				case 'square':
					$thumb_size = 'caledon_square_size';
					break;
				case 'medium':
					$thumb_size = 'medium';
					break;
				case 'large':
					$thumb_size = 'large';
					break;
				case 'full':
					$thumb_size = 'full';
					break;
			}
		}
		
		return $thumb_size;
	}
}