(function($) {
    'use strict';

    var portfolioList = {};
    cdbTheme.modules.portfolioList = portfolioList;

    portfolioList.cdbThemeWindowLoad = cdbThemeWindowLoad;
    portfolioList.cdbThemeWindowScroll = cdbThemeWindowScroll;

    $(window).load(cdbThemeWindowLoad);
    $(window).scroll(cdbThemeWindowScroll);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        portfolioFilters();
        portfolioItemsAnim();
	    portfolioPagination().init();
    }

    /*
     All functions to be called on $(window).scroll() should be in this function
     */
    function cdbThemeWindowScroll() {
	    portfolioPagination().scroll();
    }

    /**
     * Initializes portfolio list article animation
     */
    function portfolioItemsAnim(){
        var portList = $('.cdb-portfolio-grid.with-animation');

        if(portList.length){
            portList.each(function(){
                var thisPortList = $(this).children('.portfolio-wrap-inner');

                thisPortList.children('article').each(function(l) {
                    var thisArticle = $(this);

                    thisArticle.appear(function() {
                        thisArticle.addClass('show-item');

                        setTimeout(function(){
                            thisArticle.addClass('is-visible');
                        }, 1000);
                    },{accX: 0, accY: 0});
                });
            });
        }
    }

    /**
     * Initializes portfolio masonry filter
     */
    function portfolioFilters(){
        var filterHolder = $('.cdb-portfolio-grid .portfolio-filters-wrap');

        if(filterHolder.length){
            filterHolder.each(function(){
                var thisFilterHolder = $(this),
                    thisPortListHolder = thisFilterHolder.closest('.cdb-portfolio-grid'),
                    thisPortListInner = thisPortListHolder.find('.portfolio-wrap-inner'),
                    portListHasLoadMore = thisPortListHolder.hasClass('pagination-type-load-more') ? true : false;

                thisFilterHolder.find('.p-filter:first').addClass('active');
	            
	            if(thisPortListHolder.hasClass('portfolio-gallery')) {
		            thisPortListInner.isotope();
	            }

                thisFilterHolder.find('.p-filter').on('click', function(){
                    var thisFilter = $(this),
                        filterValue = thisFilter.attr('data-filter'),
                        filterClassName = filterValue.length ? filterValue.substring(1) : '',
	                    portListHasArticles = thisPortListInner.children().hasClass(filterClassName) ? true : false;

                    thisFilter.parent().children('.p-filter').removeClass('active');
                    thisFilter.addClass('active');
	
	                if(portListHasLoadMore && !portListHasArticles && filterValue.length) {
		                loadMorePortfolioFilter(thisPortListHolder, filterValue, filterClassName);
	                } else {
		                filterValue = filterValue.length === 0 ? '*' : filterValue;
                   
                        thisFilterHolder.parent().children('.portfolio-wrap-inner').isotope({ filter: filterValue });
	                    cdbTheme.modules.common.parallaxInitialize();
                    }
                });
            });
        }
    }

    /**
     * Initializes load more items if portfolio masonry filter item is empty
     */
    function loadMorePortfolioFilter($portfolioList, $filterValue, $filterClassName) {
        var thisPortList = $portfolioList,
            thisPortListInner = thisPortList.find('.portfolio-wrap-inner'),
            filterValue = $filterValue,
            filterClassName = $filterClassName,
            maxNumPages = 0;

        if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
            maxNumPages = thisPortList.data('max-num-pages');
        }

        var	loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisPortList),
            nextPage = loadMoreDatta.nextPage,
	        ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'caledon_addon_portfolio_ajax_load_more'),
            loadingItem = thisPortList.find('.portfolio-loader');

        if(nextPage <= maxNumPages) {
            loadingItem.addClass('show filter-trigger');
            thisPortListInner.css('opacity', '0');

            $.ajax({
                type: 'POST',
                data: ajaxData,
                url: theme_global_vars.vars.ajax_url,
                success: function (data) {
                    nextPage++;
                    thisPortList.data('next-page', nextPage);
                    var response = $.parseJSON(data),
                        responseHtml = response.html;

                    thisPortList.waitForImages(function () {
                        thisPortListInner.append(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
                        var portListHasArticles = !!thisPortListInner.children().hasClass(filterClassName);

                        if(portListHasArticles) {
                            setTimeout(function() {
	                            cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
                                thisPortListInner.isotope('layout').isotope({filter: filterValue});
                                loadingItem.removeClass('show filter-trigger');

                                setTimeout(function() {
                                    thisPortListInner.css('opacity', '1');
                                    portfolioItemsAnim();
	                                cdbTheme.modules.common.parallaxInitialize();
                                }, 150);
                            }, 400);
                        } else {
                            loadingItem.removeClass('show filter-trigger');
                            loadMorePortfolioFilter(thisPortList, filterValue, filterClassName);
                        }
                    });
                }
            });
        }
    }
	
	/**
	 * Initializes portfolio pagination functions
	 */
	function portfolioPagination(){
		var portList = $('.cdb-portfolio-grid');
		
		var initStandardPagination = function(thisPortList) {
			var standardLink = thisPortList.find('.portfolio-default-pagination li');
			
			if(standardLink.length) {
				standardLink.each(function(){
					var thisLink = $(this).children('a'),
						pagedLink = 1;
					
					thisLink.on('click', function(e) {
						e.preventDefault();
						e.stopPropagation();
						
						if (typeof thisLink.data('paged') !== 'undefined' && thisLink.data('paged') !== false) {
							pagedLink = thisLink.data('paged');
						}
						
						initMainPagFunctionality(thisPortList, pagedLink);
					});
				});
			}
		};
		
		var initLoadMorePagination = function(thisPortList) {
			var loadMoreButton = thisPortList.find('.portfolio-load-more a');
			
			loadMoreButton.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				
				initMainPagFunctionality(thisPortList);
			});
		};
		
		var initInifiteScrollPagination = function(thisPortList) {
			var portListHeight = thisPortList.outerHeight(),
				portListTopOffest = thisPortList.offset().top,
				portListPosition = portListHeight + portListTopOffest - theme_global_vars.vars.cdb_admin_bar;
			
			if(!thisPortList.hasClass('portfolio-infinite-start') && cdbTheme.scroll + cdbTheme.windowHeight > portListPosition) {
				initMainPagFunctionality(thisPortList);
			}
		};
		
		var initMainPagFunctionality = function(thisPortList, pagedLink) {
			var thisPortListInner = thisPortList.find('.portfolio-wrap-inner'),
				nextPage,
				maxNumPages;
			
			if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
				maxNumPages = thisPortList.data('max-num-pages');
			}
			
			if(thisPortList.hasClass('pagination-type-standard')) {
				thisPortList.data('next-page', pagedLink);
			}
			
			if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
				thisPortList.addClass('portfolio-infinite-start');
			}
			
			var loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisPortList),
				loadingItem = thisPortList.find('.portfolio-loader');
			
			nextPage = loadMoreDatta.nextPage;
			
			if(nextPage <= maxNumPages || maxNumPages === 0){
				if(thisPortList.hasClass('pagination-type-standard')) {
					loadingItem.addClass('show standard-pagination-trigger');
					thisPortList.addClass('pagination-type-standard-animate');
				} else {
					loadingItem.addClass('show');
				}
				
				var ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'caledon_addon_portfolio_ajax_load_more');
				
				$.ajax({
					type: 'POST',
					data: ajaxData,
					url: theme_global_vars.vars.ajax_url,
					success: function (data) {
						if(!thisPortList.hasClass('pagination-type-standard')) {
							nextPage++;
						}
						
						thisPortList.data('next-page', nextPage);
						
						var response = $.parseJSON(data),
							responseHtml =  response.html;
						
						if(thisPortList.hasClass('pagination-type-standard')) {
							defaultPaginationPageSwitch(thisPortList, maxNumPages, nextPage);
							
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('portfolio-masonry')){
									isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else if (thisPortList.hasClass('portfolio-gallery') && thisPortList.hasClass('has-filters')) {
									isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
									galleryHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								}
							});
						} else {
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('portfolio-masonry')){
								    if(pagedLink === 1) {
                                        isotopeHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    } else {
                                        isotopeAddNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    }
								} else if (thisPortList.hasClass('portfolio-gallery') && thisPortList.hasClass('has-filters') && pagedLink !== 1) {
									isotopeAddNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
								    if (pagedLink === 1) {
                                        galleryHtmlNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    } else {
                                        galleryAddNewContent(thisPortListInner, loadingItem, responseHtml);
                                    }
								}
							});
						}
						
						if(thisPortList.hasClass('portfolio-infinite-start')) {
							thisPortList.removeClass('portfolio-infinite-start');
						}
					}
				});
			}
			
			if(nextPage === maxNumPages){
				thisPortList.find('.portfolio-load-more-container').hide();
			}
		};
		
		var defaultPaginationPageSwitch = function(thisPortList, maxNumPages, nextPage) {
			var standardPagHolder = thisPortList.find('.portfolio-default-pagination'),
				standardPagNumericItem = standardPagHolder.find('li.page-num'),
				standardPagPrevItem = standardPagHolder.find('li.previous-page a'),
				standardPagNextItem = standardPagHolder.find('li.next-page a');
			
			standardPagNumericItem.removeClass('active');
			standardPagNumericItem.eq(nextPage-1).addClass('active');
			
			standardPagPrevItem.data('paged', nextPage-1);
			standardPagNextItem.data('paged', nextPage+1);
			
			if(nextPage > 1) {
				standardPagPrevItem.css({'opacity': '1'});
			} else {
				standardPagPrevItem.css({'opacity': '0'});
			}
			
			if(nextPage === maxNumPages) {
				standardPagNextItem.css({'opacity': '0'});
			} else {
				standardPagNextItem.css({'opacity': '1'});
			}
		};
		
		var isotopeHtmlNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.find('article').remove();
            thisPortListInner.append(responseHtml);
			cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('show standard-pagination-trigger');
			thisPortList.removeClass('pagination-type-standard-animate');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				portfolioItemsAnim();
				cdbTheme.modules.common.parallaxInitialize();
				cdbTheme.modules.common.prettyPhotoInit();
			}, 600);
		};
		
		var galleryHtmlNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('show standard-pagination-trigger');
			thisPortList.removeClass('pagination-type-standard-animate');
			thisPortListInner.html(responseHtml);
			portfolioItemsAnim();
			cdbTheme.modules.common.parallaxInitialize();
			cdbTheme.modules.common.prettyPhotoInit();
		};
		
		var isotopeAddNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.append(responseHtml);
			cdbTheme.modules.common.setFixedImageProportionSize(thisPortList, thisPortListInner.find('article'), thisPortListInner.find('.masonry-grid-sizer').width());
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('show');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				portfolioItemsAnim();
				cdbTheme.modules.common.parallaxInitialize();
				cdbTheme.modules.common.prettyPhotoInit();
			}, 600);
		};
		
		var galleryAddNewContent = function(thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('show');
			thisPortListInner.append(responseHtml);
			portfolioItemsAnim();
			cdbTheme.modules.common.parallaxInitialize();
			cdbTheme.modules.common.prettyPhotoInit();
		};
		
		return {
			init: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('pagination-type-standard')) {
							initStandardPagination(thisPortList);
						}
						
						if(thisPortList.hasClass('pagination-type-load-more')) {
							initLoadMorePagination(thisPortList);
						}
						
						if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
			scroll: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('pagination-type-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
            getMainPagFunction: function(thisPortList, paged) {
                initMainPagFunctionality(thisPortList, paged);
            }
		};
	}

})(jQuery);