<?php

namespace CaledonAddon\CPT\Shortcodes\Portfolio;

use CaledonAddon\Lib;

class PortfolioList implements Lib\ShortcodeInterface
{
    private $base;

    public function __construct() {
        $this->base = 'codebean_portfolio_list';

        add_action('vc_before_init', array($this, 'vcMap'));

        //Portfolio category filter
        add_filter('vc_autocomplete_codebean_portfolio_list_category_callback', array(&$this, 'portfolioCategoryAutocompleteSuggester',), 10, 1); // Get suggestion(find). Must return an array

        //Portfolio category render
        add_filter('vc_autocomplete_codebean_portfolio_list_category_render', array(&$this, 'portfolioCategoryAutocompleteRender',), 10, 1); // Get suggestion(find). Must return an array

        //Portfolio selected projects filter
        add_filter('vc_autocomplete_codebean_portfolio_list_selected_projects_callback', array(&$this, 'portfolioIdAutocompleteSuggester',), 10, 1); // Get suggestion(find). Must return an array

        //Portfolio selected projects render
        add_filter('vc_autocomplete_codebean_portfolio_list_selected_projects_render', array(&$this, 'portfolioIdAutocompleteRender',), 10, 1); // Render exact portfolio. Must return an array (label,value)

	    //Portfolio tag filter
	    add_filter( 'vc_autocomplete_codebean_portfolio_list_tag_callback', array( &$this, 'portfolioTagAutocompleteSuggester', ), 10, 1 ); // Get suggestion(find). Must return an array

	    //Portfolio tag render
	    add_filter( 'vc_autocomplete_codebean_portfolio_list_tag_render', array( &$this, 'portfolioTagAutocompleteRender', ), 10, 1 ); // Get suggestion(find). Must return an array
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        if (function_exists('vc_map')) {
            vc_map(array(
                    'name'     => esc_html__('Portfolio List', 'caledon-addon'),
                    'base'     => $this->getBase(),
                    'category' => esc_html__('by Caledon', 'caledon-addon'),
                    'params'   => array(
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'type',
                            'heading'     => esc_html__('Portfolio List Template', 'caledon-addon'),
                            'value'       => array(
                                esc_html__('Gallery', 'caledon-addon') => 'gallery',
                                esc_html__('Masonry', 'caledon-addon') => 'masonry'
                            ),
                            'save_always' => true,
                            'admin_label' => true
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'item_type',
                            'heading'    => esc_html__('Click Behavior', 'caledon-addon'),
                            'value'      => array(
                                esc_html__('Open portfolio single page on click', 'caledon-addon')   => '',
                                esc_html__('Open gallery in Pretty Photo on click', 'caledon-addon') => 'gallery'
                            )
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'number_of_columns',
                            'heading'     => esc_html__('Number of Columns', 'caledon-addon'),
                            'value'       => array_flip(codebean_get_number_of_columns_array(true)),
                            'description' => esc_html__('Default value is Three', 'caledon-addon'),
                            'save_always' => true
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'columns_gutter',
                            'heading'     => esc_html__('Space Between Items', 'caledon-addon'),
                            'value'       => array_flip(codebean_get_columns_gutter_array()),
                            'save_always' => true
                        ),
                        array(
                            'type'        => 'textfield',
                            'param_name'  => 'number_of_items',
                            'heading'     => esc_html__('Number of Portfolios Per Page', 'caledon-addon'),
                            'description' => esc_html__('Set number of items for your portfolio list. Enter -1 to show all.', 'caledon-addon'),
                            'value'       => '-1'
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'aspect_ratio',
                            'heading'     => esc_html__('Image Proportions', 'caledon-addon'),
                            'value'       => array(
                                esc_html__('Original', 'caledon-addon')  => 'full',
                                esc_html__('Square', 'caledon-addon')    => 'square',
                                esc_html__('Landscape', 'caledon-addon') => 'landscape',
                                esc_html__('Portrait', 'caledon-addon')  => 'portrait',
                                esc_html__('Medium', 'caledon-addon')    => 'medium',
                                esc_html__('Large', 'caledon-addon')     => 'large'
                            ),
                            'description' => esc_html__('Set image proportions for your portfolio list.', 'caledon-addon'),
                            'dependency'  => array('element' => 'type', 'value' => array('gallery'))
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'constrained_image_aspect_ratio',
                            'heading'     => esc_html__('Enable Fixed Image Proportions', 'caledon-addon'),
                            'value'       => array_flip(codebean_get_yes_no_select_array(false)),
                            'description' => esc_html__('Set predefined image proportions for your masonry portfolio list. This option will apply image proportions you set in Portfolio Single page - dimensions for masonry option.', 'caledon-addon'),
                            'dependency'  => array('element' => 'type', 'value' => array('masonry'))
                        ),
                        array(
                            'type'        => 'autocomplete',
                            'param_name'  => 'category',
                            'heading'     => esc_html__('One-Category Portfolio List', 'caledon-addon'),
                            'description' => esc_html__('Enter one category slug (leave empty for showing all categories)', 'caledon-addon')
                        ),
                        array(
                            'type'        => 'autocomplete',
                            'param_name'  => 'selected_projects',
                            'heading'     => esc_html__('Show Only Projects with Listed IDs', 'caledon-addon'),
                            'settings'    => array(
                                'multiple'      => true,
                                'sortable'      => true,
                                'unique_values' => true
                            ),
                            'description' => esc_html__('Delimit ID numbers by comma (leave empty for all)', 'caledon-addon')
                        ),
                        array(
                            'type'        => 'autocomplete',
                            'param_name'  => 'tag',
                            'heading'     => esc_html__('One-Tag Portfolio List', 'caledon-addon'),
                            'description' => esc_html__('Enter one tag slug (leave empty for showing all tags)', 'caledon-addon')
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'orderby',
                            'heading'     => esc_html__('Order By', 'caledon-addon'),
                            'value'       => array_flip(codebean_get_query_order_by_array()),
                            'save_always' => true
                        ),
                        array(
                            'type'        => 'dropdown',
                            'param_name'  => 'order',
                            'heading'     => esc_html__('Order', 'caledon-addon'),
                            'value'       => array_flip(codebean_get_query_order_array()),
                            'save_always' => true
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'item_style',
                            'heading'    => esc_html__('Item Style', 'caledon-addon'),
                            'value'      => array(
                                esc_html__('Standard - Shader', 'caledon-addon')                 => 'portfolio-default',
                                esc_html__('Gallery - Overlay', 'caledon-addon')                 => 'details-on-hover',
                                esc_html__('Gallery - Slide From Image Bottom', 'caledon-addon') => 'details-bottom',
	                            esc_html__('Gallery - Text Float', 'caledon-addon')              => 'float-details'
                            ),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'textfield',
                            'param_name' => 'content_top_margin',
                            'heading'    => esc_html__('Content Top Margin (px or %)', 'caledon-addon'),
                            'dependency' => array('element' => 'item_style', 'value' => array('portfolio-default')),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'textfield',
                            'param_name' => 'content_bottom_margin',
                            'heading'    => esc_html__('Content Bottom Margin (px or %)', 'caledon-addon'),
                            'dependency' => array('element' => 'item_style', 'value' => array('portfolio-default')),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'title_active',
                            'heading'    => esc_html__('Enable Title', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_yes_no_select_array(false, true)),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'title_tag',
                            'heading'    => esc_html__('Title Tag', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_title_tag(true)),
                            'dependency' => array('element' => 'title_active', 'value' => array('yes')),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'title_text_transform',
                            'heading'    => esc_html__('Title Text Transform', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_text_transform_array(true)),
                            'dependency' => array('element' => 'title_active', 'value' => array('yes')),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'category_active',
                            'heading'    => esc_html__('Enable Category', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_yes_no_select_array(false, true)),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'excerpt_active',
                            'heading'    => esc_html__('Enable Excerpt', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_yes_no_select_array(false)),
                            'group'      => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'        => 'textfield',
                            'param_name'  => 'excerpt_size',
                            'heading'     => esc_html__('Excerpt Length', 'caledon-addon'),
                            'description' => esc_html__('Number of characters', 'caledon-addon'),
                            'dependency'  => array('element' => 'excerpt_active', 'value' => array('yes')),
                            'group'       => esc_html__('Content Layout', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'pagination_type',
                            'heading'    => esc_html__('Pagination Type', 'caledon-addon'),
                            'value'      => array(
                                esc_html__('None', 'caledon-addon')            => 'no-pagination',
                                esc_html__('Standard', 'caledon-addon')        => 'standard',
                                esc_html__('Load More', 'caledon-addon')       => 'load-more',
                                esc_html__('Infinite Scroll', 'caledon-addon') => 'infinite-scroll'
                            ),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'textfield',
                            'param_name' => 'load_more_top_margin',
                            'heading'    => esc_html__('Load More Top Margin (px or %)', 'caledon-addon'),
                            'dependency' => array('element' => 'pagination_type', 'value' => array('load-more')),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'filter',
                            'heading'    => esc_html__('Enable Category Filter', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_yes_no_select_array(false)),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'filter_order_by',
                            'heading'    => esc_html__('Filter Order By', 'caledon-addon'),
                            'value'      => array(
                                esc_html__('Name', 'caledon-addon')  => 'name',
                                esc_html__('Count', 'caledon-addon') => 'count',
                                esc_html__('Id', 'caledon-addon')    => 'id',
                                esc_html__('Slug', 'caledon-addon')  => 'slug'
                            ),
                            'dependency' => array('element' => 'filter', 'value' => array('yes')),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'dropdown',
                            'param_name' => 'filter_text_transform',
                            'heading'    => esc_html__('Filter Text Transform', 'caledon-addon'),
                            'value'      => array_flip(codebean_get_text_transform_array(true)),
                            'dependency' => array('element' => 'filter', 'value' => array('yes')),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                        array(
                            'type'       => 'textfield',
                            'param_name' => 'filter_bottom_margin',
                            'heading'    => esc_html__('Filter Bottom Margin (px or %)', 'caledon-addon'),
                            'dependency' => array('element' => 'filter', 'value' => array('yes')),
                            'group'      => esc_html__('Additional Features', 'caledon-addon')
                        ),
                    )
                )
            );
        }
    }

    public function render($atts, $content = null) {
        $args = array(
            'type'                     => 'gallery',
            'item_type'                => '',
            'number_of_columns'        => 'three',
            'columns_gutter'      => 'normal',
            'number_of_items'          => '-1',
            'aspect_ratio'        => 'full',
            'constrained_image_aspect_ratio' => 'no',
            'category'                 => '',
            'selected_projects'        => '',
            'tag'                      => '',
            'orderby'                  => 'date',
            'order'                    => 'ASC',
            'item_style'               => 'portfolio-default',
            'content_top_margin'       => '',
            'content_bottom_margin'    => '',
            'title_active'             => 'yes',
            'title_tag'                => 'h4',
            'title_text_transform'     => '',
            'category_active'          => 'yes',
            'excerpt_active'           => 'no',
            'excerpt_size'           => '20',
            'pagination_type'          => 'no-pagination',
            'load_more_top_margin'     => '',
            'filter'                   => 'no',
            'filter_order_by'          => 'name',
            'filter_text_transform'    => '',
            'filter_bottom_margin'     => '',
            'portfolio_slider_on'      => 'no',
        );
        $params = shortcode_atts($args, $atts);

        /***
         * @params query_results
         * @params holder_data
         * @params holder_classes
         * @params holder_inner_classes
         */
        $additional_params = array();

        $query_array = $this->getQueryArray($params);
        $query_results = new \WP_Query($query_array);
        $additional_params['query_results'] = $query_results;

        $additional_params['holder_data'] = codebean_get_holder_data_for_cpt($params, $additional_params);
        $additional_params['holder_classes'] = $this->getHolderClasses($params, $args);
	    $additional_params['holder_inner_classes'] = $this->getHolderInnerClasses($params);

        $params['this_object'] = $this;

        $html = caledon_addon_get_cpt_shortcode_module_template_part('portfolio', 'portfolio-list', 'portfolio-holder', $params['type'], $params, $additional_params);

        return $html;
    }

    public function getQueryArray($params) {
        $query_array = array(
            'post_status'    => 'publish',
            'post_type'      => 'portfolio-item',
            'posts_per_page' => $params['number_of_items'],
            'orderby'        => $params['orderby'],
            'order'          => $params['order']
        );

        if (!empty($params['category'])) {
            $query_array['portfolio-category'] = $params['category'];
        }

        $project_ids = null;
        if (!empty($params['selected_projects'])) {
            $project_ids = explode(',', $params['selected_projects']);
            $query_array['post__in'] = $project_ids;
        }

        if (!empty($params['tag'])) {
            $query_array['portfolio-tag'] = $params['tag'];
        }

        if (!empty($params['next_page'])) {
            $query_array['paged'] = $params['next_page'];
        } else {
            $query_array['paged'] = 1;
        }

        return $query_array;
    }

    public function getHolderClasses($params, $args) {
        $classes = array();

        $classes[] = !empty($params['type']) ? 'portfolio-' . $params['type'] : 'portfolio-' . $args['type'];
        $classes[] = !empty($params['number_of_columns']) ? 'cdb-' . $params['number_of_columns'] . '-cols' : 'cdb-' . $args['number_of_columns'] . '-cols';
        $classes[] = !empty($params['columns_gutter']) ? 'cdb-' . $params['columns_gutter'] . '-col-gap' : 'cdb-' . $args['columns_gutter'] . '-col-gap';
        $classes[] = !empty($params['item_style']) ? 'style-' . $params['item_style'] : '';
        $classes[] = $params['constrained_image_aspect_ratio'] === 'yes' ? 'masonry-constrained' : '';
        $classes[] = $params['title_active'] === 'no' && $params['category_active'] === 'no' && $params['excerpt_active'] === 'no' ? 'portfolio-item-no-excerpt' : '';
        $classes[] = !empty($params['pagination_type']) ? 'pagination-type-' . $params['pagination_type'] : '';
        $classes[] = $params['filter'] === 'yes' ? 'has-filters' : '';
        $classes[] = !empty($params['navigation_skin']) ? 'navigation-scheme-' . $params['navigation_skin'] : '';
        $classes[] = !empty($params['pagination_skin']) ? 'pagination-scheme-' . $params['pagination_skin'] : '';

        return implode(' ', $classes);
    }

	public function getHolderInnerClasses($params) {
		$classes = array();

		$classes[] = $params['portfolio_slider_on'] === 'yes' ? 'cdb-owl-carousel items-on-carousel' : '';

		return implode(' ', $classes);
	}

    public function getArticleClasses($params) {
        $classes = array();

        $type = $params['type'];
        $item_style = $params['item_style'];

        $image_proportion = $params['constrained_image_aspect_ratio'] === 'yes' ? 'fixed' : 'original';
        $masonry_size = get_post_meta(get_the_ID(), 'cdb_portfolio_masonry_' . $image_proportion . '_dimensions_meta', true);

        $classes[] = !empty($masonry_size) && $type === 'masonry' ? 'masonry-ratio-' . esc_attr($masonry_size) : '';

        $article_classes = get_post_class($classes);

        return implode(' ', $article_classes);
    }

    public function getImageSize($params) {
        $thumb_size = 'full';

        if (!empty($params['aspect_ratio']) && $params['type'] == 'gallery') {
            $image_size = $params['aspect_ratio'];

            switch ($image_size) {
                case 'landscape':
                    $thumb_size = 'caledon_landscape_size';
                    break;
                case 'portrait':
                    $thumb_size = 'caledon_portrait_size';
                    break;
                case 'square':
                    $thumb_size = 'caledon_square_size';
                    break;
                case 'medium':
                    $thumb_size = 'medium';
                    break;
                case 'large':
                    $thumb_size = 'large';
                    break;
                case 'full':
                    $thumb_size = 'full';
                    break;
            }
        }

        if ($params['type'] == 'masonry' && $params['constrained_image_aspect_ratio'] === 'yes') {
            $fixed_image_size = get_post_meta(get_the_ID(), 'cdb_portfolio_masonry_fixed_dimensions_meta', true);

            switch ($fixed_image_size) {
                case 'small' :
                    $thumb_size = 'caledon_square_size';
                    break;
                case 'large-width':
                    $thumb_size = 'caledon_landscape_size';
                    break;
                case 'large-height':
                    $thumb_size = 'caledon_portrait_size';
                    break;
                case 'large-width-height':
                    $thumb_size = 'caledon_large_size';
                    break;
                default :
                    $thumb_size = 'full';
                    break;
            }
        }

        return $thumb_size;
    }

    public function getStandardContentStyles($params) {
        $styles = array();

        $margin_top = isset($params['content_top_margin']) ? $params['content_top_margin'] : '';
        $margin_bottom = isset($params['content_bottom_margin']) ? $params['content_bottom_margin'] : '';

        if (!empty($margin_top)) {
            if (codebean_string_ends_with($margin_top, '%') || codebean_string_ends_with($margin_top, 'px')) {
                $styles[] = 'margin-top: ' . $margin_top;
            } else {
                $styles[] = 'margin-top: ' . codebean_filter_px($margin_top) . 'px';
            }
        }

        if (!empty($margin_bottom)) {
            if (codebean_string_ends_with($margin_bottom, '%') || codebean_string_ends_with($margin_bottom, 'px')) {
                $styles[] = 'margin-bottom: ' . $margin_bottom;
            } else {
                $styles[] = 'margin-bottom: ' . codebean_filter_px($margin_bottom) . 'px';
            }
        }

        return implode(';', $styles);
    }

    public function getTitleStyles($params) {
        $styles = array();

        if (!empty($params['title_text_transform'])) {
            $styles[] = 'text-transform: ' . $params['title_text_transform'];
        }

        return implode(';', $styles);
    }

    public function getLoadMoreStyles($params) {
        $styles = array();

        if (!empty($params['load_more_top_margin'])) {
            $margin = $params['load_more_top_margin'];

            if (codebean_string_ends_with($margin, '%') || codebean_string_ends_with($margin, 'px')) {
                $styles[] = 'margin-top: ' . $margin;
            } else {
                $styles[] = 'margin-top: ' . codebean_filter_px($margin) . 'px';
            }
        }

        return implode(';', $styles);
    }

    public function getFilterCategories($params) {
        $cat_id = 0;

        if (!empty($params['category'])) {
            $top_category = get_term_by('slug', $params['category'], 'portfolio-category');

            if (isset($top_category->term_id)) {
                $cat_id = $top_category->term_id;
            }
        }

        $order = $params['filter_order_by'] === 'count' ? 'DESC' : 'ASC';

        $args = array(
            'taxonomy' => 'portfolio-category',
            'child_of' => $cat_id,
            'orderby'  => $params['filter_order_by'],
            'order'    => $order
        );

        $filter_categories = get_terms($args);

        return $filter_categories;
    }

    public function getFilterHolderStyles($params) {
        $styles = array();

        if (!empty($params['filter_bottom_margin'])) {
            $margin = $params['filter_bottom_margin'];

            if (codebean_string_ends_with($margin, '%') || codebean_string_ends_with($margin, 'px')) {
                $styles[] = 'margin-bottom: ' . $margin;
            } else {
                $styles[] = 'margin-bottom: ' . codebean_filter_px($margin) . 'px';
            }
        }

        return implode(';', $styles);
    }

    public function getFilterStyles($params) {
        $styles = array();

        if (!empty($params['filter_text_transform'])) {
            $styles[] = 'text-transform: ' . $params['filter_text_transform'];
        }

        return implode(';', $styles);
    }

    public function getItemLink() {
        $portfolio_link_meta = get_post_meta(get_the_ID(), 'portfolio_external_link', true);
        $portfolio_link = !empty($portfolio_link_meta) ? $portfolio_link_meta : get_permalink(get_the_ID());

        return apply_filters('codebean_filter_portfolio_external_link', $portfolio_link);
    }

    public function getItemLinkTarget() {
        $portfolio_link_meta = get_post_meta(get_the_ID(), 'portfolio_external_link', true);
        $portfolio_link_target = !empty($portfolio_link_meta) ? '_blank' : '_self';

        return apply_filters('codebean_filter_portfolio_external_link_target', $portfolio_link_target);
    }

    /**
     * Filter portfolio categories
     *
     * @param $query
     *
     * @return array
     */
    public function portfolioCategoryAutocompleteSuggester($query) {
        global $wpdb;
        $post_meta_infos = $wpdb->get_results($wpdb->prepare("SELECT a.slug AS slug, a.name AS portfolio_category_title
					FROM {$wpdb->terms} AS a
					LEFT JOIN ( SELECT term_id, taxonomy  FROM {$wpdb->term_taxonomy} ) AS b ON b.term_id = a.term_id
					WHERE b.taxonomy = 'portfolio-category' AND a.name LIKE '%%%s%%'", stripslashes($query)), ARRAY_A);

        $results = array();
        if (is_array($post_meta_infos) && !empty($post_meta_infos)) {
            foreach ($post_meta_infos as $value) {
                $data = array();
                $data['value'] = $value['slug'];
                $data['label'] = ((strlen($value['portfolio_category_title']) > 0) ? esc_html__('Category', 'caledon-addon') . ': ' . $value['portfolio_category_title'] : '');
                $results[] = $data;
            }
        }

        return $results;
    }

    /**
     * Find portfolio category by slug
     * @since 4.4
     *
     * @param $query
     *
     * @return bool|array
     */
    public function portfolioCategoryAutocompleteRender($query) {
        $query = trim($query['value']); // get value from requested
        if (!empty($query)) {
            // get portfolio category
            $portfolio_category = get_term_by('slug', $query, 'portfolio-category');
            if (is_object($portfolio_category)) {

                $portfolio_category_slug = $portfolio_category->slug;
                $portfolio_category_title = $portfolio_category->name;

                $portfolio_category_title_display = '';
                if (!empty($portfolio_category_title)) {
                    $portfolio_category_title_display = esc_html__('Category', 'caledon-addon') . ': ' . $portfolio_category_title;
                }

                $data = array();
                $data['value'] = $portfolio_category_slug;
                $data['label'] = $portfolio_category_title_display;

                return !empty($data) ? $data : false;
            }

            return false;
        }

        return false;
    }

    /**
     * Filter portfolios by ID or Title
     *
     * @param $query
     *
     * @return array
     */
    public function portfolioIdAutocompleteSuggester($query) {
        global $wpdb;
        $portfolio_id = (int)$query;
        $post_meta_infos = $wpdb->get_results($wpdb->prepare("SELECT ID AS id, post_title AS title
					FROM {$wpdb->posts} 
					WHERE post_type = 'portfolio-item' AND ( ID = '%d' OR post_title LIKE '%%%s%%' )", $portfolio_id > 0 ? $portfolio_id : -1, stripslashes($query), stripslashes($query)), ARRAY_A);

        $results = array();
        if (is_array($post_meta_infos) && !empty($post_meta_infos)) {
            foreach ($post_meta_infos as $value) {
                $data = array();
                $data['value'] = $value['id'];
                $data['label'] = esc_html__('Id', 'caledon-addon') . ': ' . $value['id'] . ((strlen($value['title']) > 0) ? ' - ' . esc_html__('Title', 'caledon-addon') . ': ' . $value['title'] : '');
                $results[] = $data;
            }
        }

        return $results;
    }

    /**
     * Find portfolio by id
     * @since 4.4
     *
     * @param $query
     *
     * @return bool|array
     */
    public function portfolioIdAutocompleteRender($query) {
        $query = trim($query['value']); // get value from requested
        if (!empty($query)) {
            // get portfolio
            $portfolio = get_post((int)$query);
            if (!is_wp_error($portfolio)) {

                $portfolio_id = $portfolio->ID;
                $portfolio_title = $portfolio->post_title;

                $portfolio_title_display = '';
                if (!empty($portfolio_title)) {
                    $portfolio_title_display = ' - ' . esc_html__('Title', 'caledon-addon') . ': ' . $portfolio_title;
                }

                $portfolio_id_display = esc_html__('Id', 'caledon-addon') . ': ' . $portfolio_id;

                $data = array();
                $data['value'] = $portfolio_id;
                $data['label'] = $portfolio_id_display . $portfolio_title_display;

                return !empty($data) ? $data : false;
            }

            return false;
        }

        return false;
    }

	/**
	 * Filter portfolio tags
	 *
	 * @param $query
	 *
	 * @return array
	 */
	public function portfolioTagAutocompleteSuggester( $query ) {
		global $wpdb;
		$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT a.slug AS slug, a.name AS portfolio_tag_title
					FROM {$wpdb->terms} AS a
					LEFT JOIN ( SELECT term_id, taxonomy  FROM {$wpdb->term_taxonomy} ) AS b ON b.term_id = a.term_id
					WHERE b.taxonomy = 'portfolio-tag' AND a.name LIKE '%%%s%%'", stripslashes( $query ) ), ARRAY_A );

		$results = array();
		if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
			foreach ( $post_meta_infos as $value ) {
				$data          = array();
				$data['value'] = $value['slug'];
				$data['label'] = ( ( strlen( $value['portfolio_tag_title'] ) > 0 ) ? esc_html__( 'Tag', 'caledon-addon' ) . ': ' . $value['portfolio_tag_title'] : '' );
				$results[]     = $data;
			}
		}

		return $results;
	}

	/**
	 * Find portfolio tag by slug
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function portfolioTagAutocompleteRender( $query ) {
		$query = trim( $query['value'] ); // get value from requested
		if ( ! empty( $query ) ) {
			// get portfolio category
			$portfolio_tag = get_term_by( 'slug', $query, 'portfolio-tag' );
			if ( is_object( $portfolio_tag ) ) {

				$portfolio_tag_slug  = $portfolio_tag->slug;
				$portfolio_tag_title = $portfolio_tag->name;

				$portfolio_tag_title_display = '';
				if ( ! empty( $portfolio_tag_title ) ) {
					$portfolio_tag_title_display = esc_html__( 'Tag', 'caledon-addon' ) . ': ' . $portfolio_tag_title;
				}

				$data          = array();
				$data['value'] = $portfolio_tag_slug;
				$data['label'] = $portfolio_tag_title_display;

				return ! empty( $data ) ? $data : false;
			}

			return false;
		}

		return false;
	}
}