<?php
namespace CaledonAddon\CPT\Shortcodes\AnimationHolder;

use CaledonAddon\Lib;

class AnimationHolder implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'codebean_animation_holder';
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                    => esc_html__( 'Animation Holder', 'caledon-addon' ),
					'base'                    => $this->base,
					"as_parent"               => array( 'except' => 'vc_row' ),
					'content_element'         => true,
					'category'                => esc_html__( 'by Caledon', 'caledon-addon' ),
					'show_settings_on_create' => true,
					'js_view'                 => 'VcColumnView',
					'params'                  => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'animation',
							'heading'     => esc_html__( 'Animation Type', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Element Grow In', 'caledon-addon' )          => 'zoomIn',
								esc_html__( 'Element Fade In Down', 'caledon-addon' )     => 'fadeInDown',
								esc_html__( 'Element From Fade', 'caledon-addon' )        => 'fadeIn',
								esc_html__( 'Element From Left', 'caledon-addon' )        => 'fadeInLeft',
								esc_html__( 'Element From Right', 'caledon-addon' )       => 'fadeInRight',
								esc_html__( 'Element From Top', 'caledon-addon' )         => 'fadeInUp',
								esc_html__( 'Element From Bottom', 'caledon-addon' )      => 'fadeInDown',
								esc_html__( 'Element Flip In', 'caledon-addon' )          => 'flipIn',
								esc_html__( 'Element X Rotate', 'caledon-addon' )         => 'rotateX',
								esc_html__( 'Element Z Rotate', 'caledon-addon' )         => 'rotateZ',
								esc_html__( 'Element Y Translate', 'caledon-addon' )      => 'translateY',
								esc_html__( 'Element Fade In X Rotate', 'caledon-addon' ) => 'leftRotateX',
							),
							'save_always' => true
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'animation_delay',
							'heading'    => esc_html__( 'Animation Delay (ms)', 'caledon-addon' )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args = array(
			'animation'       => '',
			'animation_delay' => ''
		);
		extract( shortcode_atts( $args, $atts ) );
		
		$html = '<div class="element-animate ' . esc_attr( $animation ) . '" data-animation-type="' . esc_attr( $animation ) . '" data-animation-delay="' . esc_attr( $animation_delay ) . '">' . do_shortcode( $content ) . '</div>';
		
		return $html;
	}
}