<?php
namespace CaledonAddon\CPT\Shortcodes\ClientsGrid;

use CaledonAddon\Lib;

class ClientsGrid implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'codebean_clients_grid';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if(function_exists('vc_map')) {
			vc_map(
				array(
					'name'      => esc_html__( 'Clients Grid', 'caledon-addon' ),
					'base'      => $this->base,
					'category'  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'as_parent' => array( 'only' => 'codebean_clients_carousel_item' ),
					'js_view'   => 'VcColumnView',
					'params'    => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_number_of_columns_array( true ) ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'columns_gutter',
							'heading'     => esc_html__( 'Space Between Items', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_columns_gutter_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'image_alignment',
							'heading'     => esc_html__( 'Items Horizontal Alignment', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Default Center', 'caledon-addon' ) => '',
								esc_html__( 'Left', 'caledon-addon' )           => 'left',
								esc_html__( 'Right', 'caledon-addon' )          => 'right'
							),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'items_hover_animation',
							'heading'     => esc_html__( 'Items Hover Animation', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Switch Images', 'caledon-addon' ) => 'style1',
								esc_html__( 'Roll Over', 'caledon-addon' )     => 'style2'
							),
							'save_always' => true
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'number_of_columns'     => 'three',
			'columns_gutter'   => 'normal',
			'image_alignment'       => '',
			'items_hover_animation' => 'style1'
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['holder_classes'] = $this->getHolderClasses( $params, $args );
		$params['content']        = $content;
		
		$html = caledon_addon_get_shortcode_module_template_part( 'templates/clients-grid', 'clients-grid', '', $params );
		
		return $html;
	}

	private function getHolderClasses( $params, $args ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['number_of_columns'] ) ? 'cdb-' . $params['number_of_columns'] . '-cols' : 'cdb-' . $args['number_of_columns'] . '-cols';
		$holderClasses[] = ! empty( $params['columns_gutter'] ) ? 'cdb-' . $params['columns_gutter'] . '-col-gap' : 'cdb-' . $args['columns_gutter'] . '-col-gap';
		$holderClasses[] = ! empty( $params['image_alignment'] ) ? 'align--' . $params['image_alignment'] : '';
		$holderClasses[] = ! empty( $params['items_hover_animation'] ) ? 'hover-' . $params['items_hover_animation'] : 'hover-' . $args['items_hover_animation'];
		
		return implode( ' ', $holderClasses );
	}
}
