<?php
namespace CaledonAddon\CPT\Shortcodes\Countdown;

use CaledonAddon\Lib;

class Countdown implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'codebean_countdown';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Countdown', 'caledon-addon' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'custom_class',
							'heading'     => esc_html__( 'Custom CSS Class', 'caledon-addon' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'caledon-addon' )
						),
						array(
							'type'				=> 'codebean_timepicker',
							'heading'           => esc_html__( 'Target time for countdown', 'caledon-addon' ),
							'param_name'		=> 'datetime',
							'admin_label'		=> true,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'skin',
							'heading'    => esc_html__( 'Skin', 'caledon-addon' ),
							'value'      => array(
								esc_html__( 'Default', 'caledon-addon' ) => '',
								esc_html__( 'Light', 'caledon-addon' )   => 'color-scheme-light',
							),
							'save_always' => true
						),
						array(
							'type'				=> 'dropdown',
							'heading'			=> esc_html__('Countdown alignment', 'caledon-addon'),
							'param_name'		=> 'count_alignment',
							'value' 			=> array(
								esc_html__('Left', 'caledon-addon')	=> 'text-align-left',
								esc_html__('Center', 'caledon-addon')	=> 'text-align-center',
								esc_html__('Right', 'caledon-addon')	=> 'text-align-right',
							),
						),
						array(
							'type'				=> 'checkbox',
							'heading'			=> esc_html__('Select time units to display in countdown timer', 'caledon-addon'),
							'param_name'		=> 'countdown_opts',
							'value'				=> array(
								esc_html__('Years','caledon-addon')	=> 'syear',
								esc_html__('Months','caledon-addon')	=> 'smonth',
								esc_html__('Days','caledon-addon')	=> 'sday',
								esc_html__('Hours','caledon-addon')	=> 'shr',
								esc_html__('Minutes','caledon-addon') => 'smin',
								esc_html__('Seconds','caledon-addon') => 'ssec',
							),
						),
						array(
							'type'				=> 'textfield',
							'heading'			=> esc_html__('Delimeter value. : or /', 'caledon-addon'),
							'param_name'		=> 'delimeter_val',
							'value'				=> ':',
						),

					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'custom_class'    => '',
			'datetime'        => '',
			'skin'            => '',
			'count_alignment' => 'text-left',
			'countdown_opts'  => array('syear', 'smonth', 'sday'),
			'delimeter_val'   => ':'
		);
		$params = shortcode_atts( $args, $atts );

		$params['markup_html']    = $this->getCountdownOptsArray($params);
		$params['id']             = uniqid();
		$params['holder_classes'] = $this->getHolderClasses( $params );
		$params['holder_data']    = $this->getHolderData( $params );
		
		$html = caledon_addon_get_shortcode_module_template_part( 'templates/countdown', 'countdown', '', $params );
		
		return $html;
	}

	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = ! empty( $params['count_alignment'] ) ? $params['count_alignment'] : '';
		$holderClasses[] = ! empty( $params['skin'] ) ? $params['skin'] : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getCountdownOptsArray($params) {
		$count_frmt = $dot_html = '';

		if ( ! empty( $params['delimeter_val'] ) ) {
			$dot_html .= '<span class="separator">'. $params['delimeter_val'] .'</span>';
		}

		$countdown_opts    = explode( ',', $params['countdown_opts'] );

		if ( in_array( 'syear', $countdown_opts ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-Y</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Years', 'caledon-addon').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		}

		if( ( in_array( 'smonth', $countdown_opts ) ) && ( in_array( 'syear', $countdown_opts ) ) ) {
			if ( in_array( 'smonth', $countdown_opts ) ) {
				$count_frmt .= '<div class="countdown-timer">';
					$count_frmt .= '<span class="time-number"><span>%-z</span></span>';
					$count_frmt .= '<span class="time-label">'.esc_html__('Months', 'caledon-addon').'</span>';
				$count_frmt .= '</div>';
				$count_frmt .= $dot_html;
			}
		} elseif ( ( in_array( 'smonth', $countdown_opts ) ) && ( ! in_array( 'syear', $countdown_opts ) ) ) {
			if ( in_array( 'smonth', $countdown_opts ) ) {
				$count_frmt .= '<div class="countdown-timer">';
					$count_frmt .= '<span class="time-number"><span>%-m</span></span>';
					$count_frmt .= '<span class="time-label">'.esc_html__('Months', 'caledon-addon').'</span>';
				$count_frmt .= '</div>';
				$count_frmt .= $dot_html;
			}
		}

		if ( ( in_array( 'sday', $countdown_opts ) ) && ( in_array( 'smonth', $countdown_opts ) ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-n</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Days', 'caledon-addon').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		} elseif( ( in_array( 'sday', $countdown_opts ) ) && ( ! in_array( 'smonth', $countdown_opts ) ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-D</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Days', 'caledon-addon').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		}

		if ( in_array( 'shr', $countdown_opts ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-H</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Hours', 'dfd-native').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		}

		if ( in_array( 'smin', $countdown_opts ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-M</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Minutes', 'dfd-native').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		}

		if ( in_array( 'ssec', $countdown_opts ) ) {
			$count_frmt .= '<div class="countdown-timer">';
				$count_frmt .= '<span class="time-number"><span>%-S</span></span>';
				$count_frmt .= '<span class="time-label">'.esc_html__('Seconds', 'dfd-native').'</span>';
			$count_frmt .= '</div>';
			$count_frmt .= $dot_html;
		}

		return $count_frmt;
	}
	
	private function getHolderData( $params ) {
		$holderData = array();

		$datetime = str_replace("/", ".", $params['datetime']);
		$unix_number = strtotime($datetime);
		$echo_date = date("Y/m/d H:i:s", $unix_number);
		
		$holderData['data-date']         = ! empty( $echo_date ) ? $echo_date : '';
		$holderData['data-finish-text']  = esc_html__( 'Event already pass', 'caledon-addon' );
		return $holderData;
	}
}