(function($) {
    'use strict';

    var fullscreenCarousel = {};
    cdbTheme.modules.fullscreenCarousel = fullscreenCarousel;

    fullscreenCarousel.fullScreenCarousel = fullScreenCarousel;

    fullscreenCarousel.cdbThemeDocumentReady = cdbThemeDocumentReady;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        fullScreenCarousel();
    }

    /**
     * Init Fullscreen Carousel shortcode
     */
    function fullScreenCarousel() {
        var fullscreenCarousels = $('.fullscreen-carousel-wrap');

        if (fullscreenCarousels.length) {
            fullscreenCarousels.each(function(){
                var fullscreenCarousel = $(this),
                    items = fullscreenCarousel.find('.carousel-item'),
                    images = fullscreenCarousel.find('.carousel-background'),
                    nextTrigger = fullscreenCarousel.find('.carousel-next-trigger'),
                    mouseXBuffer;

                //fullscreen calcs
                var fullscreenCalcs = function() {
                    var heightVal = cdbTheme.windowHeight - fullscreenCarousel.offset().top;

                    if (cdbTheme.body.hasClass('site-borders-on')) {
                        var passepartoutSize = parseInt($('.site-wrapper').css('padding-top'));

                        heightVal -= passepartoutSize;
                    }

                    fullscreenCarousel.css('height', heightVal);
                }

                //item classes setup
                var prepItems = function() {
                    items.first().addClass('active').find('> div').css('transition','none');
                    fullscreenCarousel.css('visibility','visible');
                    setTimeout(function(){
                        items.filter('.active').next().addClass('next-item');
                    }, 200);
                }

                //slideshow logic start
                var startAnimating = function() {
                    fullscreenCarousel.addClass('is-loading');
                }

                var endAnimating = function() {
                    updateNav();

                    items.filter('.active').one(cdbTheme.transitionEnd,function(){
                        fullscreenCarousel.removeClass('is-loading');
                    });
                }

                var changeItem = function() {
                    startAnimating(); //before change

                    var nextIndex;

                    //loop
                    if (items.filter('.active').data('index') < items.length) {
                        nextIndex = items.filter('.active').next().data('index') - 1;
                    } else {
                        nextIndex = 0;
                    }

                    items.find('> div').removeAttr('style');
                    items.removeClass('previous-item');
                    items.filter('.active').addClass('previous-item');
                    items.removeClass('active next-item');
                    items.eq(nextIndex).addClass('active');
                    if (nextIndex < items.length - 1) {
                        items.filter('.active').next().addClass('next-item');
                    } else {
                        items.first().addClass('next-item');
                    }

                    endAnimating(); //after change
                }
                //slideshow logic end

                //change on click
                var slideshowTrigger = function() {
                    nextTrigger.on('click', function(e){
                        if (!fullscreenCarousel.hasClass('is-loading')) {
                            changeItem();         
                        }           
                    });

                    nextTrigger.on('mouseenter', function(){
                        fullscreenCarousel.addClass('hovered');
                    }).on('mouseleave', function(){
                        fullscreenCarousel.removeClass('hovered');
                    });
                }

                //change on scroll
                var slideshowScroll = function() {
                    if (fullscreenCarousel.hasClass('slide-on-scroll') && !cdbTheme.htmlEl.hasClass('touch')) {
                        var delta = 0;

                        fullscreenCarousel.mousewheel(function(e) {
                            e.preventDefault();

                            if (!fullscreenCarousel.hasClass('is-loading')) {
                                if (e.deltaY < 0) {
                                    delta = -1;
                                } else {
                                    delta = 1;
                                }

                                if (delta == -1 ) {
                                    changeItem();
                                }
                            }
                        });

                        fullscreenCarousel.on('wheel', function() { return false; });
                    }
                }

                //update indicators
                var updateNav = function() {
                    if (fullscreenCarousel.hasClass('indicators-active')) {
                        var bullets = fullscreenCarousel.find('.carousel-indicator'),
                            activeIndex = items.filter('.active').data('index') - 1;

                        bullets.removeClass('active');
                        bullets.eq(activeIndex).addClass('active');
                    }
                }

                //init
                fullscreenCarousel.waitForImages(function(){
                    fullscreenCalcs();
                    prepItems();
                    slideshowTrigger();
                    slideshowScroll();
                    updateNav();
                });

                $(window).resize(function(){
                    fullscreenCalcs();
                });
            });
        }
    }
})(jQuery);
