<?php
namespace CaledonAddon\CPT\Shortcodes\IconWithText;

use CaledonAddon\Lib;

class IconWithText implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'codebean_icon_with_text';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Icon With Text', 'caledon-addon' ),
					'base'                      => $this->base,
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array_merge(
						array(
							array(
								'type'        => 'textfield',
								'param_name'  => 'custom_padding',
								'heading'     => esc_html__( 'Custom CSS Padding', 'caledon-addon' ),
								'description' => esc_html__( 'Add custom padding to IWT element', 'caledon-addon' )
							),
							array(
								'type'        => 'textfield',
								'param_name'  => 'custom_class',
								'heading'     => esc_html__( 'Custom CSS Class', 'caledon-addon' ),
								'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'caledon-addon' )
							),
							array(
								'type'        => 'dropdown',
								'param_name'  => 'type',
								'heading'     => esc_html__( 'Type', 'caledon-addon' ),
								'value'       => array(
									esc_html__( 'Icon Left From Text', 'caledon-addon' )              => 'icon-left',
									esc_html__( 'Icon Left From Title', 'caledon-addon' )             => 'icon-left-from-title',
									esc_html__( 'Icon Top', 'caledon-addon' )                         => 'icon-top'
								),
								'save_always' => true
							),
						),
						codebean_icon_collections()->getVCParamsArray(),
						array(
							array(
								'type'       => 'attach_image',
								'param_name' => 'custom_icon',
								'heading'    => esc_html__( 'Custom Icon', 'caledon-addon' )
							),
							array(
								'type'       => 'attach_image',
								'param_name' => 'custom_hover_icon',
								'heading'    => esc_html__( 'Custom Hover Icon', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'custom_icon',
									'not_empty' => true ),
									),
							array(
								'type'       => 'dropdown',
								'param_name' => 'icon_type',
								'heading'    => esc_html__( 'Icon Type', 'caledon-addon' ),
								'value'      => array(
									esc_html__( 'Normal', 'caledon-addon' ) => 'default-style',
									esc_html__( 'Circle', 'caledon-addon' ) => 'circle-style',
									esc_html__( 'Square', 'caledon-addon' ) => 'square-style'
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'dropdown',
								'param_name' => 'icon_size',
								'heading'    => esc_html__( 'Icon Size', 'caledon-addon' ),
								'value'      => array(
									esc_html__( 'Medium', 'caledon-addon' )     => 'cdb-icon-medium',
									esc_html__( 'Tiny', 'caledon-addon' )       => 'cdb-icon-tiny',
									esc_html__( 'Small', 'caledon-addon' )      => 'cdb-icon-small',
									esc_html__( 'Large', 'caledon-addon' )      => 'cdb-icon-large',
									esc_html__( 'Very Large', 'caledon-addon' ) => 'cdb-icon-huge'
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'custom_icon_size',
								'heading'    => esc_html__( 'Custom Icon Size (px)', 'caledon-addon' ),
								'description'=> esc_html__( 'Enter image size in pixels: 200x100 (Width x Height). Default size is 118px.', 'caledon-addon' ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'shape_size',
								'heading'    => esc_html__( 'Shape Size (px)', 'caledon-addon' ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_color',
								'heading'    => esc_html__( 'Icon Color', 'caledon-addon' ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_hover_color',
								'heading'    => esc_html__( 'Icon Hover Color', 'caledon-addon' ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_background_color',
								'heading'    => esc_html__( 'Icon Background Color', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'icon_type',
									'value'   => array( 'square-style', 'circle-style' )
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_hover_background_color',
								'heading'    => esc_html__( 'Icon Hover Background Color', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'icon_type',
									'value'   => array( 'square-style', 'circle-style' )
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_border_color',
								'heading'    => esc_html__( 'Icon Border Color', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'icon_type',
									'value'   => array( 'square-style', 'circle-style' )
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'icon_border_hover_color',
								'heading'    => esc_html__( 'Icon Border Hover Color', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'icon_type',
									'value'   => array( 'square-style', 'circle-style' )
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'icon_border_width',
								'heading'    => esc_html__( 'Border Width (px)', 'caledon-addon' ),
								'dependency' => array(
									'element' => 'icon_type',
									'value'   => array( 'square-style', 'circle-style' )
								),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'dropdown',
								'param_name' => 'icon_animation',
								'heading'    => esc_html__( 'Icon Animation', 'caledon-addon' ),
								'value'      => array_flip( codebean_get_yes_no_select_array( false ) ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'icon_animation_delay',
								'heading'    => esc_html__( 'Icon Animation Delay (ms)', 'caledon-addon' ),
								'dependency' => array( 'element' => 'icon_animation', 'value' => array( 'yes' ) ),
								'group'      => esc_html__( 'Icon Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'title',
								'heading'    => esc_html__( 'Title', 'caledon-addon' )
							),
							array(
								'type'        => 'dropdown',
								'param_name'  => 'title_tag',
								'heading'     => esc_html__( 'Title Tag', 'caledon-addon' ),
								'value'       => array_flip( codebean_get_title_tag( true ) ),
								'save_always' => true,
								'dependency'  => array( 'element' => 'title', 'not_empty' => true ),
								'group'       => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'title_color',
								'heading'    => esc_html__( 'Title Color', 'caledon-addon' ),
								'dependency' => array( 'element' => 'title', 'not_empty' => true ),
								'group'      => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'title_top_margin',
								'heading'    => esc_html__( 'Title Top Margin (px)', 'caledon-addon' ),
								'dependency' => array( 'element' => 'title', 'not_empty' => true ),
								'group'      => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textarea',
								'param_name' => 'text',
								'heading'    => esc_html__( 'Text', 'caledon-addon' )
							),
							array(
								'type'       => 'colorpicker',
								'param_name' => 'text_color',
								'heading'    => esc_html__( 'Text Color', 'caledon-addon' ),
								'dependency' => array( 'element' => 'text', 'not_empty' => true ),
								'group'      => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'       => 'textfield',
								'param_name' => 'text_top_margin',
								'heading'    => esc_html__( 'Text Top Margin (px)', 'caledon-addon' ),
								'dependency' => array( 'element' => 'text', 'not_empty' => true ),
								'group'      => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'        => 'textfield',
								'param_name'  => 'link',
								'heading'     => esc_html__( 'Link', 'caledon-addon' ),
								'description' => esc_html__( 'Set link around icon and title', 'caledon-addon' )
							),
							array(
								'type'       => 'dropdown',
								'param_name' => 'target',
								'heading'    => esc_html__( 'Target', 'caledon-addon' ),
								'value'      => array_flip( codebean_get_link_target_array() ),
								'dependency' => array( 'element' => 'link', 'not_empty' => true ),
							),
							array(
								'type'        => 'textfield',
								'param_name'  => 'text_padding',
								'heading'     => esc_html__( 'Text Top/Left Padding (px)', 'caledon-addon' ),
								'description' => esc_html__( 'Set left or top padding dependence of type for your text holder. Default value is 13 for left type and 25 for top icon with text type', 'caledon-addon' ),
								'dependency'  => array( 'element' => 'type', 'value'   => array( 'icon-left', 'icon-top' ) ),
								'group'       => esc_html__( 'Text Settings', 'caledon-addon' )
							),
							array(
								'type'        => 'textfield',
								'param_name'  => 'text_bottom_padding',
								'heading'     => esc_html__( 'Text Bottom Padding (px)', 'caledon-addon' ),
								'description' => esc_html__( 'Set bottom padding. Default value is 0.', 'caledon-addon' ),
								'dependency'  => array( 'element' => 'type', 'value'   => array( 'icon-left', 'icon-top' ) ),
								'group'       => esc_html__( 'Text Settings', 'caledon-addon' )
							),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'regular_shadow',
                                'heading'    => esc_html__( 'Shadow', 'caledon-addon' ),
                                'value'      => array(
                                    esc_html__( 'No', 'caledon-addon' ) => '',
                                    esc_html__( 'Yes', 'caledon-addon' ) => 'small',
                                ),
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'hover_shadow',
                                'heading'    => esc_html__( 'Hover Shadow', 'caledon-addon' ),
                                'value'      => array(
                                    esc_html__( 'Yes', 'caledon-addon' ) => '',
                                    esc_html__( 'No', 'caledon-addon' ) => 'no-shadow',
                                ),
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'hover_effect',
                                'heading'    => esc_html__( 'Additional Hover Effect', 'caledon-addon' ),
                                'value'      => array(
                                    esc_html__( 'Yes', 'caledon-addon' ) => '',
                                    esc_html__( 'No', 'caledon-addon' ) => 'hover-off',
                                ),
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'border',
                                'heading'    => esc_html__( 'Border', 'caledon-addon' ),
                                'value'      => array(
                                    esc_html__( 'No', 'caledon-addon' ) => '',
                                    esc_html__( 'Yes', 'caledon-addon' ) => 'bordered',
                                ),
                            )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$default_atts = array(
			'custom_padding'              => '',
			'custom_class'                => '',
			'type'                        => 'icon-left',
			'custom_icon'                 => '',
			'custom_hover_icon'           => '',
			'icon_type'                   => 'normal-style',
			'icon_size'                   => 'cdb-icon-medium',
			'custom_icon_size'            => '',
			'shape_size'                  => '',
			'icon_color'                  => '',
			'icon_hover_color'            => '',
			'icon_background_color'       => '',
			'icon_hover_background_color' => '',
			'icon_border_color'           => '',
			'icon_border_hover_color'     => '',
			'icon_border_width'           => '',
			'icon_animation'              => '',
			'icon_animation_delay'        => '',
			'title'                       => '',
			'title_tag'                   => 'h4',
			'title_color'                 => '',
			'title_top_margin'            => '',
			'text'                        => '',
			'text_color'                  => '',
			'text_top_margin'             => '',
            'text_alignment'              => '',
            'show_arrow'                  => '',
            'regular_shadow'              => '',
            'hover_shadow'                => '',
			'hover_effect'                => '',
			'border'                      => '',
			'link'                        => '',
			'target'                      => '_self',
			'text_padding'                => '',
			'text_bottom_padding'         => ''
		);
		$default_atts = array_merge( $default_atts, codebean_icon_collections()->getShortcodeParams() );
		$params       = shortcode_atts( $default_atts, $atts );
		
		$params['type'] = ! empty( $params['type'] ) ? $params['type'] : $default_atts['type'];
		
		$params['icon_parameters'] = $this->getIconParameters( $params );
		$params['inner_holder_classes']  = $this->getInnerHolderClasses( $params );
		$params['content_styles']  = $this->getContentStyles( $params );
		$params['title_styles']    = $this->getTitleStyles( $params );
		$params['padding_styles']  = $this->getPaddingStyles( $params );
		$params['title_tag']       = ! empty( $params['title_tag'] ) ? $params['title_tag'] : $default_atts['title_tag'];
		$params['text_styles']     = $this->getTextStyles( $params );
		$params['target']          = ! empty( $params['target'] ) ? $params['target'] : $default_atts['target'];
		
		return caledon_addon_get_shortcode_module_template_part( 'templates/iwt', 'icon-with-text', $params['type'], $params );
	}
	
	private function getIconParameters( $params ) {
		$params_array = array();
		
		if ( empty( $params['custom_icon'] ) ) {
			$iconPackName = codebean_icon_collections()->getIconCollectionParamNameByKey( $params['icon_pack'] );
			
			$params_array['icon_pack']     = $params['icon_pack'];
			$params_array[ $iconPackName ] = $params[ $iconPackName ];
			
			if ( ! empty( $params['icon_size'] ) ) {
				$params_array['size'] = $params['icon_size'];
			}
			
			if ( ! empty( $params['custom_icon_size'] ) ) {
				$params_array['custom_size'] = codebean_filter_px( $params['custom_icon_size'] ) . 'px';
			}
			
			if ( ! empty( $params['icon_type'] ) ) {
				$params_array['type'] = $params['icon_type'];
			}
			
			if ( ! empty( $params['shape_size'] ) ) {
				$params_array['shape_size'] = codebean_filter_px( $params['shape_size'] ) . 'px';
			}
			
			if ( ! empty( $params['icon_border_color'] ) ) {
				$params_array['border_color'] = $params['icon_border_color'];
			}
			
			if ( ! empty( $params['icon_border_hover_color'] ) ) {
				$params_array['hover_border_color'] = $params['icon_border_hover_color'];
			}
			
			if ( $params['icon_border_width'] !== '' ) {
				$params_array['border_width'] = codebean_filter_px( $params['icon_border_width'] ) . 'px';
			}
			
			if ( ! empty( $params['icon_background_color'] ) ) {
				$params_array['background_color'] = $params['icon_background_color'];
			}
			
			if ( ! empty( $params['icon_hover_background_color'] ) ) {
				$params_array['hover_background_color'] = $params['icon_hover_background_color'];
			}
			
			$params_array['icon_color'] = $params['icon_color'];
			
			if ( ! empty( $params['icon_hover_color'] ) ) {
				$params_array['hover_icon_color'] = $params['icon_hover_color'];
			}
			
			$params_array['icon_animation']       = $params['icon_animation'];
			$params_array['icon_animation_delay'] = $params['icon_animation_delay'];
		}
		
		return $params_array;
	}
	
	private function getInnerHolderClasses( $params ) {
		$holderClasses = array( 'iconbox-inner' );
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = ! empty( $params['type'] ) ? $params['type'] : '';
        $holderClasses[] = ! empty( $params['regular_shadow'] ) ? $params['regular_shadow'] : '';
        $holderClasses[] = ! empty( $params['hover_shadow'] ) ? $params['hover_shadow'] : '';
        $holderClasses[] = ! empty( $params['hover_effect'] ) ? 'iconbox-' . $params['hover_effect'] : '';
        $holderClasses[] = ! empty( $params['border'] ) ? $params['border'] : '';
		$holderClasses[] = ! empty( $params['icon_size'] ) ? 'iconbox-' . str_replace( 'cdb-', '', $params['icon_size'] ) : '';
		
		return $holderClasses;
	}
	
	private function getContentStyles( $params ) {
		$styles = array();
		
		if ( $params['text_padding'] !== '' && $params['type'] === 'icon-left' ) {
			$styles[] = 'padding-left: ' . codebean_filter_px( $params['text_padding'] ) . 'px';
		}
		
		if ( $params['text_padding'] !== '' && $params['type'] === 'icon-top' ) {
			$styles[] = 'padding-top: ' . codebean_filter_px( $params['text_padding'] ) . 'px';
		}

		if ( $params['text_bottom_padding'] !== '') {
			$styles[] = 'padding-bottom: ' . codebean_filter_px( $params['text_bottom_padding'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}
	
	private function getTitleStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['title_color'] ) ) {
			$styles[] = 'color: ' . $params['title_color'];
		}
		
		if ( $params['title_top_margin'] !== '' ) {
			$styles[] = 'margin-top: ' . codebean_filter_px( $params['title_top_margin'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}
	
	private function getTextStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['text_color'] ) ) {
			$styles[] = 'color: ' . $params['text_color'];
		}
		
		if ( $params['text_top_margin'] !== '' ) {
			$styles[] = 'margin-top: ' . codebean_filter_px( $params['text_top_margin'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}

	private function getPaddingStyles( $params ) {
		$styles = array();

		if ( ! empty( $params['custom_padding'] ) ) {
			$styles[] = 'padding: ' . $params['custom_padding'];
		}

		return implode( ';', $styles );
	}
}