<?php

namespace CaledonAddon\CPT\Shortcodes\TripleFrameImageHighlight;

use CaledonAddon\Lib;

class TripleFrameImageHighlight implements Lib\ShortcodeInterface
{
    private $base;

    function __construct() {
        $this->base = 'codebean_image_frame_slider';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        if (function_exists('vc_map')) {
            vc_map(array(
                'name'     => esc_html__('Image Frame Slider', 'caledon-addon'),
                'base'     => $this->base,
                'category' => esc_html__('by Caledon', 'caledon-addon'),
                'params'   => array(
                    array(
                        'type'       => 'attach_image',
                        'param_name' => 'centered_image',
                        'heading'    => esc_html__('Centered Image', 'caledon-addon')
                    ),
                    array(
                        'type'       => 'textfield',
                        'param_name' => 'centered_image_link',
                        'heading'    => esc_html__('Centered Image Link', 'caledon-addon')
                    ),
                    array(
                        'type'       => 'attach_image',
                        'param_name' => 'left_image',
                        'heading'    => esc_html__('Left Image', 'caledon-addon')
                    ),
                    array(
                        'type'       => 'textfield',
                        'param_name' => 'left_image_link',
                        'heading'    => esc_html__('Left Image Link', 'caledon-addon')
                    ),
                    array(
                        'type'       => 'attach_image',
                        'param_name' => 'right_image',
                        'heading'    => esc_html__('Right Image', 'caledon-addon')
                    ),
                    array(
                        'type'       => 'textfield',
                        'param_name' => 'right_image_link',
                        'heading'    => esc_html__('Right Image Link', 'caledon-addon')
                    ),
                    array(
                        'type'        => 'dropdown',
                        'param_name'  => 'enable_navigation',
                        'heading'     => esc_html__( 'Enable Navigation', 'caledon-addon' ),
                        'value'       => array_flip( codebean_get_yes_no_select_array( false ) ),
                        'admin_label' => true
                    ),
                    array(
                        'type'        => 'dropdown',
                        'param_name'  => 'link_target',
                        'heading'     => esc_html__( 'Link Target', 'caledon-addon' ),
                        'value'       => array_flip( codebean_get_link_target_array() ),
                        'save_always' => true
                    )
                )
            ));
        }
    }

    public function render($atts, $content = null) {
        $args = array(
            'centered_image'    => '',
            'centered_image_link'     => '',
            'left_image'    => '',
            'left_image_link'   => '',
            'right_image'   => '',
            'right_image_link'  => '',
            'link_target'    => '',
            'enable_navigation' => 'no',
        );
        $params = shortcode_atts($args, $atts);

        $params['holder_classes'] = $this->getHolderClasses( $params );

        $html = caledon_addon_get_shortcode_module_template_part('templates/image-frame-slider-template', 'image-frame-slider', '', $params);

        return $html;
    }

    private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = !empty($params['layout']) ? 'frame-slider-'.$params['layout'] : '';
		$holderClasses[] = ($params['enable_navigation'] == 'yes') ? 'frame-slider-has-navigation' : '';
		
		return implode( ' ', $holderClasses );
    }

	
}