<?php
namespace CaledonAddon\CPT\Shortcodes\PricingTable;

use CaledonAddon\Lib;

class PricingTable implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'codebean_pricing_table';
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                    => esc_html__( 'Pricing Table', 'caledon-addon' ),
					'base'                    => $this->base,
					'as_parent'               => array( 'only' => 'codebean_pricing_table_item' ),
					'content_element'         => true,
					'category'                => esc_html__( 'by Caledon', 'caledon-addon' ),
					'show_settings_on_create' => true,
					'js_view'                 => 'VcColumnView',
					'params'                  => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_number_of_columns_array( true, array('five', 'six') ) ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'columns_gutter',
							'heading'     => esc_html__( 'Space Between Items', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_columns_gutter_array() ),
							'save_always' => true
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'number_of_columns'   => 'three',
			'columns_gutter' => 'normal'
		);
		$params = shortcode_atts( $args, $atts );
		
		$holder_class = $this->getHolderClasses( $params, $args );
		
		$html = '<div class="pricing-blocks-wrapper container-list  clearfix ' . esc_attr( $holder_class ) . '">';
			$html .= '<div class="fix-col-gap clearfix">';
				$html .= do_shortcode( $content );
			$html .= '</div>';
		$html .= '</div>';
		
		return $html;
	}
	
	private function getHolderClasses( $params, $args ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['number_of_columns'] ) ? 'cdb-' . $params['number_of_columns'] . '-cols' : 'cdb-' . $args['number_of_columns'] . '-cols';
		$holderClasses[] = ! empty( $params['columns_gutter'] ) ? 'cdb-' . $params['columns_gutter'] . '-col-gap' : 'cdb-' . $args['columns_gutter'] . '-col-gap';
		
		return implode( ' ', $holderClasses );
	}
}