<?php
namespace CaledonAddon\CPT\Shortcodes\SocialShare;

use CaledonAddon\Lib;

class SocialShare implements Lib\ShortcodeInterface {
	private $base;
	private $socialNetworks;
	
	function __construct() {
		$this->base           = 'codebean_social_share';
		$this->socialNetworks = array(
			'twitter',
			'facebook',
			'google_plus',
			'linkedin',
			'tumblr',
			'pinterest',
			'vk'
		);
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function getSocialNetworks() {
		return $this->socialNetworks;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Social Share', 'caledon-addon' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'       => 'dropdown',
							'param_name' => 'type',
							'heading'    => esc_html__( 'Type', 'caledon-addon' ),
							'value'      => array(
								esc_html__( 'List', 'caledon-addon' )     => 'list',
								esc_html__( 'Dropdown', 'caledon-addon' ) => 'dropdown',
								esc_html__( 'Text', 'caledon-addon' )     => 'text'
							)
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'icon_type',
							'heading'    => esc_html__( 'Icons Type', 'caledon-addon' ),
							'value'      => array(
								esc_html__( 'Font Awesome', 'caledon-addon' ) => 'font-awesome',
								esc_html__( 'Font Elegant', 'caledon-addon' ) => 'font-elegant'
							),
							'dependency' => array( 'element' => 'type', 'value' => array( 'list', 'dropdown' ) )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'title',
							'heading'    => esc_html__( 'Social Share Title', 'caledon-addon' ),
							'dependency' => array( 'element' => 'type', 'value' => array( 'list', 'text' ) )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'type'      => 'list',
			'icon_type' => 'font-elegant',
			'title'     => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		//Is social share enabled
		$params['enable_social_share'] = ( codebean_options()->getOptionValue( 'enable_social_share' ) == 'yes' ) ? true : false;
		
		//Is social share enabled for post type
		$post_type         = get_post_type();
		$params['enabled'] = ( codebean_options()->getOptionValue( 'enable_social_share_on_' . $post_type ) == 'yes' ) ? true : false;
		
		//Social Networks Data
		$params['networks'] = $this->getSocialNetworksParams( $params );
		
		$html = '';
		
		if ( $params['enable_social_share'] ) {
			if ( $params['enabled'] ) {
				$html .= caledon_addon_get_shortcode_module_template_part( 'templates/' . $params['type'], 'social-share', '', $params );
			}
		}
		
		return $html;
	}

    /**
     * Get Social Networks data to display
     * @return array
     */
	private function getSocialNetworksParams( $params ) {
		$networks   = array();
		$icons_type = $params['icon_type'];
		$type       = $params['type'];
		
		foreach ( $this->socialNetworks as $net ) {
			$html = '';
			
			if ( codebean_options()->getOptionValue( 'enable_' . $net . '_share' ) == 'yes' ) {
				$image                 = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
				$params                = array(
					'name' => $net,
					'type' => $type
				);

				$params['link']        = $this->getSocialNetworkShareLink( $net, $image );

				if ($type == 'text') {
					$params['text']    = $this->getSocialNetworkText( $net );
				} else {
					$params['icon']    = $this->getSocialNetworkIcon( $net, $icons_type );
				}

				$params['custom_icon'] = ( codebean_options()->getOptionValue( $net . '_icon' ) ) ? codebean_options()->getOptionValue( $net . '_icon' ) : '';
				
				$html = caledon_addon_get_shortcode_module_template_part( 'templates/parts/network', 'social-share', '', $params );
			}
			
			$networks[ $net ] = $html;
		}
		
		return $networks;
	}

    /**
     * Get share link for networks
     *
     * @param $net
     * @param $image
     * @return string
     */
    private function getSocialNetworkShareLink($net, $image) {
        switch ($net) {
            case 'facebook':
                if (wp_is_mobile()) {
                    $link = 'http://m.facebook.com/sharer.php?u=' . urlencode(get_permalink());
                } else {
                    $link = 'http://www.facebook.com/sharer.php?u=' . urlencode(get_permalink());
                }
                break;
            case 'twitter':
                $count_char = (isset($_SERVER['https'])) ? 23 : 22;
                $twitter_via = (codebean_options()->getOptionValue('twitter_via') !== '') ? ' via ' . codebean_options()->getOptionValue('twitter_via') . ' ' : '';
	            $link = 'http://twitter.com/home?status=' . urlencode(codebean_the_excerpt_max_charlength($count_char) . $twitter_via) . get_permalink();
                break;
            case 'google_plus':
                $link = 'https://plus.google.com/share?url=' . urlencode(get_permalink());
                break;
            case 'linkedin':
                $link = 'http://linkedin.com/shareArticle?mini=true&amp;url=' . urlencode(get_permalink()) . '&amp;title=' . urlencode(get_the_title());
                break;
            case 'tumblr':
                $link = 'http://www.tumblr.com/share/link?url=' . urlencode(get_permalink()) . '&amp;name=' . urlencode(get_the_title()) . '&amp;description=' . urlencode(get_the_excerpt());
                break;
            case 'pinterest':
                $link = 'http://pinterest.com/pin/create/button/?url=' . urlencode(get_permalink()) . '&amp;description=' . codebean_addslashes(get_the_title()) . '&amp;media=' . urlencode($image[0]);
                break;
            case 'vk':
                $link = 'http://vkontakte.ru/share.php?url=' . urlencode(get_permalink()) . '&amp;title=' . urlencode(get_the_title()) . '&amp;description=' . urlencode(get_the_excerpt()) . '&amp;image=' . urlencode($image[0]);
                break;
            default:
                $link = '';
        }

        return $link;
    }
	
	private function getSocialNetworkIcon( $net, $type ) {
		switch ( $net ) {
			case 'facebook':
				$icon = ( $type == 'font-elegant' ) ? 'social_facebook' : 'fab fa-facebook';
				break;
			case 'twitter':
				$icon = ( $type == 'font-elegant' ) ? 'social_twitter' : 'fab fa-twitter';
				break;
			case 'google_plus':
				$icon = ( $type == 'font-awesome' ) ? 'social_googleplus' : 'fab fa-google-plus-g';
				break;
			case 'linkedin':
				$icon = ( $type == 'font-elegant' ) ? 'social_linkedin' : 'fab fa-linkedin';
				break;
			case 'tumblr':
				$icon = ( $type == 'font-elegant' ) ? 'social_tumblr' : 'fab fa-tumblr';
				break;
			case 'pinterest':
				$icon = ( $type == 'font-elegant' ) ? 'social_pinterest' : 'fab fa-pinterest';
				break;
			case 'vk':
				$icon = 'fab fa-vk';
				break;
			default:
				$icon = '';
		}
		
		return $icon;
	}

	private function getSocialNetworkText( $net ) {
		switch ( $net ) {
			case 'facebook':
				$text = esc_html__( 'Facebook', 'caledon-addon');
				break;
			case 'twitter':
				$text = esc_html__( 'Twitter', 'caledon-addon');
				break;
			case 'google_plus':
				$text = esc_html__( 'Google+', 'caledon-addon');
				break;
			case 'linkedin':
				$text = esc_html__( 'LinkedIn', 'caledon-addon');
				break;
			case 'tumblr':
				$text = esc_html__( 'Tumblr', 'caledon-addon');
				break;
			case 'pinterest':
				$text = esc_html__( 'Pinterest', 'caledon-addon');
				break;
			case 'vk':
				$text = esc_html__( 'VK', 'caledon-addon');
				break;
			default:
				$text = '';
		}
		
		return $text;
	}
}