<?php

namespace CaledonAddon\CPT\Shortcodes\VideoButton;

use CaledonAddon\Lib;

class VideoButton implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'codebean_video_button';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Video Button', 'caledon-addon' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'custom_class',
							'heading'     => esc_html__( 'Custom CSS Class', 'caledon-addon' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'caledon-addon' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'video_button_type',
							'heading'     => esc_html__( 'Video Button Type', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Default', 'caledon-addon' ) => 'default',
								esc_html__( 'Button Only', 'caledon-addon' ) => 'button'
							)
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'video_link',
							'heading'    => esc_html__( 'Video Link', 'caledon-addon' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'video_text',
							'heading'     => esc_html__( 'Video Button Text', 'caledon-addon' ),
							'dependency' => array( 'element' => 'video_button_type', 'value' => array( 'button' ) )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'video_button_align',
							'heading'     => esc_html__( 'Video Button Alignment', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Left', 'caledon-addon' )    => 'left',
								esc_html__( 'Center', 'caledon-addon' )  => 'center',
								esc_html__( 'Right', 'caledon-addon' )   => 'right'
							),
							'default'    => 'center',
							'dependency' => array( 'element' => 'video_button_type', 'value' => array( 'button' ) )
						),
						array(
							'type'        => 'attach_image',
							'param_name'  => 'video_image',
							'heading'     => esc_html__( 'Video Image', 'caledon-addon' ),
							'description' => esc_html__( 'Select image from media library', 'caledon-addon' ),
							'dependency' => array( 'element' => 'video_button_type', 'value' => array( 'default' ) )
						),
						array(
							'type'        => 'attach_image',
							'param_name'  => 'play_button_image',
							'heading'     => esc_html__( 'Play Button Custom Image', 'caledon-addon' ),
							'description' => esc_html__( 'Select image from media library. If you use this field then play button color and button size options will not work', 'caledon-addon' ),
							'dependency' => array( 'element' => 'video_button_type', 'value' => array( 'default' ) )
						),
						array(
							'type'        => 'attach_image',
							'param_name'  => 'play_button_hover_image',
							'heading'     => esc_html__( 'Play Button Custom Hover Image', 'caledon-addon' ),
							'description' => esc_html__( 'Select image from media library. If you use this field then play button color and button size options will not work', 'caledon-addon' ),
							'dependency' => array( 'element' => 'video_button_type', 'value' => array( 'default' ) )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'video_button_type'       => 'default',
			'custom_class'            => '',
			'video_link'              => '#',
			'video_text'              => '',
			'video_button_align'      => '',
			'video_image'             => '',
			'play_button_image'       => '',
			'play_button_hover_image' => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['holder_classes']     = $this->getHolderClasses( $params );
		$params['holder_style']       = $this->getHolderStyle( $params );
		
		$html = caledon_addon_get_shortcode_module_template_part( 'templates/video-button', 'video-button', '', $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = ! empty( $params['video_image'] ) ? 'video-poster-with-img' : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getHolderStyle( $params ) {
		$styles = array();

		if ( ! empty( $params['video_button_align'] ) ) {
			$styles[] = 'text-align: ' . $params['video_button_align'];
		}

		return $styles;
	}
}