<?php
/*
Plugin Name: Caledon Addon
Description: Plugin that adds all post types needed by our theme
Author: CodeBean
Version: 1.0
*/

require_once 'load.php';

add_action( 'after_setup_theme', array( CaledonAddon\CPT\PostTypesRegister::getInstance(), 'register' ) );

if ( ! function_exists( 'caledon_addon_activation' ) ) {
	/**
	 * Triggers when plugin is activated. It calls flush_rewrite_rules
	 * and defines codebean_action_core_on_activate action
	 */
	function caledon_addon_activation() {
		do_action( 'codebean_action_core_on_activate' );
		
		CaledonAddon\CPT\PostTypesRegister::getInstance()->register();
		flush_rewrite_rules();
	}
	
	register_activation_hook( __FILE__, 'caledon_addon_activation' );
}

if ( ! function_exists( 'caledon_addon_text_domain' ) ) {
	/**
	 * Loads plugin text domain so it can be used in translation
	 */
	function caledon_addon_text_domain() {
		load_plugin_textdomain( 'caledon-addon', false, CALEDON_ADDON_REL_PATH . '/languages' );
	}
	
	add_action( 'plugins_loaded', 'caledon_addon_text_domain' );
}

if ( ! function_exists( 'CALEDON_ADDON_VERSION_class' ) ) {
	/**
	 * Adds plugins version class to body
	 *
	 * @param $classes
	 *
	 * @return array
	 */
	function CALEDON_ADDON_VERSION_class( $classes ) {
		$classes[] = 'caledon-addon-' . CALEDON_ADDON_VERSION;
		
		return $classes;
	}
	
	add_filter( 'body_class', 'CALEDON_ADDON_VERSION_class' );
}

if ( ! function_exists( 'caledon_addon_theme_installed' ) ) {
	/**
	 * Checks whether theme is installed or not
	 * @return bool
	 */
	function caledon_addon_theme_installed() {
		return defined( 'CODEBEAN_ROOT' );
	}
}

if ( ! function_exists( 'caledon_addon_visual_composer_installed' ) ) {
	/**
	 * Function that checks if Visual Composer plugin installed
	 * @return bool
	 */
	function caledon_addon_visual_composer_installed() {
		return class_exists( 'WPBakeryVisualComposerAbstract' );
	}
}

if ( ! function_exists( 'caledon_addon_is_woocommerce_installed' ) ) {
	/**
	 * Function that checks if woocommerce is installed
	 * @return bool
	 */
	function caledon_addon_is_woocommerce_installed() {
		return function_exists( 'is_woocommerce' );
	}
}

if ( ! function_exists( 'caledon_addon_is_woocommerce_integration_installed' ) ) {
	//is CodeBean Woocommerce Integration installed?
	function caledon_addon_is_woocommerce_integration_installed() {
		return defined( 'CALEDON_CHECKOUT_INTEGRATION' );
	}
}

if ( ! function_exists( 'caledon_addon_is_revolution_slider_installed' ) ) {
	function caledon_addon_is_revolution_slider_installed() {
		return class_exists( 'RevSliderFront' );
	}
}

if ( ! function_exists( 'caledon_addon_is_wpml_installed' ) ) {
	/**
	 * Function that checks if WPML plugin is installed
	 * @return bool
	 *
	 * @version 0.1
	 */
	function caledon_addon_is_wpml_installed() {
		return defined( 'ICL_SITEPRESS_VERSION' );
	}
}

if ( ! function_exists( 'caledon_addon_theme_menu' ) ) {
	/**
	 * Function that generates admin menu for options page.
	 * It generates one admin page per options page.
	 */
	function caledon_addon_theme_menu() {
		if ( caledon_addon_theme_installed() ) {
			
			global $codebean_global_framework;
			codebean_init_theme_options();
			
			$page_hook_suffix = add_menu_page(
				esc_html__( 'Theme Options', 'caledon-addon' ),                                             // The value used to populate the browser's title bar when the menu page is active
				esc_html__( 'Theme Options', 'caledon-addon' ),                                             // The text of the menu in the administrator's sidebar
				'administrator',                                                                               // What roles are able to access the menu
				CODEBEAN_OPTIONS_SLUG,                                                                             // The ID used to bind submenu items to this menu
				array( $codebean_global_framework->getSkin(), 'renderOptions' ),                         // The callback function used to render this menu
				'dashicons-admin-generic',
				62                                                                                            // Position
			);
			
			foreach ( $codebean_global_framework->cdbOptions->adminPages as $key => $value ) {
				$slug = ! empty( $value->slug ) ? '_tab' . $value->slug : '';
				
				$subpage_hook_suffix = add_submenu_page(
					CODEBEAN_OPTIONS_SLUG,
					esc_html__( 'Theme Options - ', 'caledon-addon' ) . $value->title, // The value used to populate the browser's title bar when the menu page is active
					$value->title,                                                        // The text of the menu in the administrator's sidebar
					'administrator',                                                      // What roles are able to access the menu
					CODEBEAN_OPTIONS_SLUG . $slug,                                            // The ID used to bind submenu items to this menu
					array( $codebean_global_framework->getSkin(), 'renderOptions' )
				);
				
				add_action( 'admin_print_scripts-' . $subpage_hook_suffix, 'codebean_enqueue_admin_scripts' );
				add_action( 'admin_print_styles-' . $subpage_hook_suffix, 'codebean_enqueue_admin_styles' );
			};
			
			add_action( 'admin_print_scripts-' . $page_hook_suffix, 'codebean_enqueue_admin_scripts' );
			add_action( 'admin_print_styles-' . $page_hook_suffix, 'codebean_enqueue_admin_styles' );
		}
	}
	
	add_action( 'admin_menu', 'caledon_addon_theme_menu' );
}

if ( ! function_exists( 'caledon_addon_theme_menu_backup_options' ) ) {
	/**
	 * Function that generates admin menu for options page.
	 * It generates one admin page per options page.
	 */
	function caledon_addon_theme_menu_backup_options() {
		if ( caledon_addon_theme_installed() ) {
			global $codebean_global_framework;
			
			$slug             = "_backup_options";
			$page_hook_suffix = add_submenu_page(
				CODEBEAN_OPTIONS_SLUG,
				esc_html__( 'Theme Options - Backup Options', 'caledon-addon' ), // The value used to populate the browser's title bar when the menu page is active
				esc_html__( 'Backup Options', 'caledon-addon' ),                // The text of the menu in the administrator's sidebar
				'administrator',                                             // What roles are able to access the menu
				CODEBEAN_OPTIONS_SLUG . $slug,                     // The ID used to bind submenu items to this menu
				array( $codebean_global_framework->getSkin(), 'renderBackupOptions' )
			);
			
			add_action( 'admin_print_scripts-' . $page_hook_suffix, 'codebean_enqueue_admin_scripts' );
			add_action( 'admin_print_styles-' . $page_hook_suffix, 'codebean_enqueue_admin_styles' );
		}
	}
	
	add_action( 'admin_menu', 'caledon_addon_theme_menu_backup_options' );
}

if ( ! function_exists( 'caledon_addon_theme_admin_bar_menu_options' ) ) {
	/**
	 * Add a link to the WP Toolbar
	 */
	function caledon_addon_theme_admin_bar_menu_options( $wp_admin_bar ) {
		global $codebean_global_framework;
		
		$args = array(
			'id'    => 'codebean-admin-bar-options',
			'title' => sprintf( '<span class="ab-icon dashicons-before dashicons-admin-generic"></span> %s', esc_html__( 'Theme Options', 'caledon-addon' ) ),
			'href'  => esc_url( admin_url( 'admin.php?page=' . CODEBEAN_OPTIONS_SLUG ) )
		);
		
		$wp_admin_bar->add_node( $args );
		
		foreach ( $codebean_global_framework->cdbOptions->adminPages as $key => $value ) {
			$suffix = ! empty( $value->slug ) ? '_tab' . $value->slug : '';
			
			$args = array(
				'id'     => 'codebean-admin-bar-options-' . $suffix,
				'title'  => $value->title,
				'parent' => 'codebean-admin-bar-options',
				'href'   => esc_url( admin_url( 'admin.php?page=' . CODEBEAN_OPTIONS_SLUG . $suffix ) )
			);
			
			$wp_admin_bar->add_node( $args );
		};
	}
	
	add_action( 'admin_bar_menu', 'caledon_addon_theme_admin_bar_menu_options', 999 );
}

if ( ! function_exists( 'caledon_addon_enqueue_our_prettyphoto_scripts_for_theme' ) ) {
	/**
	 * Function that includes our prettyphoto script
	 */
	function caledon_addon_enqueue_our_prettyphoto_scripts_for_theme() {
		
		if ( caledon_addon_theme_installed() && caledon_addon_visual_composer_installed() ) {
			wp_deregister_script( 'prettyphoto' );
			wp_enqueue_script( 'prettyphoto', CODEBEAN_ASSETS_ROOT . '/js/vendors/jquery.prettyPhoto.js', array( 'jquery' ), false, true );
		}
	}
	
	add_action( 'codebean_action_enqueue_third_party_scripts', 'caledon_addon_enqueue_our_prettyphoto_scripts_for_theme' );
}