(function ($) {
	'use strict';
	
	var customFont = {};
	cdbTheme.modules.customFont = customFont;
	
	customFont.customHeadingFontSizes = customHeadingFontSizes;
	customFont.customHeadingAutoType = customHeadingAutoType;
	
	
	customFont.cdbThemeDocumentReady = cdbThemeDocumentReady;
	customFont.cdbThemeWindowLoad = cdbThemeWindowLoad;
	
	$(document).ready(cdbThemeDocumentReady);
	$(window).load(cdbThemeWindowLoad);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		customHeadingFontSizes();
	}
	
	/*
	 All functions to be called on $(window).load() should be in this function
	 */
	function cdbThemeWindowLoad() {
		customHeadingAutoType();
	}
	
	/*
	 **	Custom Font resizing style
	 */
	function customHeadingFontSizes() {
		var holder = $('.custom-heading');
		
		if (holder.length) {
			holder.each(function () {
				var thisItem = $(this),
					itemClass = '',
					smallLaptopStyle = '',
					ipadLandscapeStyle = '',
					ipadPortraitStyle = '',
					mobileLandscapeStyle = '',
					style = '',
					responsiveStyle = '';
				
				if (typeof thisItem.data('selector') !== 'undefined' && thisItem.data('selector') !== false) {
					itemClass = thisItem.data('selector');
				}
				
				if (typeof thisItem.data('font-size-1366') !== 'undefined' && thisItem.data('font-size-1366') !== false) {
					smallLaptopStyle += 'font-size: ' + thisItem.data('font-size-1366') + ' !important;';
				}
				if (typeof thisItem.data('font-size-1024') !== 'undefined' && thisItem.data('font-size-1024') !== false) {
					ipadLandscapeStyle += 'font-size: ' + thisItem.data('font-size-1024') + ' !important;';
				}
				if (typeof thisItem.data('font-size-768') !== 'undefined' && thisItem.data('font-size-768') !== false) {
					ipadPortraitStyle += 'font-size: ' + thisItem.data('font-size-768') + ' !important;';
				}
				if (typeof thisItem.data('font-size-680') !== 'undefined' && thisItem.data('font-size-680') !== false) {
					mobileLandscapeStyle += 'font-size: ' + thisItem.data('font-size-680') + ' !important;';
				}
				
				if (typeof thisItem.data('line-height-1366') !== 'undefined' && thisItem.data('line-height-1366') !== false) {
					smallLaptopStyle += 'line-height: ' + thisItem.data('line-height-1366') + ' !important;';
				}
				if (typeof thisItem.data('line-height-1024') !== 'undefined' && thisItem.data('line-height-1024') !== false) {
					ipadLandscapeStyle += 'line-height: ' + thisItem.data('line-height-1024') + ' !important;';
				}
				if (typeof thisItem.data('line-height-768') !== 'undefined' && thisItem.data('line-height-768') !== false) {
					ipadPortraitStyle += 'line-height: ' + thisItem.data('line-height-768') + ' !important;';
				}
				if (typeof thisItem.data('line-height-680') !== 'undefined' && thisItem.data('line-height-680') !== false) {
					mobileLandscapeStyle += 'line-height: ' + thisItem.data('line-height-680') + ' !important;';
				}
				
				if (smallLaptopStyle.length || ipadLandscapeStyle.length || ipadPortraitStyle.length || mobileLandscapeStyle.length) {
					
					if (smallLaptopStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1366px) {.custom-heading." + itemClass + " { " + smallLaptopStyle + " } }";
					}
					if (ipadLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 1024px) {.custom-heading." + itemClass + " { " + ipadLandscapeStyle + " } }";
					}
					if (ipadPortraitStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 768px) {.custom-heading." + itemClass + " { " + ipadPortraitStyle + " } }";
					}
					if (mobileLandscapeStyle.length) {
						responsiveStyle += "@media only screen and (max-width: 680px) {.custom-heading." + itemClass + " { " + mobileLandscapeStyle + " } }";
					}
				}
				
				if (responsiveStyle.length) {
					style = '<style type="text/css">' + responsiveStyle + '</style>';
				}
				
				if (style.length) {
					$('head').append(style);
				}
			});
		}
	}
	
	/*
	 * Init Type out functionality for Custom Font shortcode
	 */
	function customHeadingAutoType() {
		var autotype_text = $('.autotype-entries');
		
		if (autotype_text.length) {
			autotype_text.each(function () {
				
				//vars
				var thisTyped = $(this),
					typedWrap = thisTyped.parent('.autotype-wrap'),
					customFontHolder = typedWrap.parent('.custom-heading'),
					str = [],
					string_1 = thisTyped.find('.autotype-entry-1').text(),
					string_2 = thisTyped.find('.autotype-entry-2').text(),
					string_3 = thisTyped.find('.autotype-entry-3').text(),
					string_4 = thisTyped.find('.autotype-entry-4').text();
				
				if (string_1.length) {
					str.push(string_1);
				}
				
				if (string_2.length) {
					str.push(string_2);
				}
				
				if (string_3.length) {
					str.push(string_3);
				}
				
				if (string_4.length) {
					str.push(string_4);
				}
				
				customFontHolder.appear(function () {
					thisTyped.typed({
						strings: str,
						typeSpeed: 90,
						backDelay: 700,
						loop: true,
						contentType: 'text',
						loopCount: false,
						cursorChar: '_'
					});
				}, {accX: 0, accY: theme_global_vars.vars.appear_element_amount});
			});
		}
	}
	
})(jQuery);