<?php

namespace CaledonAddon\CPT\Shortcodes\FullScreenCarousel;

use CaledonAddon\Lib;

class FullScreenCarousel implements Lib\ShortcodeInterface {
	private $base;

	public function __construct() {
		$this->base = 'codebean_fullscreen_carousel';

		add_action('vc_before_init', array($this, 'vcMap'));
	}

	/**
	 * Returns base for shortcode
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}

	/**
	 * Maps shortcode to Visual Composer. Hooked on vc_before_init
	 */
	public function vcMap() {
		if(function_exists('vc_map')) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Fullscreen Carousel', 'caledon-addon' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type' => 'param_group',
							'heading' => esc_html__( 'Carousel Items', 'caledon-addon' ),
							'param_name' => 'carousel_items',
							'params' => array(
								array(
									'type'        => 'attach_image',
									'param_name'  => 'item_image',
									'heading'     => esc_html__( 'Item Image', 'caledon-addon' ),
								),
								array(
									'type'        => 'textfield',
									'param_name'  => 'item_title',
									'heading'     => esc_html__( 'Item Title', 'caledon-addon' ),
									'admin_label' => true
								),
								array(
									'type'       => 'textarea',
									'param_name' => 'text',
									'heading'    => esc_html__( 'Content', 'caledon-addon' ),
									'value'      => esc_html__( 'I am test text for Full Screen Carousel shortcode content', 'caledon-addon' )
								),
								array(
									'type'       => 'textfield',
									'param_name' => 'item_link',
									'heading'    => esc_html__( 'Item Link', 'caledon-addon' )
								),
								array(
									'type'       => 'textfield',
									'param_name' => 'item_link_text',
									'heading'    => esc_html__( 'Item Link Text', 'caledon-addon' ),
									'dependency'  => array( 'element' => 'item_link', 'not_empty' => true )
								),
							)
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'change_slides_on_scroll',
							'heading'  => esc_html__( 'Change Slides On Scroll', 'caledon-addon' ),
							'value'      => array_flip( codebean_get_yes_no_select_array( false, true ) ),
							'save_always' => true,
							'admin_label' => true,
							'group'     => esc_html__( 'Layout and Behavior', 'caledon-addon' ),
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'enable_progress_indicator',
							'heading'  => esc_html__( 'Enable Progress Indicator', 'caledon-addon' ),
							'value'      => array_flip( codebean_get_yes_no_select_array( false, true ) ),
							'save_always' => true,
							'admin_label' => true,
							'group'     => esc_html__( 'Layout and Behavior', 'caledon-addon' ),
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'skin',
							'heading'  => esc_html__( 'Skin for Indicator', 'caledon-addon' ),
							'value'      => array(
								esc_html__( 'Light', 'caledon-addon' )   => 'light',
								esc_html__( 'Dark', 'caledon-addon' )  => 'dark'
							),
							'save_always' => true,
							'admin_label' => true,
							'group'     => esc_html__( 'Layout and Behavior', 'caledon-addon' ),
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'items_link_target',
							'heading'     => esc_html__( 'Items Link Target', 'caledon-addon' ),
							'value'       => array_flip( codebean_get_link_target_array() ),
							'save_always' => true,
							'group'     => esc_html__( 'Layout and Behavior', 'caledon-addon' ),
						)
					)
				)
			);
		}
	}

	/**
	 * Renders shortcodes HTML
	 *
	 * @param $atts array of shortcode params
	 * @param $content string shortcode content
	 * @return string
	 */
	public function render($atts, $content = null) {
		$args = array(
			'carousel_items'            	=> '',
			'change_slides_on_scroll'		=> '',
			'enable_progress_indicator' 	=> '',
			'items_link_target'     		=> '',
			'skin'            				=> '',
		);

		$params = shortcode_atts($args, $atts);
		$params['holder_classes'] = $this->getHolderClasses($params);
		$params['content'] = $content;
		$params['carousel_items'] = json_decode(urldecode($params['carousel_items']), true);

		$html = caledon_addon_get_shortcode_module_template_part('templates/fullscreen-carousel-template', 'fullscreen-carousel', '', $params);

		return $html;
	}


	/**
	 * Generates holder classes
	 *
	 * @param $params
	 *
	 * @return string
	 */
	private function getHolderClasses($params){
		$holderClasses = array();

		$holderClasses[] = 'fullscreen-carousel-wrap';

		if ($params['change_slides_on_scroll'] == 'yes') {
			$holderClasses[] = 'slide-on-scroll';
		}

		if ($params['enable_progress_indicator'] == 'yes') {
			$holderClasses[] = 'indicators-active';
		}

		if (!empty($params['skin'])) {
			$holderClasses[] = 'carousel-skin-'.$params['skin'];
		}

		return implode(' ', $holderClasses);
	}
}