(function($) {
    'use strict';

    var tripleFrameImageHighlight = {};
    cdbTheme.modules.tripleFrameImageHighlight = tripleFrameImageHighlight;

    tripleFrameImageHighlight.cdbThemeDocumentReady = cdbThemeDocumentReady;
    tripleFrameImageHighlight.frameImageSlider = frameImageSlider;

    $(document).ready(cdbThemeDocumentReady);

    /*
     All functions to be called on $(document).ready() should be in this function
     */
    function cdbThemeDocumentReady() {
        frameImageSlider();
    }

    /**
     * Image Frame Slider
     */
    function frameImageSlider() {
        var tfihShortcodes = $('.frame-slider');

        if (tfihShortcodes.length) {
            var initClasses = function(c, l, r) {
                c.addClass('center');
                l.addClass('left');
                r.addClass('right');
            }

            var resetIndexes = function(c, l, r) {
                c.css('z-index', 30);
                l.css('z-index', 20);
                r.css('z-index', 20);
            }

            var setTriggerSize = function(holder,inner) {
                holder.find('div[class*="trigger"]').width(Math.round(inner.position().left));
            }

            var setPositioning = function(holder, inner) {
                var left = holder.find('.left'),
                    right = holder.find('.right'),
                    centered = holder.find('.center');

                var xOffset = inner.position().left;

                left.css({
                    'visibility': 'visible',
                    'transform-origin': '0% 50%',
                    'transform': 'matrix(.68,0,0,.68,-'+xOffset+',0)'
                });
                right.css({
                    'visibility': 'visible',
                    'transform-origin': '100% 50%',
                    'transform': 'matrix(.68,0,0,.68,'+xOffset+',0)'
                });
                centered.css({
                    'transform': 'matrix(1, 0, 0, 1, 0, 0)'
                });
            }

            var rotateAnimation = function(holder, inner, direction) {
                holder.data('animating', true);

                if (direction == 'left') {
                    var toFront = holder.find('.left'),
                        toBack = holder.find('.center'),
                        toPrep = holder.find('.right');

                    toPrep.removeClass('right').addClass('left');
                    toBack.removeClass('center').addClass('right');
                    toFront.removeClass('left').addClass('center');
                } else {
                    var toFront = holder.find('.right'),
                        toBack = holder.find('.center'),
                        toPrep = holder.find('.left');

                    toPrep.removeClass('left').addClass('right');
                    toBack.removeClass('center').addClass('left');
                    toFront.removeClass('right').addClass('center');
                }

                toPrep.css({
                    'z-index': 15,
                    'transform-origin': '0% 50%',
                    'transition': 'transform .5s, transform-origin .5s'
                });
                toBack.css({
                    'z-index': 25,
                    'transform-origin': '100% 50%',
                    'transition': 'transform 1s ease .2s, \
                                    transform-origin 1s ease .2s'
                });
                toFront.css({
                    'z-index': 20,
                    'transform-origin': '50% 50%',
                    'transition': 'transform .75s ease .5s, \
                                    transform-origin .75s ease .5s'
                });

                holder.find('a').css('pointer-events', 'none');
                setTimeout(function() {
                    holder.find('a').css('pointer-events', 'auto');
                    resetIndexes(toFront, toPrep, toBack);
                }, 500);

                toFront.one(cdbTheme.transitionEnd, function() {
                    holder.data('animating', false);
                    clearInterval(holder.data('autoplay'));
                    holder.data('autoplay', setInterval(function() {
                        navigate(holder, inner);
                    }, 3000));
                })
            }

            var navigate = function(holder, inner, event) {
                var direction,
                    linkActive = false;

                if (typeof event !== 'undefined') {
                    switch(event.target.className) {
                        case 'frame-slider-left-trigger':
                            direction = 'left';
                            break;
                        case 'frame-slider-right-trigger':
                            direction = 'right';
                            break;
                        case 'frame-slider-link':
                            linkActive = true;
                            holder.data('animating', false);
                            clearInterval(holder.data('autoplay'));
                            break;
                    }
                } else {
                    direction = 'right';
                }

                if (!linkActive) {
                    rotateAnimation(holder, inner, direction)
                    setPositioning(holder, inner);
                }
            }

            tfihShortcodes.each(function() {
                var holder = $(this),
                    inner = holder.find('.frame-slider-inner'),
                    centeredH = holder.find('.frame-slider-centered'),
                    leftH = holder.find('.frame-slider-left'),
                    rightH = holder.find('.frame-slider-right');

                //state
                holder
                    .data('animating', false)
                    .data('autoplay', false);

                initClasses(centeredH, leftH, rightH);
                resetIndexes(centeredH, leftH, rightH);
                setTriggerSize(holder, inner);

                holder.waitForImages(function() {
                    holder.appear(function() {
                        holder.css('visibility', 'visible');
                        setPositioning(holder, inner);
                        holder.data('autoplay', setInterval(function() {
                            navigate(holder, inner);
                        }, 3000));
                    }, {accX: 0, accY: theme_global_vars.vars.appear_element_amount});
                });

                holder.on('click', function(event) {
                    if (!holder.data('animating')) {
                        clearInterval(holder.data('autoplay'));
                        navigate(holder, inner, event);
                    }
                });

                if (holder.parent().hasClass('frame-slider-has-navigation')) {
                    var left = holder.parent().find('.nav-left'),
                        right = holder.parent().find('.nav-right');

                    left.on('click', function() {
                        if (!holder.data('animating')) {
                            rotateAnimation(holder, inner, 'left')
                            setPositioning(holder, inner);
                        }
                    });

                    right.on('click', function() {
                        if (!holder.data('animating')) {
                            rotateAnimation(holder, inner, 'right')
                            setPositioning(holder, inner);
                        }
                    });
                }

                $(window).on('resize', function() {
                    setPositioning(holder, inner);
                    setTriggerSize(holder, inner);
                    inner.find('>div').css('transition', 'none');
                })
            });
        }
    }
})(jQuery);
