<?php
namespace CaledonAddon\CPT\Shortcodes\InstagramShortCode;

use CaledonAddon\Lib;

class InstagramShortCode implements Lib\ShortcodeInterface {
	private $base;

	public function __construct() {
		$this->base = 'codebean_instagram';

		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}

	public function getBase() {
		return $this->base;
	}

	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Instagram', 'caledon-addon' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by Caledon', 'caledon-addon' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type' => 'textfield',
							'heading' => esc_html__( 'Username', 'caledon-addon' ),
							'param_name' => 'username',
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__( 'Number of photos', 'caledon-addon' ),
							'param_name' => 'number',
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Photo size', 'caledon-addon' ),
							'param_name' => 'size',
							'value' => array(
								esc_html__( 'Thumbnail', 'caledon-addon' ) => 'thumbnail',
								esc_html__( 'Large', 'caledon-addon' ) => 'large'
							),
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Open link in', 'caledon-addon' ),
							'param_name' => 'target',
							'value' => array(
								esc_html__( 'Current window (_self)', 'caledon-addon' ) => '_self',
								esc_html__( 'New window (_blank)', 'caledon-addon' ) => '_blank'
							),
						),
						array(
							'type' => 'textfield',
							'heading' => esc_html__( 'Link text', 'caledon-addon' ),
							'param_name' => 'link',
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Design', 'caledon-addon' ),
							'param_name' => 'design',
							'value' => array(
								esc_html__( 'Default', 'caledon-addon' ) => '',
								esc_html__( 'Grid', 'caledon-addon' ) => 'grid',
								esc_html__( 'Slider', 'caledon-addon' ) => 'slider'
							),
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Photos per row', 'caledon-addon' ),
							'param_name' => 'per_row',
							'description' => esc_html__('Number of photos per row for grid design or items in slider per view.', 'caledon-addon' ),
							'value' => array_flip(codebean_get_number_of_columns_array()),
						),
						array(
							'type' => 'textarea_html',
							'holder' => 'div',
							'heading' => esc_html__( 'Instagram text', 'caledon-addon' ),
							'param_name' => 'content',
							'description' => esc_html__( 'Add here few words about your instagram profile.', 'caledon-addon' )
						),
						array(
							'param_name' => 'space_between_columns',
							'type' => 'dropdown',
							'heading' => esc_html__('Space Between Items', 'caledon-addon'),
							'value' => array_flip(codebean_get_columns_gutter_array())
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Rounded corners for images', 'caledon-addon' ),
							'param_name' => 'rounded',
							'value' => array_flip(codebean_get_yes_no_select_array(false)),
						),
						array(
							'type' => 'dropdown',
							'heading' => esc_html__( 'Hide likes and comments', 'caledon-addon' ),
							'param_name' => 'hide_mask',
							'value' => array_flip(codebean_get_yes_no_select_array(false)),
						),
						array(
							'type' => 'dropdown',
							'param_name' => 'slider_loop',
							'heading' => esc_html__('Enable Slider Loop', 'caledon-instagram-feed'),
							'value' => array_flip(codebean_get_yes_no_select_array(false, true)),
							'save_always' => true,
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						),
						array(
							'type' => 'dropdown',
							'param_name' => 'slider_autoplay',
							'heading' => esc_html__('Enable Slider Autoplay', 'caledon-addon'),
							'value' => array_flip(codebean_get_yes_no_select_array(false, true)),
							'save_always' => true,
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						),
						array(
							'type' => 'textfield',
							'param_name' => 'slider_speed',
							'heading' => esc_html__('Slide Duration', 'caledon-addon'),
							'description' => esc_html__('Default value is 5000 (ms)', 'caledon-addon'),
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						),
						array(
							'type' => 'textfield',
							'param_name' => 'slider_speed_animation',
							'heading' => esc_html__('Slide Animation Duration', 'caledon-addon'),
							'description' => esc_html__('Speed of slide animation in milliseconds. Default value is 600.', 'caledon-addon'),
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						),
						array(
							'type' => 'dropdown',
							'param_name' => 'slider_navigation',
							'heading' => esc_html__('Enable Slider Navigation Arrows', 'caledon-addon'),
							'value' => array_flip(codebean_get_yes_no_select_array(false, true)),
							'save_always' => true,
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						),
						array(
							'type' => 'dropdown',
							'param_name' => 'slider_pagination',
							'heading' => esc_html__('Enable Slider Pagination', 'caledon-addon'),
							'value' => array_flip(codebean_get_yes_no_select_array(false, false)),
							'save_always' => true,
							'group' => esc_html__('Slider Settings', 'caledon-addon'),
							'dependency' => array(
								'element' => 'design',
								'value' => array( 'slider' )
							),
						)
					)
				)
			);
		}
	}

	public function render( $atts, $content = null ) {
		$args   = array(
			'username' => '',
			'number' => 6,
			'size' => 'medium',
			'target' => '_blank',
			'link' => '',
			'design' => 'grid',
			'per_row' => '4',
			'space_between_columns' => 'normal',
			'rounded' => 'no',
			'hide_mask' => 'no',
			'slider_loop' => 'yes',
			'slider_autoplay' => 'yes',
			'slider_speed' => '5000',
			'slider_speed_animation' => '600',
			'slider_navigation' => 'yes',
			'slider_pagination' => 'no'
		);
		$params = shortcode_atts( $args, $atts );

		$params['content'] = preg_replace( '#^<\/p>|<p>$#', '', $content );

		$params['holder_classes'] = $this->getHolderClasses($params);
		$params['carousel_classes'] = $this->getCarouselClasses($params);

		$params['images_array'] = caledon_scrape_instagram( $params['username'], $params['number'] );

		$params['data_attr'] = $this->getSliderData($params);

		$html = caledon_addon_get_shortcode_module_template_part( 'templates/instagram', 'instagram', '', $params );

		return $html;
	}


	public function getHolderClasses($params) {
		$holderClasses = array();

		$holderClasses[] = ! empty( $params['number_of_columns'] ) ? 'cdb-' . $params['per_row'] . '-cols' : 'cdb-' . $params['per_row'] . '-cols';
		$holderClasses[] = ! empty( $params['space_between_columns'] ) ? 'cdb-' . $params['space_between_columns'] . '-col-gap' : 'cdb-normal-col-gap';

		if ( $params['hide_mask'] == 'yes' ) {
			$holderClasses[] = 'has-no-hover';
		}

		return implode(' ', $holderClasses);
	}

	public function getCarouselClasses($params) {
		$carouselClasses = array();

		if ($params['design'] === 'slider') {
			$carouselClasses = 'slider-layout cdb-owl-carousel';

		} else if ($params['design'] == 'grid') {
			$carouselClasses = 'grid-layout';
		}

		return $carouselClasses;
	}

	public function getSliderItems($params) {
		switch ($params) {
			case 'one':
				$items = 1;
				break;
			case 'two':
				$items = 2;
				break;
			case 'three':
				$items = 3;
				break;
			case 'four':
				$items = 4;
				break;
			case 'five':
				$items = 5;
				break;
			case 'six':
				$items = 6;
				break;
			default:
				$items = 4;
				break;
		}

		return $items;
	}

	private function getSliderData($params) {
		$slider_data = array();

		$slider_data['data-number-of-items'] = $this->getSliderItems($params['per_row']);;
		$slider_data['data-enable-loop'] = !empty($params['slider_loop']) ? $params['slider_loop'] : '';
		$slider_data['data-enable-autoplay'] = !empty($params['slider_autoplay']) ? $params['slider_autoplay'] : '';
		$slider_data['data-slider-speed'] = !empty($params['slider_speed']) ? $params['slider_speed'] : '5000';
		$slider_data['data-slider-speed-animation'] = !empty($params['slider_speed_animation']) ? $params['slider_speed_animation'] : '600';
		$slider_data['data-enable-navigation'] = !empty($params['slider_navigation']) ? $params['slider_navigation'] : '';
		$slider_data['data-enable-pagination'] = !empty($params['slider_pagination']) ? $params['slider_pagination'] : '';

		return $slider_data;
	}

}