<?php

namespace CaledonAddon\CPT\Shortcodes\InfoBoxes;

use CaledonAddon\Lib;

class InfoBoxes implements Lib\ShortcodeInterface {
	private $base;

	public function __construct() {
		$this->base = 'codebean_rotate_boxes';

		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}

	public function getBase() {
		return $this->base;
	}

	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					"name"                    => esc_html__( 'Rotate Boxes', 'caledon-addon' ),
					"base"                    => $this->base,
					'as_parent'               => array( 'only' => 'codebean_rotate_boxes_item' ),
					"category"                => esc_html__( 'by Caledon', 'caledon-addon' ),
					"show_settings_on_create" => true,
					"js_view"                 => 'VcColumnView',
					"params"                  => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'caledon-addon' ),
							'value'       => array(
								esc_html__( 'Default', 'caledon-addon' ) => '',
								esc_html__( 'Three', 'caledon-addon' )   => '3',
								esc_html__( 'Four', 'caledon-addon' )    => '4',
							),
							'save_always' => true,
							'description' => esc_html__( 'Default value is Four', 'caledon-addon' )
						)
					)
				)
			);
		}
	}

	public function render( $atts, $content = null ) {
		$default_atts = array(
			'number_of_columns'   => ''
		);

		$params = shortcode_atts( $default_atts, $atts );

		$params['content']   = $content;
		$params['holder_classes']     = $this->getHolderClasses( $params );

		$output = caledon_addon_get_shortcode_module_template_part( 'templates/rotate-boxes', 'rotate-boxes', '', $params );

		return $output;
	}

	private function getHolderClasses( $params ) {
		$holderClasses = array();

		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';

		$number_of_columns   = $params['number_of_columns'];

		switch ($number_of_columns):
			case '3':
				$holderClasses[] = 'three-columns';
				break;
			case '4':
				$holderClasses[] = 'four-columns';
				break;
			default:
				$holderClasses[] = 'four-columns';
				break;
		endswitch;

		return implode( ' ', $holderClasses );
	}
}