(function($) {
	'use strict';
	
	var vSplitSlider = {};
	cdbTheme.modules.vSplitSlider = vSplitSlider;
	
	vSplitSlider.splitSliderInitialize = splitSliderInitialize;
	
	
	vSplitSlider.cdbThemeDocumentReady = cdbThemeDocumentReady;
	
	$(document).ready(cdbThemeDocumentReady);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		splitSliderInitialize();
	}
	
	/*
	 **	Vertical Split Slider
	 */
	function splitSliderInitialize() {
		var slider = $('.sl-slider-wrapper'),
			progressBarFlag = true;
		
		if (slider.length) {
			if (cdbTheme.body.hasClass('sl-slider-active')) {
				cdbTheme.body.removeClass('sl-slider-active');
				$.fn.multiscroll.destroy();
			}
			
			slider.height(cdbTheme.windowHeight).animate({opacity: 1}, 300);
			
			var defaultHeaderStyle = '';
			if (cdbTheme.body.hasClass('light-header')) {
				defaultHeaderStyle = 'light';
			} else if (cdbTheme.body.hasClass('dark-header')) {
				defaultHeaderStyle = 'dark';
			}
			
			slider.multiscroll({
				scrollingSpeed: 700,
				easing: 'easeInOutQuart',
				navigation: true,
				useAnchorsOnLoad: false,
				sectionSelector: '.sl-slider-content',
				leftSelector: '.sl-slider-left-wrapper',
				rightSelector: '.sl-slider-right-wrapper',
				afterRender: function () {
					slSliderHeaderSwitchMode($('.sl-slider-left-wrapper .sl-slider-content:first-child').data('header-style'), defaultHeaderStyle);

					cdbTheme.body.addClass('sl-slider-active');
					
					var contactForm7 = $('div.wpcf7 > form');
					if (contactForm7.length) {
						contactForm7.each(function(){
							var thisForm = $(this);
							
							thisForm.find('.wpcf7-submit').off().on('click', function(e){
								e.preventDefault();
								wpcf7.submit(thisForm);
							});
						});
					}
					
					//prepare html for smaller screens - start //
					var vSplitSliderResponsive = $('<div class="sl-slider-responsive"></div>'),
						leftSide = slider.find('.sl-slider-left-wrapper > div'),
						rightSide = slider.find('.sl-slider-right-wrapper > div');
					
					slider.after(vSplitSliderResponsive);
					
					for (var i = 0; i < leftSide.length; i++) {
						vSplitSliderResponsive.append($(leftSide[i]).clone(true));
						vSplitSliderResponsive.append($(rightSide[leftSide.length - 1 - i]).clone(true));
					}
					
					//prepare google maps clones
					var googleMapHolder = $('.sl-slider-responsive .codebean-google-map');
					if (googleMapHolder.length) {
						googleMapHolder.each(function () {
							var map = $(this);
							map.empty();
							var num = Math.floor((Math.random() * 100000) + 1);
							map.attr('id', 'cdb-map-' + num);
							map.data('unique-id', num);
						});
					}
					
					if (typeof cdbTheme.modules.animationHolder.animationBox === "function") {
						cdbTheme.modules.animationHolder.animationBox();
					}
					
					if (typeof cdbTheme.modules.button.codeBeanButton === "function") {
						cdbTheme.modules.button.codeBeanButton().init();
					}
					
					if (typeof cdbTheme.modules.elementsHolder.contentBoxResponsiveStyles === "function") {
						cdbTheme.modules.elementsHolder.contentBoxResponsiveStyles();
					}
					
					if (typeof cdbTheme.modules.googleMap.showGoogleMap === "function") {
						cdbTheme.modules.googleMap.showGoogleMap();
					}
					
					if (typeof cdbTheme.modules.icon.codeBeanIcon === "function") {
						cdbTheme.modules.icon.codeBeanIcon().init();
					}
					
					if (progressBarFlag && typeof cdbTheme.modules.progressBar.progressBars === "function" && ($('.sl-slider-left-wrapper .sl-slider-content.active').find('.progress-bar').length || $('.sl-slider-right-wrapper .sl-slider-content.active').find('.progress-bar').length)) {
						cdbTheme.modules.progressBar.progressBars();
						progressBarFlag = false;
					}
				},
				onLeave: function (index, nextIndex) {

					if (progressBarFlag && typeof cdbTheme.modules.progressBar.progressBars === "function" && ($('.sl-slider-left-wrapper .sl-slider-content.active').find('.progress-bar').length || $('.sl-slider-right-wrapper .sl-slider-content.active').find('.progress-bar').length)) {
						setTimeout(function(){
							cdbTheme.modules.progressBar.progressBars();
						},700);

						progressBarFlag = false;
					}

					animationOnScroll(slider, nextIndex);
					slSliderHeaderSwitchMode($($('.sl-slider-left-wrapper .sl-slider-content')[nextIndex - 1]).data('header-style'), defaultHeaderStyle);
				}
			});
			
			if (cdbTheme.windowWidth <= 1024) {
				$.fn.multiscroll.destroy();
				cdbTheme.modules.progressBar.progressBars();
				progressBarFlag = false;
			} else {
				$.fn.multiscroll.build();
			}
			
			$(window).resize(function () {
				if (cdbTheme.windowWidth <= 1024) {
					$.fn.multiscroll.destroy();
					cdbTheme.modules.progressBar.progressBars();
					progressBarFlag = false;

				} else {
					$.fn.multiscroll.build();
				}
			});
		}
	}
	
	function animationOnScroll(slider, nextIndex) {
		
		if (slider.hasClass('sl-slider-true-on-scroll')) {
			
			if (nextIndex > 1 && !slider.hasClass('sl-slider-scrolled')) {
				slider.addClass('sl-slider-scrolled');
			} else if (nextIndex === 1 && slider.hasClass('sl-slider-scrolled')) {
				slider.removeClass('sl-slider-scrolled');
			}
		}
	}
	
	/*
	 **	Check slides on load and slide change for header style changing
	 */
	function slSliderHeaderSwitchMode(section_header_style, default_header_style) {
		if (section_header_style !== undefined && section_header_style !== '') {
			cdbTheme.body.removeClass('light-header dark-header').addClass( section_header_style + '-header');
		} else if (default_header_style !== '') {
			cdbTheme.body.removeClass('light-header dark-header').addClass( default_header_style + '-header');
		} else {
			cdbTheme.body.removeClass('light-header dark-header');
		}
	}
	
})(jQuery);