<?php

if ( ! function_exists( 'codebean_design_styles' ) ) {
	/**
	 * Generates general custom styles
	 */
	function codebean_design_styles() {
		$font_family = codebean_options()->getOptionValue( 'google_fonts' );
		if ( ! empty( $font_family ) && codebean_is_font_option_valid( $font_family ) ) {
			$font_family_selector = array(
				'body'
			);
			echo codebean_dynamic_css( $font_family_selector, array( 'font-family' => codebean_get_font_option_val( $font_family ) ) );
		}

		$first_main_color = codebean_options()->getOptionValue( 'first_color' );
		if ( ! empty( $first_main_color ) ) {
			$color_selector = array(
				'h1 a:hover',
				'h2 a:hover',
				'h3 a:hover',
				'h4 a:hover',
				'h5 a:hover',
				'h6 a:hover',
				'.site-footer .widget a:hover',
				'.top-bar a:hover',
				'.widget.widget_rss .widget-title .rsswidget:hover',
				'.blog-loop-wrap article.format-link .blog-post-label .blog-post-link-symbol',

			);

			$woo_color_selector = array();
			if ( caledon_is_woocommerce_installed() ) {
				$woo_color_selector = array(
					'.woocommerce-page .page-wrap .quantity-buttons .quantity-minus:hover'
				);
			}

			$color_selector = array_merge( $color_selector, $woo_color_selector );

			$background_color_selector = array(
				'.cdb-preloader .pulse',
				'.off-canvas-sidebar-button.off-canvas-sidebar-button-preset',
				'.off-canvas-sidebar a.off-canvas-sidebar-close.off-canvas-sidebar-close-preset',
				'.mini-cart-wrapper .mini-cart-button .cart-items-count',
				'.widget #wp-calendar td#today',
				'aside.cdb-sidebar .widget-title-box:after',
				'.blog-loop-wrap article.format-quote .blog-post-content'
			);

			$woo_background_color_selector = array();
			if ( caledon_is_woocommerce_installed() ) {
				$woo_background_color_selector = array(
					'.woocommerce-page .page-wrap a.button'
				);
			}

			$background_color_selector = array_merge( $background_color_selector, $woo_background_color_selector );

			$border_color_selector = array(
				'.cdb-preloader .pulse_circles .ball',
			);

			echo codebean_dynamic_css( $color_selector, array( 'color' => $first_main_color ) );
			echo codebean_dynamic_css( $background_color_selector, array( 'background-color' => $first_main_color ) );
			echo codebean_dynamic_css( $border_color_selector, array( 'border-color' => $first_main_color ) );
		}

		$page_background_color = codebean_options()->getOptionValue( 'page_background_color' );
		if ( ! empty( $page_background_color ) ) {
			$background_color_selector = array(
				'body',
				'.page-wrap'
			);
			echo codebean_dynamic_css( $background_color_selector, array( 'background-color' => $page_background_color ) );
		}

		$page_background_image  = codebean_options()->getOptionValue( 'page_background_image' );
		$page_background_repeat = codebean_options()->getOptionValue( 'page_background_image_repeat' );

		if ( ! empty( $page_background_image ) ) {

			if ( $page_background_repeat === 'yes' ) {
				$background_image_style = array(
					'background-image'    => 'url(' . esc_url( $page_background_image ) . ')',
					'background-repeat'   => 'repeat',
					'background-position' => '0 0',
				);
			} else {
				$background_image_style = array(
					'background-image'    => 'url(' . esc_url( $page_background_image ) . ')',
					'background-repeat'   => 'no-repeat',
					'background-position' => 'center 0',
					'background-size'     => 'cover'
				);
			}

			echo codebean_dynamic_css( '.page-wrap', $background_image_style );
		}

		$selection_color = codebean_options()->getOptionValue( 'selection_color' );
		if ( ! empty( $selection_color ) ) {
			echo codebean_dynamic_css( '::selection', array( 'background' => $selection_color ) );
			echo codebean_dynamic_css( '::-moz-selection', array( 'background' => $selection_color ) );
		}

		$preload_background_styles = array();

		if ( codebean_options()->getOptionValue( 'preload_pattern_image' ) !== "" ) {
			$preload_background_styles['background-image'] = 'url(' . codebean_options()->getOptionValue( 'preload_pattern_image' ) . ') !important';
		}

		echo codebean_dynamic_css( '.prealoader-bg', $preload_background_styles );
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_design_styles' );
}

if ( ! function_exists( 'codebean_content_styles' ) ) {
	function codebean_content_styles() {
		$content_style = array();

		$padding = codebean_options()->getOptionValue( 'content_padding' );
		if ( $padding !== '' ) {
			$content_style['padding'] = $padding;
		}

		$content_selector = array(
			'.page-wrap .page-wrap-inner > .fw-container > .fw-container-inner',
		);

		echo codebean_dynamic_css( $content_selector, $content_style );

		$content_style_in_grid = array();

		$padding_in_grid = codebean_options()->getOptionValue( 'content_padding_in_grid' );
		if ( $padding_in_grid !== '' ) {
			$content_style_in_grid['padding'] = $padding_in_grid;
		}

		$content_selector_in_grid = array(
			'.page-wrap .page-wrap-inner > .cdb-grid > .cdb-grid-box',
		);

		echo codebean_dynamic_css( $content_selector_in_grid, $content_style_in_grid );
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_content_styles' );
}

if ( ! function_exists( 'codebean_h1_styles' ) ) {
	function codebean_h1_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h1_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h1_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h1' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h1'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h1_styles' );
}

if ( ! function_exists( 'codebean_h2_styles' ) ) {
	function codebean_h2_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h2_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h2_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h2' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h2'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h2_styles' );
}

if ( ! function_exists( 'codebean_h3_styles' ) ) {
	function codebean_h3_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h3_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h3_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h3' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h3'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h3_styles' );
}

if ( ! function_exists( 'codebean_h4_styles' ) ) {
	function codebean_h4_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h4_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h4_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h4' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h4'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h4_styles' );
}

if ( ! function_exists( 'codebean_h5_styles' ) ) {
	function codebean_h5_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h5_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h5_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h5' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h5'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h5_styles' );
}

if ( ! function_exists( 'codebean_h6_styles' ) ) {
	function codebean_h6_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'h6_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'h6_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'h6' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'h6'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_h6_styles' );
}

if ( ! function_exists( 'codebean_text_styles' ) ) {
	function codebean_text_styles() {
		$margin_top    = codebean_options()->getOptionValue( 'text_margin_top' );
		$margin_bottom = codebean_options()->getOptionValue( 'text_margin_bottom' );

		$item_styles = codebean_get_typography_styles( 'text' );

		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = codebean_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = codebean_filter_px( $margin_bottom ) . 'px';
		}

		$item_selector = array(
			'p'
		);

		if ( ! empty( $item_styles ) ) {
			echo codebean_dynamic_css( $item_selector, $item_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_text_styles' );
}

if ( ! function_exists( 'codebean_link_styles' ) ) {
	function codebean_link_styles() {
		$link_styles      = array();
		$link_color       = codebean_options()->getOptionValue( 'link_color' );
		$link_font_style  = codebean_options()->getOptionValue( 'link_fontstyle' );
		$link_font_weight = codebean_options()->getOptionValue( 'link_fontweight' );
		$link_decoration  = codebean_options()->getOptionValue( 'link_fontdecoration' );

		if ( ! empty( $link_color ) ) {
			$link_styles['color'] = $link_color;
		}
		if ( ! empty( $link_font_style ) ) {
			$link_styles['font-style'] = $link_font_style;
		}
		if ( ! empty( $link_font_weight ) ) {
			$link_styles['font-weight'] = $link_font_weight;
		}
		if ( ! empty( $link_decoration ) ) {
			$link_styles['text-decoration'] = $link_decoration;
		}

		$link_selector = array(
			'a',
			'p a'
		);

		if ( ! empty( $link_styles ) ) {
			echo codebean_dynamic_css( $link_selector, $link_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_link_styles' );
}

if ( ! function_exists( 'codebean_link_hover_styles' ) ) {
	function codebean_link_hover_styles() {
		$link_hover_styles     = array();
		$link_hover_color      = codebean_options()->getOptionValue( 'link_hovercolor' );
		$link_hover_decoration = codebean_options()->getOptionValue( 'link_hover_fontdecoration' );

		if ( ! empty( $link_hover_color ) ) {
			$link_hover_styles['color'] = $link_hover_color;
		}
		if ( ! empty( $link_hover_decoration ) ) {
			$link_hover_styles['text-decoration'] = $link_hover_decoration;
		}

		$link_hover_selector = array(
			'a:hover',
			'p a:hover'
		);

		if ( ! empty( $link_hover_styles ) ) {
			echo codebean_dynamic_css( $link_hover_selector, $link_hover_styles );
		}

		$link_heading_hover_styles = array();

		if ( ! empty( $link_hover_color ) ) {
			$link_heading_hover_styles['color'] = $link_hover_color;
		}

		$link_heading_hover_selector = array(
			'h1 a:hover',
			'h2 a:hover',
			'h3 a:hover',
			'h4 a:hover',
			'h5 a:hover',
			'h6 a:hover'
		);

		if ( ! empty( $link_heading_hover_styles ) ) {
			echo codebean_dynamic_css( $link_heading_hover_selector, $link_heading_hover_styles );
		}
	}

	add_action( 'codebean_action_style_dynamic', 'codebean_link_hover_styles' );
}

if ( ! function_exists( 'codebean_smooth_page_transition_styles' ) ) {
	function codebean_smooth_page_transition_styles( $style ) {
		$id            = codebean_get_page_id();
		$loader_style  = array();
		$current_style = '';

		$background_color = codebean_get_meta_field_intersect( 'smooth_pt_bgnd_color', $id );
		if ( ! empty( $background_color ) ) {
			$loader_style['background-color'] = $background_color;
		}

		$loader_selector = array(
			'.smooth-page-loader'
		);

		if ( ! empty( $loader_style ) ) {
			$current_style .= codebean_dynamic_css( $loader_selector, $loader_style );
		}

		$spinner_style = array();
		$spinner_color = codebean_get_meta_field_intersect( 'smooth_pt_spinner_color', $id );
		if ( ! empty( $spinner_color ) ) {
			$spinner_style['background-color'] = $spinner_color;
		}

		$spinner_selectors = array(
			'.cdb-preloader .rotating-circles > div',
			'.cdb-preloader .pulse',
			'.cdb-preloader .double_pulse .double-bounce1',
			'.cdb-preloader .double_pulse .double-bounce2',
			'.cdb-preloader .cube',
			'.cdb-preloader .rotating_cubes .cube1',
			'.cdb-preloader .rotating_cubes .cube2',
			'.cdb-preloader .stripes > div',
			'.cdb-preloader .wave > div',
			'.cdb-preloader .two_rotating_circles .dot1',
			'.cdb-preloader .two_rotating_circles .dot2',
			'.cdb-preloader .five_rotating_circles .container1 > div',
			'.cdb-preloader .five_rotating_circles .container2 > div',
			'.cdb-preloader .five_rotating_circles .container3 > div',
			'.cdb-preloader .atom .ball-1:before',
			'.cdb-preloader .atom .ball-2:before',
			'.cdb-preloader .atom .ball-3:before',
			'.cdb-preloader .atom .ball-4:before',
			'.cdb-preloader .clock .ball:before',
			'.cdb-preloader .mitosis .ball',
			'.cdb-preloader .lines .line1',
			'.cdb-preloader .lines .line2',
			'.cdb-preloader .lines .line3',
			'.cdb-preloader .lines .line4',
			'.cdb-preloader .fussion .ball',
			'.cdb-preloader .fussion .ball-1',
			'.cdb-preloader .fussion .ball-2',
			'.cdb-preloader .fussion .ball-3',
			'.cdb-preloader .fussion .ball-4',
			'.cdb-preloader .wave_circles .ball',
			'.cdb-preloader .pulse_circles .ball',
			'.cdb-preloader .page-loader-letter .character-bg'
		);

		if ( ! empty( $spinner_style ) ) {
			$current_style .= codebean_dynamic_css( $spinner_selectors, $spinner_style );
		}

		$current_style = $current_style . $style;

		return $current_style;
	}

	add_filter( 'codebean_filter_add_page_custom_style', 'codebean_smooth_page_transition_styles' );
}