<?php

if ( ! function_exists( 'codebean_map_general_meta' ) ) {
	function codebean_map_general_meta() {
		
		$general_meta_box = codebean_create_meta_box(
			array(
				'scope' => apply_filters( 'codebean_filter_set_scope_for_meta_boxes', array( 'page', 'post' ), 'general_meta' ),
				'title' => esc_html__( 'General', 'caledon' ),
				'name'  => 'general_meta'
			)
		);
		
		/***************** Slider Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_page_slider_meta',
				'type'        => 'text',
				'label'       => esc_html__( 'Slider Shortcode', 'caledon' ),
				'description' => esc_html__( 'Paste your slider shortcode here', 'caledon' ),
				'parent'      => $general_meta_box
			)
		);
		
		/***************** Slider Layout - begin **********************/
		
		/***************** Content Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_page_content_behind_header_meta',
				'type'          => 'yesno',
				'default_value' => 'no',
				'label'         => esc_html__( 'Always put content behind header', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will put page content behind page header', 'caledon' ),
				'parent'        => $general_meta_box
			)
		);
		
		$cdb_content_padding_group = codebean_add_admin_group(
			array(
				'name'        => 'content_padding_group',
				'title'       => esc_html__( 'Content Styles', 'caledon' ),
				'description' => esc_html__( 'Define styles for Content area', 'caledon' ),
				'parent'      => $general_meta_box
			)
		);
		
			$cdb_content_padding_row = codebean_add_admin_row(
				array(
					'name'   => 'cdb_content_padding_row',
					'parent' => $cdb_content_padding_group
				)
			);
			
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_page_background_color_meta',
						'type'        => 'colorsimple',
						'label'       => esc_html__( 'Page Background Color', 'caledon' ),
						'parent'      => $cdb_content_padding_row
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_page_background_image_meta',
						'type'          => 'imagesimple',
						'label'         => esc_html__( 'Page Background Image', 'caledon' ),
						'parent'        => $cdb_content_padding_row
					)
				);

				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_page_background_repeat_meta',
						'type'          => 'selectsimple',
						'default_value' => '',
						'label'         => esc_html__( 'Page Background Image Repeat', 'caledon' ),
						'options'       => codebean_get_yes_no_select_array(),
						'parent'        => $cdb_content_padding_row
					)
				);
		
			$cdb_content_padding_row_1 = codebean_add_admin_row(
				array(
					'name'   => 'cdb_content_padding_row_1',
					'next'   => true,
					'parent' => $cdb_content_padding_group
				)
			);
		
				codebean_create_meta_box_field(
					array(
						'name'   => 'cdb_page_content_padding',
						'type'   => 'textsimple',
						'label'  => esc_html__( 'Content Padding (eg. 10px 5px 10px 5px)', 'caledon' ),
						'parent' => $cdb_content_padding_row_1,
						'args'        => array(
							'col_width' => 4
						)
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'    => 'cdb_page_content_padding_mobile',
						'type'    => 'textsimple',
						'label'   => esc_html__( 'Content Padding for mobile (eg. 10px 5px 10px 5px)', 'caledon' ),
						'parent'  => $cdb_content_padding_row_1,
						'args'        => array(
							'col_width' => 4
						)
					)
				);

		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_page_dynamic_background_color',
				'type'        => 'yesno',
				'default_value' => 'no',
				'label'       => esc_html__( 'Dynamic Background Color', 'caledon' ),
				'description' => esc_html__( 'Background color will change depending on the value set on the corresponding Row element - currently in viewport.', 'caledon' ),
				'parent'      => $general_meta_box
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_initial_content_width_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Initial Width of Content', 'caledon' ),
				'description'   => esc_html__( 'Choose the initial width of content which is in grid (Applies to pages set to "Default Template" and rows set to "In Grid")', 'caledon' ),
				'parent'        => $general_meta_box,
				'options'       => array(
					''                => esc_html__( 'Default', 'caledon' ),
					'container-1300' => esc_html__( '1300px', 'caledon' ),
					'container-1200' => esc_html__( '1200px', 'caledon' ),
					'container-1100' => esc_html__( '1100px', 'caledon' ),
					'container-1000' => esc_html__( '1000px', 'caledon' ),
					'container-800'  => esc_html__( '800px', 'caledon' )
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_page_grid_space_meta',
				'type'        => 'select',
				'default_value' => '',
				'label'       => esc_html__( 'Grid Layout Space', 'caledon' ),
				'description' => esc_html__( 'Choose a space between content layout and sidebar layout for your page', 'caledon' ),
				'options'     => codebean_get_columns_gutter_array( true ),
				'parent'      => $general_meta_box
			)
		);
		
		/***************** Content Layout - end **********************/
		
		/***************** Boxed Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'    => 'cdb_boxed_meta',
				'type'    => 'select',
				'label'   => esc_html__( 'Boxed Layout', 'caledon' ),
				'parent'  => $general_meta_box,
				'options' => codebean_get_yes_no_select_array()
			)
		);
		
			$boxed_container_meta = codebean_add_admin_container(
				array(
					'parent'          => $general_meta_box,
					'name'            => 'boxed_container_meta',
					'dependency' => array(
						'hide' => array(
							'cdb_boxed_meta' => array( '', 'no' )
						)
					)
				)
			);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_page_background_color_in_box_meta',
						'type'        => 'color',
						'label'       => esc_html__( 'Page Background Color', 'caledon' ),
						'description' => esc_html__( 'Choose the page background color outside box', 'caledon' ),
						'parent'      => $boxed_container_meta
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_boxed_background_image_meta',
						'type'        => 'image',
						'label'       => esc_html__( 'Background Image', 'caledon' ),
						'description' => esc_html__( 'Choose an image to be displayed in background', 'caledon' ),
						'parent'      => $boxed_container_meta
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_boxed_pattern_background_image_meta',
						'type'        => 'image',
						'label'       => esc_html__( 'Background Pattern', 'caledon' ),
						'description' => esc_html__( 'Choose an image to be used as background pattern', 'caledon' ),
						'parent'      => $boxed_container_meta
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_boxed_background_image_attachment_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Background Image Attachment', 'caledon' ),
						'description'   => esc_html__( 'Choose background image attachment', 'caledon' ),
						'parent'        => $boxed_container_meta,
						'options'       => array(
							''       => esc_html__( 'Default', 'caledon' ),
							'fixed'  => esc_html__( 'Fixed', 'caledon' ),
							'scroll' => esc_html__( 'Scroll', 'caledon' )
						)
					)
				);
		
		/***************** Boxed Layout - end **********************/
		
		/***************** Passepartout Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_paspartu_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Passepartout', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will display passepartout around site content', 'caledon' ),
				'parent'        => $general_meta_box,
				'options'       => codebean_get_yes_no_select_array(),
			)
		);
		
			$paspartu_container_meta = codebean_add_admin_container(
				array(
					'parent'          => $general_meta_box,
					'name'            => 'cdb_paspartu_container_meta',
					'dependency' => array(
						'hide' => array(
							'cdb_paspartu_meta'  => array('','no')
						)
					)
				)
			);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_paspartu_color_meta',
						'type'        => 'color',
						'label'       => esc_html__( 'Passepartout Color', 'caledon' ),
						'description' => esc_html__( 'Choose passepartout color, default value is #ffffff', 'caledon' ),
						'parent'      => $paspartu_container_meta
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_paspartu_width_meta',
						'type'        => 'text',
						'label'       => esc_html__( 'Passepartout Size', 'caledon' ),
						'description' => esc_html__( 'Enter size amount for passepartout', 'caledon' ),
						'parent'      => $paspartu_container_meta,
						'args'        => array(
							'col_width' => 2,
							'suffix'    => 'px or %'
						)
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_paspartu_responsive_width_meta',
						'type'        => 'text',
						'label'       => esc_html__( 'Responsive Passepartout Size', 'caledon' ),
						'description' => esc_html__( 'Enter size amount for passepartout for smaller screens (tablets and mobiles view)', 'caledon' ),
						'parent'      => $paspartu_container_meta,
						'args'        => array(
							'col_width' => 2,
							'suffix'    => 'px or %'
						)
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'parent'        => $paspartu_container_meta,
						'type'          => 'select',
						'default_value' => '',
						'name'          => 'cdb_disable_top_paspartu_meta',
						'label'         => esc_html__( 'Disable Top Passepartout', 'caledon' ),
						'options'       => codebean_get_yes_no_select_array(),
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'parent'        => $paspartu_container_meta,
						'type'          => 'select',
						'default_value' => '',
						'name'          => 'cdb_enable_fixed_paspartu_meta',
						'label'         => esc_html__( 'Enable Fixed Passepartout', 'caledon' ),
						'description'   => esc_html__( 'Enabling this option will set fixed passepartout for your screens', 'caledon' ),
						'options'       => codebean_get_yes_no_select_array(),
					)
				);
		
		/***************** Passepartout Layout - end **********************/
		
		/***************** Smooth Page Transitions Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_smooth_page_transitions_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Smooth Page Transitions', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will perform a smooth transition between pages when clicking on links', 'caledon' ),
				'parent'        => $general_meta_box,
				'options'       => codebean_get_yes_no_select_array()
			)
		);
		
			$page_transitions_container_meta = codebean_add_admin_container(
				array(
					'parent'     => $general_meta_box,
					'name'       => 'page_transitions_container_meta',
					'dependency' => array(
						'hide' => array(
							'cdb_smooth_page_transitions_meta' => array( '', 'no' )
						)
					)
				)
			);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_page_transition_preloader_meta',
						'type'        => 'select',
						'label'       => esc_html__( 'Enable Preloading Animation', 'caledon' ),
						'description' => esc_html__( 'Enabling this option will display an animated preloader while the page content is loading', 'caledon' ),
						'parent'      => $page_transitions_container_meta,
						'options'     => codebean_get_yes_no_select_array()
					)
				);
		
				$page_transition_preloader_container_meta = codebean_add_admin_container(
					array(
						'parent'     => $page_transitions_container_meta,
						'name'       => 'page_transition_preloader_container_meta',
						'dependency' => array(
							'hide' => array(
								'cdb_page_transition_preloader_meta' => array( '', 'no' )
							)
						)
					)
				);
				
					codebean_create_meta_box_field(
						array(
							'name'   => 'cdb_smooth_pt_bgnd_color_meta',
							'type'   => 'color',
							'label'  => esc_html__( 'Page Loader Background Color', 'caledon' ),
							'parent' => $page_transition_preloader_container_meta
						)
					);
					
					$group_pt_spinner_animation_meta = codebean_add_admin_group(
						array(
							'name'        => 'group_pt_spinner_animation_meta',
							'title'       => esc_html__( 'Loader Style', 'caledon' ),
							'description' => esc_html__( 'Define styles for loader spinner animation', 'caledon' ),
							'parent'      => $page_transition_preloader_container_meta
						)
					);
					
					$row_pt_spinner_animation_meta = codebean_add_admin_row(
						array(
							'name'   => 'row_pt_spinner_animation_meta',
							'parent' => $group_pt_spinner_animation_meta
						)
					);
					
					codebean_create_meta_box_field(
						array(
							'type'    => 'selectsimple',
							'name'    => 'cdb_smooth_pt_spinner_type_meta',
							'label'   => esc_html__( 'Spinner Type', 'caledon' ),
							'parent'  => $row_pt_spinner_animation_meta,
							'options' => array(
								''                      => esc_html__( 'Default', 'caledon' ),
								'logo_letter'        	=> esc_html__( 'Logo Letter', 'caledon' ),
								'rotate_circles'        => esc_html__( 'Rotate Circles', 'caledon' ),
								'pulse'                 => esc_html__( 'Pulse', 'caledon' ),
								'double_pulse'          => esc_html__( 'Double Pulse', 'caledon' ),
								'cube'                  => esc_html__( 'Cube', 'caledon' ),
								'rotating_cubes'        => esc_html__( 'Rotating Cubes', 'caledon' ),
								'stripes'               => esc_html__( 'Stripes', 'caledon' ),
								'wave'                  => esc_html__( 'Wave', 'caledon' ),
								'two_rotating_circles'  => esc_html__( '2 Rotating Circles', 'caledon' ),
								'five_rotating_circles' => esc_html__( '5 Rotating Circles', 'caledon' ),
								'atom'                  => esc_html__( 'Atom', 'caledon' ),
								'clock'                 => esc_html__( 'Clock', 'caledon' ),
								'mitosis'               => esc_html__( 'Mitosis', 'caledon' ),
								'lines'                 => esc_html__( 'Lines', 'caledon' ),
								'fussion'               => esc_html__( 'Fussion', 'caledon' ),
								'wave_circles'          => esc_html__( 'Wave Circles', 'caledon' ),
								'pulse_circles'         => esc_html__( 'Pulse Circles', 'caledon' )
							)
						)
					);

					codebean_create_meta_box_field(
						array(
							'type' => 'textsimple',
							'name' => 'cdb_logo_letter_val_meta',
							'default_value' => esc_html__('', 'caledon'),
							'label' => esc_html__('Logo Letter', 'caledon'),
							'parent' => $row_pt_spinner_animation_meta,
							'dependency' => array(
								'show' => array(
									'cdb_smooth_pt_spinner_type_meta' => 'logo_letter'
								)
							)
						)
					);
					
					codebean_create_meta_box_field(
						array(
							'type'   => 'colorsimple',
							'name'   => 'cdb_smooth_pt_spinner_color_meta',
							'label'  => esc_html__( 'Spinner Color', 'caledon' ),
							'parent' => $row_pt_spinner_animation_meta
						)
					);
					
					codebean_create_meta_box_field(
						array(
							'name'        => 'cdb_page_transition_fadeout_meta',
							'type'        => 'select',
							'label'       => esc_html__( 'Enable Fade Out Animation', 'caledon' ),
							'description' => esc_html__( 'Enabling this option will turn on fade out animation when leaving page', 'caledon' ),
							'options'     => codebean_get_yes_no_select_array(),
							'parent'      => $page_transitions_container_meta
						
						)
					);
		
		/***************** Smooth Page Transitions Layout - end **********************/
		
		/***************** Comments Layout - begin **********************/
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_page_comments_meta',
				'type'        => 'select',
				'label'       => esc_html__( 'Show Comments', 'caledon' ),
				'description' => esc_html__( 'Enabling this option will show comments on your page', 'caledon' ),
				'parent'      => $general_meta_box,
				'options'     => codebean_get_yes_no_select_array()
			)
		);
		
		/***************** Comments Layout - end **********************/
	}
	
	add_action( 'codebean_action_meta_boxes_map', 'codebean_map_general_meta', 10 );
}

if ( ! function_exists( 'codebean_container_background_style' ) ) {
	/**
	 * Function that return container style
	 */
	function codebean_container_background_style( $style ) {
		$page_id      = codebean_get_page_id();
		$class_prefix = codebean_get_unique_page_class( $page_id, true );
		
		$container_selector = array(
			$class_prefix . ' .page-wrap'
		);
		
		$container_class        = array();
		$page_background_color  = get_post_meta( $page_id, 'cdb_page_background_color_meta', true );
		$page_background_image  = get_post_meta( $page_id, 'cdb_page_background_image_meta', true );
		$page_background_repeat = get_post_meta( $page_id, 'cdb_page_background_repeat_meta', true );
		
		if ( ! empty( $page_background_color ) ) {
			$container_class['background-color'] = $page_background_color;
		}
		
		if ( ! empty( $page_background_image ) ) {
			$container_class['background-image'] = 'url(' . esc_url( $page_background_image ) . ')';
			
			if ( $page_background_repeat === 'yes' ) {
				$container_class['background-repeat']   = 'repeat';
				$container_class['background-position'] = '0 0';
			} else {
				$container_class['background-repeat']   = 'no-repeat';
				$container_class['background-position'] = 'center 0';
				$container_class['background-size']     = 'cover';
			}
		}
		
		$current_style = codebean_dynamic_css( $container_selector, $container_class );
		$current_style = $current_style . $style;
		
		return $current_style;
	}
	
	add_filter( 'codebean_filter_add_page_custom_style', 'codebean_container_background_style' );
}