<?php

//if accessed directly exit
if(!defined('ABSPATH')) exit;

class CodebeanSkin extends CodeBeanClassSkinAbstract {
	
	/**
	 * Skin constructor. Hooks to codebean_admin_scripts_init and codebean_enqueue_admin_styles
	 */
	public function __construct() {
		$this->skinName = 'codebean';
		
		//hook to
		add_action( 'codebean_action_admin_scripts_init', array( $this, 'registerStyles' ) );
		add_action( 'codebean_action_admin_scripts_init', array( $this, 'registerScripts' ) );
		
		add_action( 'codebean_action_enqueue_admin_styles', array( $this, 'enqueueStyles' ) );
		add_action( 'codebean_action_enqueue_admin_scripts', array( $this, 'enqueueScripts' ) );
		
		add_action( 'codebean_action_enqueue_meta_box_styles', array( $this, 'enqueueStyles' ) );
		add_action( 'codebean_action_enqueue_meta_box_scripts', array( $this, 'enqueueScripts' ) );
		
		add_filter( 'codebean_filter_options_map_position', array( $this, 'setOptionsMapPosition' ), 10, 2 );
		
		add_action( 'before_wp_tiny_mce', array( $this, 'setShortcodeJSParams' ) );
	}

    /**
     * Method that registers skin scripts
     */
	public function registerScripts() {
		
		$this->scripts['cdb-ui-admin-skin'] = array(
			'path'       => 'assets/js/cdb-ui.js',
			'dependency' => array()
		);
		
		foreach ( $this->scripts as $scriptHandle => $script ) {
			codebean_register_skin_script( $scriptHandle, $script['path'], $script['dependency'] );
		}
	}

    /**
     * Method that registers skin styles
     */
    public function registerStyles() {
	    $this->styles['cdb-bootstrap'] = 'assets/css/cdb-bootstrap.css';
        $this->styles['cdb-page-admin'] = 'assets/css/cdb-page.css';
        $this->styles['cdb-options-admin'] = 'assets/css/cdb-options.css';
        $this->styles['cdb-meta-boxes-admin'] = 'assets/css/cdb-meta-boxes.css';
        $this->styles['cdb-ui-admin'] = 'assets/css/cdb-ui/cdb-ui.css';
        $this->styles['cdb-forms-admin'] = 'assets/css/cdb-forms.css';

        foreach ($this->styles as $styleHandle => $stylePath) {
            codebean_register_skin_style($styleHandle, $stylePath);
        }
    }

    /**
     * Method that renders options page
     *
     * @see CodebeanSkin::getHeader()
     * @see CodebeanSkin::getPageNav()
     * @see CodebeanSkin::getPageContent()
     */
    public function renderOptions() {
        global $codebean_global_framework;
        $tab    		= codebean_get_admin_tab();
        $active_page 	= $codebean_global_framework->cdbOptions->getAdminPageFromSlug($tab);
        $current_theme 	= wp_get_theme();

        if ($active_page == null) return;
        ?>
        <div class="cdb-options-page cdb-page">
            <?php $this->getHeader($current_theme->get('Name'), $current_theme->get('Version')); ?>
            <div class="cdb-page-content-wrapper">
                <div class="cdb-page-content">
                    <div class="cdb-page-navigation cdb-tabs-wrapper vertical left clearfix">
                        <?php $this->getPageNav($tab); ?>
                        <?php $this->getPageContent($active_page, $tab); ?>
                    </div>
                </div>
            </div>
        </div>
        <a id='back_to_top' href='#'>
            <span class="fa-stack">
                <span class="fa fa-angle-up"></span>
            </span>
        </a>
    <?php }

    /**
     * Method that renders header of options page.
     * @param string $themeName - theme name to display
     * @param string $themeVersion -  version to display
     * @param bool $showSaveButton - whether to show save button or not
     *
     * @see CodeBeanClassSkinAbstract::loadTemplatePart()
     */
    public function getHeader($themeName = '', $themeVersion, $showSaveButton = true) {
        $this->loadTemplatePart('header', array(
            'themeName' => $themeName,
            'themeVersion' => $themeVersion,
            'showSaveButton' => $showSaveButton)
        );
    }

    /**
     * Method that loads page navigation
     * @param string $tab current tab
     *
     * @see CodeBeanClassSkinAbstract::loadTemplatePart()
     */
    public function getPageNav($tab, $isBackupOptionsPage = false) {
        $this->loadTemplatePart('navigation', array(
            'tab' => $tab,
            'isBackupOptionsPage' => $isBackupOptionsPage
        ));
    }

    /**
     * Method that loads current page content
     *
     * @param CodeBeanClassAdminPage $page current page to load
     * @param string $tab current page slug
     * @param bool $showAnchors whether to show anchors template or not
     *
     * @see CodeBeanClassSkinAbstract::loadTemplatePart()
     */
    public function getPageContent($page, $tab, $showAnchors = true) {
        $this->loadTemplatePart('content', array(
            'page' => $page,
            'tab' => $tab,
            'showAnchors' => $showAnchors
        ));
    }

	/**
     * Method that loads content for import page
     */
    public function getBackupOptionsContent() {
        $this->loadTemplatePart('backup-options');
    }

    /**
     * Method that loads anchors and save button template part
     *
	 * @param CodeBeanClassAdminPage $page current page to load
     *
     * @see CodeBeanClassSkinAbstract::loadTemplatePart()
     */
    public function getAnchors($page) {
        $this->loadTemplatePart('anchors', array('page' => $page));
    }

	/**
	 * Method that renders backup options page
	 *
	 * @see CodebeanSkin::getHeader()
	 * * @see CodebeanSkin::getPageNav()
	 * * @see CodebeanSkin::getImportContent()
	 */
	public function renderBackupOptions() { ?>
		<div class="cdb-options-page cdb-page">
			<?php $this->getHeader(codebean_get_theme_info_item('Name'), codebean_get_theme_info_item('Version'), false); ?>
			<div class="cdb-page-content-wrapper">
				<div class="cdb-page-content">
					<div class="cdb-page-navigation cdb-tabs-wrapper vertical left clearfix">
						<?php $this->getPageNav('backup_options', false, true); ?>
						<?php $this->getBackupOptionsContent(); ?>
					</div>
				</div>
			</div>
		</div>
	<?php }
	
	function setOptionsMapPosition( $position, $map ) {
		
		switch ( $map ) {
			case 'fonts':
				$position = 2;
				break;
			case 'header':
				$position = 3;
				break;
			case 'sidearea':
				$position = 4;
				break;
			case 'search':
				$position = 5;
				break;
		}
		
		return $position;
	}
}
?>