(function($) {
	"use strict";

    var blog = {};
    cdbTheme.modules.blog = blog;

    blog.cdbThemeDocumentReady = cdbThemeDocumentReady;
    blog.cdbThemeWindowLoad = cdbThemeWindowLoad;
    blog.cdbThemeWindowScroll = cdbThemeWindowScroll;

    $(document).ready(cdbThemeDocumentReady);
    $(window).load(cdbThemeWindowLoad);
    $(window).scroll(cdbThemeWindowScroll);
    
    /* 
        All functions to be called on $(document).ready() should be in this function
    */
    function cdbThemeDocumentReady() {
        audioPlayerInitialize();
    }

    /* 
        All functions to be called on $(window).load() should be in this function
    */
    function cdbThemeWindowLoad() {
	    blogPagination().init();
    }

    /* 
        All functions to be called on $(window).scroll() should be in this function
    */
    function cdbThemeWindowScroll() {
	    blogPagination().scroll();
    }

    /**
    * Init audio player for Blog list and single pages
    */
    function audioPlayerInitialize() {
	    var players = $('audio.blog-post-audio');
	
	    if (players.length) {
		    players.mediaelementplayer({
			    audioWidth: '100%'
		    });
	    }
    }
	
	/**
	 * Initializes blog pagination functions
	 */
	function blogPagination(){
		var holder = $('.blog-loop-wrap');
		
		var initLoadMorePagination = function(thisHolder) {
			var loadMoreButton = thisHolder.find('.blog-load-more a');
			
			loadMoreButton.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				
				initMainPagFunctionality(thisHolder);
			});
		};
		
		var initInifiteScrollPagination = function(thisHolder) {
			var blogListHeight = thisHolder.outerHeight(),
				blogListTopOffest = thisHolder.offset().top,
				blogListPosition = blogListHeight + blogListTopOffest - theme_global_vars.vars.cdb_admin_bar;
			
			if(!thisHolder.hasClass('blog-loop-pagination-infinite-scroll-started') && cdbTheme.scroll + cdbTheme.windowHeight > blogListPosition) {
				initMainPagFunctionality(thisHolder);
			}
		};
		
		var initMainPagFunctionality = function(thisHolder) {
			var thisHolderInner = thisHolder.children('.blog-loop-wrap-inner'),
				nextPage,
				maxNumPages;
			
			if (typeof thisHolder.data('max-num-pages') !== 'undefined' && thisHolder.data('max-num-pages') !== false) {
				maxNumPages = thisHolder.data('max-num-pages');
			}
			
			if(thisHolder.hasClass('blog-loop-pagination-infinite-scroll')) {
				thisHolder.addClass('blog-loop-pagination-infinite-scroll-started');
			}
			
			var loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisHolder),
				loadingItem = thisHolder.find('.blog-loading');
			
			nextPage = loadMoreDatta.nextPage;
			
			if(nextPage <= maxNumPages){
				loadingItem.addClass('show');
				
				var ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'codebean_blog_load_more');
				
				$.ajax({
					type: 'POST',
					data: ajaxData,
					url: theme_global_vars.vars.ajax_url,
					success: function (data) {
						nextPage++;
						
						thisHolder.data('next-page', nextPage);

						var response = $.parseJSON(data),
							responseHtml =  response.html;

						thisHolder.waitForImages(function(){
							if(thisHolder.hasClass('container-masonry-list')){
								isotopeAddNewContent(thisHolderInner, loadingItem, responseHtml);
								cdbTheme.modules.common.setFixedImageProportionSize(thisHolder, thisHolder.find('article'), thisHolderInner.find('.masonry-grid-sizer').width());
							} else {
								galleryAddNewContent(thisHolderInner, loadingItem, responseHtml);
							}
							
							setTimeout(function() {
								audioPlayerInitialize();
								cdbTheme.modules.common.codebeanOwlCarousel();
								cdbTheme.modules.common.codebeanFluidVideo();
                                cdbTheme.modules.common.selfHostedVideoPlayer();
                                cdbTheme.modules.common.selfHostedVideoSize();
								
								if (typeof cdbTheme.modules.common.sidebarWidgetFixed === 'function') {
									cdbTheme.modules.common.sidebarWidgetFixed().reInit();
								}

                                // Trigger event.
                                $( document.body ).trigger( 'blog_list_load_more_trigger' );

							}, 400);
						});
						
						if(thisHolder.hasClass('blog-loop-pagination-infinite-scroll-started')) {
							thisHolder.removeClass('blog-loop-pagination-infinite-scroll-started');
						}
					}
				});
			}
			
			if(nextPage === maxNumPages){
				thisHolder.find('.blog-load-more').hide();
			}
		};
		
		var isotopeAddNewContent = function(thisHolderInner, loadingItem, responseHtml) {
			thisHolderInner.append(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('show');
			
			setTimeout(function() {
				thisHolderInner.isotope('layout');
			}, 600);
		};
		
		var galleryAddNewContent = function(thisHolderInner, loadingItem, responseHtml) {
			loadingItem.removeClass('show');
			thisHolderInner.append(responseHtml);
		};
		
		return {
			init: function() {
				if(holder.length) {
					holder.each(function() {
						var thisHolder = $(this);
						
						if(thisHolder.hasClass('blog-loop-pagination-load-more')) {
							initLoadMorePagination(thisHolder);
						}
						
						if(thisHolder.hasClass('blog-loop-pagination-infinite-scroll')) {
							initInifiteScrollPagination(thisHolder);
						}
					});
				}
			},
			scroll: function() {
				if(holder.length) {
					holder.each(function() {
						var thisHolder = $(this);
						
						if(thisHolder.hasClass('blog-loop-pagination-infinite-scroll')) {
							initInifiteScrollPagination(thisHolder);
						}
					});
				}
			}
		};
	}

})(jQuery);