(function($) {
    "use strict";

    var blogListSC = {};
    cdbTheme.modules.blogListSC = blogListSC;
    
    blogListSC.cdbThemeWindowLoad = cdbThemeWindowLoad;
    blogListSC.cdbThemeWindowScroll = cdbThemeWindowScroll;

    $(window).load(cdbThemeWindowLoad);
    $(window).scroll(cdbThemeWindowScroll);

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function cdbThemeWindowLoad() {
        blogPaginationShortcode().init();
    }

    /*
     All functions to be called on $(window).scroll() should be in this function
     */
    function cdbThemeWindowScroll() {
        blogPaginationShortcode().scroll();
    }

    /**
     * Init blog list shortcode pagination functions
     */
    function blogPaginationShortcode(){
        var holder = $('.blog-shortcode');

        var initStandardPagination = function(thisHolder) {
            var standardLink = thisHolder.find('.blog-shortcode-standard-pagination li');

            if(standardLink.length) {
                standardLink.each(function(){
                    var thisLink = $(this).children('a'),
                        pagedLink = 1;

                    thisLink.on('click', function(e) {
                        e.preventDefault();
                        e.stopPropagation();

                        if (typeof thisLink.data('paged') !== 'undefined' && thisLink.data('paged') !== false) {
                            pagedLink = thisLink.data('paged');
                        }

                        initMainPagFunctionality(thisHolder, pagedLink);
                    });
                });
            }
        };

        var initLoadMorePagination = function(thisHolder) {
            var loadMoreButton = thisHolder.find('.blog-load-more a');

            loadMoreButton.on('click', function(e) {
                e.preventDefault();
                e.stopPropagation();

                initMainPagFunctionality(thisHolder);
            });
        };

        var initInifiteScrollPagination = function(thisHolder) {
            var blogListHeight = thisHolder.outerHeight(),
                blogListTopOffest = thisHolder.offset().top,
                blogListPosition = blogListHeight + blogListTopOffest - theme_global_vars.vars.cdb_admin_bar;

            if(!thisHolder.hasClass('blog-pagination-infinite-scroll-started') && cdbTheme.scroll + cdbTheme.windowHeight > blogListPosition) {
                initMainPagFunctionality(thisHolder);
            }
        };

        var initMainPagFunctionality = function(thisHolder, pagedLink) {
            var thisHolderInner = thisHolder.find('.blog-shortcode-list'),
                nextPage,
                maxNumPages;

            if (typeof thisHolder.data('max-num-pages') !== 'undefined' && thisHolder.data('max-num-pages') !== false) {
                maxNumPages = thisHolder.data('max-num-pages');
            }

            if(thisHolder.hasClass('blog-pagination-standard-shortcodes')) {
                thisHolder.data('next-page', pagedLink);
            }

            if(thisHolder.hasClass('blog-pagination-infinite-scroll')) {
                thisHolder.addClass('blog-pagination-infinite-scroll-started');
            }

            var loadMoreDatta = cdbTheme.modules.common.getLoadMoreData(thisHolder),
                loadingItem = thisHolder.find('.blog-loading');

            nextPage = loadMoreDatta.nextPage;

            if(nextPage <= maxNumPages){
                if(thisHolder.hasClass('blog-pagination-standard-shortcodes')) {
                    loadingItem.addClass('show standard-pagination-trigger');
                    thisHolder.addClass('blog-pagination-standard-shortcodes-animate');
                } else {
                    loadingItem.addClass('show');
                }

                var ajaxData = cdbTheme.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'codebean_blog_shortcode_load_more');

                $.ajax({
                    type: 'POST',
                    data: ajaxData,
                    url: theme_global_vars.vars.ajax_url,
                    success: function (data) {
                        if(!thisHolder.hasClass('blog-pagination-standard-shortcodes')) {
                            nextPage++;
                        }

                        thisHolder.data('next-page', nextPage);

                        var response = $.parseJSON(data),
                            responseHtml =  response.html;

                        if(thisHolder.hasClass('blog-pagination-standard-shortcodes')) {
                            defaultPaginationNextLink(thisHolder, maxNumPages, nextPage);

                            thisHolder.waitForImages(function(){
                                if(thisHolder.hasClass('blog-shortcode-masonry')){
                                    isotopeHtmlNewContent(thisHolder, thisHolderInner, loadingItem, responseHtml);
                                } else {
                                    galleryHtmlNewContent(thisHolder, thisHolderInner, loadingItem, responseHtml);

                                    if (typeof cdbTheme.modules.common.sidebarWidgetFixed === 'function') {
                                        cdbTheme.modules.common.sidebarWidgetFixed().reInit();
                                    }
                                }
                            });
                        } else {
                            thisHolder.waitForImages(function(){
                                if(thisHolder.hasClass('blog-shortcode-masonry')){
                                    isotopeAddNewContent(thisHolderInner, loadingItem, responseHtml);
                                } else {
                                    galleryAddNewContent(thisHolderInner, loadingItem, responseHtml);

                                    if (typeof cdbTheme.modules.common.sidebarWidgetFixed === 'function') {
                                        cdbTheme.modules.common.sidebarWidgetFixed().reInit();
                                    }
                                }
                            });
                        }

                        if(thisHolder.hasClass('blog-pagination-infinite-scroll-started')) {
                            thisHolder.removeClass('blog-pagination-infinite-scroll-started');
                        }
                    }
                });
            }

            if(nextPage === maxNumPages){
                thisHolder.find('.blog-load-more').hide();
            }
        };

        var defaultPaginationNextLink = function(thisHolder, maxNumPages, nextPage) {
            var standardPagHolder = thisHolder.find('.blog-shortcode-standard-pagination'),
                standardPagNumericItem = standardPagHolder.find('li.page-num'),
                standardPagPrevItem = standardPagHolder.find('li.previous-page a'),
                standardPagNextItem = standardPagHolder.find('li.next-page a');

            standardPagNumericItem.removeClass('active');
            standardPagNumericItem.eq(nextPage-1).addClass('active');

            standardPagPrevItem.data('paged', nextPage-1);
            standardPagNextItem.data('paged', nextPage+1);

            if(nextPage > 1) {
                standardPagPrevItem.css({'opacity': '1'});
            } else {
                standardPagPrevItem.css({'opacity': '0'});
            }

            if(nextPage === maxNumPages) {
                standardPagNextItem.css({'opacity': '0'});
            } else {
                standardPagNextItem.css({'opacity': '1'});
            }
        };

        var isotopeHtmlNewContent = function(thisHolder, thisHolderInner, loadingItem, responseHtml) {
            thisHolderInner.html(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
            loadingItem.removeClass('show standard-pagination-trigger');
            thisHolder.removeClass('blog-pagination-standard-shortcodes-animate');

            setTimeout(function() {
                thisHolderInner.isotope('layout');

                if (typeof cdbTheme.modules.common.sidebarWidgetFixed === 'function') {
                    cdbTheme.modules.common.sidebarWidgetFixed().reInit();
                }
            }, 600);
        };

        var galleryHtmlNewContent = function(thisHolder, thisHolderInner, loadingItem, responseHtml) {
            loadingItem.removeClass('show standard-pagination-trigger');
            thisHolder.removeClass('blog-pagination-standard-shortcodes-animate');
            thisHolderInner.html(responseHtml);
        };

        var isotopeAddNewContent = function(thisHolderInner, loadingItem, responseHtml) {
            thisHolderInner.append(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
            loadingItem.removeClass('show');

            setTimeout(function() {
                thisHolderInner.isotope('layout');

                if (typeof cdbTheme.modules.common.sidebarWidgetFixed === 'function') {
                    cdbTheme.modules.common.sidebarWidgetFixed().reInit();
                }
            }, 600);
        };

        var galleryAddNewContent = function(thisHolderInner, loadingItem, responseHtml) {
            loadingItem.removeClass('show');
            thisHolderInner.append(responseHtml);
        };

        return {
            init: function() {
                if(holder.length) {
                    holder.each(function() {
                        var thisHolder = $(this);

                        if(thisHolder.hasClass('blog-pagination-standard-shortcodes')) {
                            initStandardPagination(thisHolder);
                        }

                        if(thisHolder.hasClass('blog-pagination-load-more')) {
                            initLoadMorePagination(thisHolder);
                        }

                        if(thisHolder.hasClass('blog-pagination-infinite-scroll')) {
                            initInifiteScrollPagination(thisHolder);
                        }
                    });
                }
            },
            scroll: function() {
                if(holder.length) {
                    holder.each(function() {
                        var thisHolder = $(this);

                        if(thisHolder.hasClass('blog-pagination-infinite-scroll')) {
                            initInifiteScrollPagination(thisHolder);
                        }
                    });
                }
            }
        };
    }

})(jQuery);