<?php

if ( ! function_exists( 'codebean_get_blog_holder_params' ) ) {
	/**
	 * Function that generates params for holders on blog templates
	 */
	function codebean_get_blog_holder_params( $params ) {
		$params_list = array();
		
		$masonry_layout = codebean_get_meta_field_intersect( 'blog_masonry_layout' );
		if ( $masonry_layout === 'in-grid' ) {
			$params_list['holder'] = 'cdb-grid';
			$params_list['inner']  = 'cdb-grid-box clearfix';
		} else {
			$params_list['holder'] = 'fw-container';
			$params_list['inner']  = 'fw-container-inner';
		}
		
		return $params_list;
	}
	
	add_filter( 'codebean_filter_blog_holder_params', 'codebean_get_blog_holder_params' );
}

if ( ! function_exists( 'codebean_get_blog_list_classes' ) ) {
	/**
	 * Function that generates blog list holder classes for blog list templates
	 */
	function codebean_get_blog_list_classes( $classes ) {
		$list_classes   = array();
		$list_classes[] = 'container-list container-masonry-list';
		
		$number_of_columns = codebean_get_meta_field_intersect( 'blog_masonry_number_of_columns' );
		if ( ! empty( $number_of_columns ) ) {
			$list_classes[] = 'cdb-' . $number_of_columns . '-cols';
		}
		
		$columns_gutter = codebean_get_meta_field_intersect( 'blog_masonry_columns_gutter' );
		if ( ! empty( $columns_gutter ) ) {
			$list_classes[] = 'cdb-' . $columns_gutter . '-col-gap';
		}
		
		$masonry_layout = codebean_get_meta_field_intersect( 'blog_masonry_layout' );
		$list_classes[] = 'blog-loop-masonry-' . $masonry_layout;
		
		if ( $masonry_layout === 'full-width') {
			$list_classes[] = 'blog-layout-extra-space';
		}
		
		$classes = array_merge( $classes, $list_classes );
		
		return $classes;
	}
	
	add_filter( 'codebean_filter_blog_list_classes', 'codebean_get_blog_list_classes' );
}

if ( ! function_exists( 'codebean_blog_part_params' ) ) {
	function codebean_blog_part_params( $params ) {
		$part_params              = array();
		$part_params['title_tag'] = 'h2';
		$part_params['link_tag']  = 'h5';
		$part_params['quote_tag'] = 'h5';
		
		return array_merge( $params, $part_params );
	}
	
	add_filter( 'codebean_filter_blog_part_params', 'codebean_blog_part_params' );
}