<?php

if (!function_exists('codebean_map_footer_meta')) {
    function codebean_map_footer_meta() {

        $footer_meta_box = codebean_create_meta_box(
            array(
                'scope' => apply_filters('codebean_filter_set_scope_for_meta_boxes', array('page', 'post'), 'footer_meta'),
                'title' => esc_html__('Footer', 'caledon'),
                'name'  => 'footer_meta'
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'          => 'cdb_disable_footer_meta',
                'type'          => 'select',
                'default_value' => '',
                'label'         => esc_html__('Disable Footer for this Page', 'caledon'),
                'description'   => esc_html__('Enabling this option will hide footer on this page', 'caledon'),
                'options'       => codebean_get_yes_no_select_array(),
                'parent'        => $footer_meta_box
            )
        );

        $show_footer_meta_container = codebean_add_admin_container(
            array(
                'name'       => 'cdb_show_footer_meta_container',
                'parent'     => $footer_meta_box,
                'dependency' => array(
                    'hide' => array(
                        'cdb_disable_footer_meta' => 'yes'
                    )
                )
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'          => 'cdb_footer_in_grid_meta',
                'type'          => 'select',
                'default_value' => '',
                'label'         => esc_html__('Footer in Grid', 'caledon'),
                'description'   => esc_html__('Enabling this option will place Footer content in grid', 'caledon'),
                'options'       => codebean_get_yes_no_select_array(),
                'parent'        => $show_footer_meta_container
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'          => 'cdb_uncovering_footer_meta',
                'type'          => 'select',
                'default_value' => '',
                'label'         => esc_html__('Uncovering Footer', 'caledon'),
                'description'   => esc_html__('Enabling this option will make Footer gradually appear on scroll', 'caledon'),
                'options'       => codebean_get_yes_no_select_array(),
                'parent'        => $show_footer_meta_container
            )
        );

        codebean_create_meta_box_field(
            array(
                'type'          => 'select',
                'name'          => 'cdb_footer_skin_meta',
                'default_value' => '',
                'label'         => esc_html__('Footer Skin', 'caledon'),
                'options'       => array(
                    ''      => esc_html__('Default', 'caledon'),
                    'light' => esc_html__('Light', 'caledon'),
                    'dark'  => esc_html__('Dark', 'caledon'),
                ),
                'parent'        => $show_footer_meta_container,
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'          => 'cdb_show_footer_top_meta',
                'type'          => 'select',
                'default_value' => '',
                'label'         => esc_html__('Show Footer Top', 'caledon'),
                'description'   => esc_html__('Enabling this option will show Footer Top area', 'caledon'),
                'options'       => codebean_get_yes_no_select_array(),
                'parent'        => $show_footer_meta_container
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'        => 'cdb_footer_top_background_color_meta',
                'type'        => 'color',
                'label'       => esc_html__('Footer Top Background Color', 'caledon'),
                'description' => esc_html__('Set background color for top footer area', 'caledon'),
                'parent'      => $show_footer_meta_container,
                'dependency'  => array(
                    'show' => array(
                        'cdb_show_footer_top_meta' => array('', 'yes')
                    )
                )
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'          => 'cdb_show_footer_bottom_meta',
                'type'          => 'select',
                'default_value' => '',
                'label'         => esc_html__('Show Footer Bottom', 'caledon'),
                'description'   => esc_html__('Enabling this option will show Footer Bottom area', 'caledon'),
                'options'       => codebean_get_yes_no_select_array(),
                'parent'        => $show_footer_meta_container
            )
        );

        codebean_create_meta_box_field(
            array(
                'name'        => 'cdb_footer_bottom_background_color_meta',
                'type'        => 'color',
                'label'       => esc_html__('Footer Bottom Background Color', 'caledon'),
                'description' => esc_html__('Set background color for bottom footer area', 'caledon'),
                'parent'      => $show_footer_meta_container,
                'dependency'  => array(
                    'show' => array(
                        'cdb_show_footer_bottom_meta' => array('', 'yes')
                    )
                )
            )
        );
    }

    add_action('codebean_action_meta_boxes_map', 'codebean_map_footer_meta', 70);
}