<?php

if ( ! function_exists( 'codebean_footer_options_map' ) ) {
	function codebean_footer_options_map() {

		codebean_add_admin_page(
			array(
				'slug'  => '_footer_page',
				'title' => esc_html__( 'Footer', 'caledon' ),
				'icon'  => 'fa fa-sort-amount-asc'
			)
		);

		$footer_panel = codebean_add_admin_panel(
			array(
				'title' => esc_html__( 'Footer', 'caledon' ),
				'name'  => 'footer',
				'page'  => '_footer_page'
			)
		);

		codebean_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'footer_in_grid',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Footer in Grid', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will place Footer content in grid', 'caledon' ),
				'parent'        => $footer_panel
			)
		);

        codebean_add_admin_field(
            array(
                'type'          => 'yesno',
                'name'          => 'uncovering_footer',
                'default_value' => 'no',
                'label'         => esc_html__( 'Uncovering Footer', 'caledon' ),
                'description'   => esc_html__( 'Enabling this option will make Footer gradually appear on scroll', 'caledon' ),
                'parent'        => $footer_panel,
            )
        );

        codebean_add_admin_field(
            array(
                'type'          => 'select',
                'name'          => 'footer_skin',
                'default_value' => 'light',
                'label'         => esc_html__( 'Footer Skin', 'caledon' ),
                'options'       => array(
                    'light'   => esc_html__( 'Light', 'caledon' ),
                    'dark' => esc_html__( 'Dark', 'caledon' ),
                ),
                'parent'        => $footer_panel,
            )
        );

		codebean_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'show_footer_top',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Footer Top', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will show Footer Top area', 'caledon' ),
				'parent'        => $footer_panel,
			)
		);
		
		$show_footer_top_container = codebean_add_admin_container(
			array(
				'name'       => 'show_footer_top_container',
				'parent'     => $footer_panel,
				'dependency' => array(
					'show' => array(
						'show_footer_top' => 'yes'
					)
				)
			)
		);

		codebean_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_top_columns',
				'parent'        => $show_footer_top_container,
				'default_value' => '3 3 3 3',
				'label'         => esc_html__( 'Footer Top Columns', 'caledon' ),
				'description'   => esc_html__( 'Choose number of columns for Footer Top area', 'caledon' ),
				'options'       => array(
					'12' => '1',
					'6 6' => '2',
					'4 4 4' => '3',
                    '3 3 6' => '3 (25% + 25% + 50%)',
					'3 3 3 3' => '4'
				)
			)
		);

		codebean_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_top_columns_alignment',
				'default_value' => 'left',
				'label'         => esc_html__( 'Footer Top Columns Alignment', 'caledon' ),
				'description'   => esc_html__( 'Text Alignment in Footer Columns', 'caledon' ),
				'options'       => array(
					''       => esc_html__( 'Default', 'caledon' ),
					'left'   => esc_html__( 'Left', 'caledon' ),
					'center' => esc_html__( 'Center', 'caledon' ),
					'right'  => esc_html__( 'Right', 'caledon' )
				),
				'parent'        => $show_footer_top_container,
			)
		);

		codebean_add_admin_field(
			array(
				'name'        => 'footer_top_background_color',
				'type'        => 'color',
				'label'       => esc_html__( 'Background Color', 'caledon' ),
				'description' => esc_html__( 'Set background color for top footer area', 'caledon' ),
				'parent'      => $show_footer_top_container
			)
		);

		codebean_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'show_footer_bottom',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Footer Bottom', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will show Footer Bottom area', 'caledon' ),
				'parent'        => $footer_panel,
			)
		);

		$show_footer_bottom_container = codebean_add_admin_container(
			array(
				'name'            => 'show_footer_bottom_container',
				'parent'          => $footer_panel,
				'dependency' => array(
					'show' => array(
						'show_footer_bottom'  => 'yes'
					)
				)
			)
		);

		codebean_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'footer_bottom_columns',
				'default_value' => '6 6',
				'label'         => esc_html__( 'Footer Bottom Columns', 'caledon' ),
				'description'   => esc_html__( 'Choose number of columns for Footer Bottom area', 'caledon' ),
				'options'       => array(
					'12' => '1',
					'6 6' => '2',
					'4 4 4' => '3'
				),
				'parent'        => $show_footer_bottom_container,
			)
		);

		codebean_add_admin_field(
			array(
				'name'        => 'footer_bottom_background_color',
				'type'        => 'color',
				'label'       => esc_html__( 'Background Color', 'caledon' ),
				'description' => esc_html__( 'Set background color for bottom footer area', 'caledon' ),
				'parent'      => $show_footer_bottom_container
			)
		);
	}

	add_action( 'codebean_action_options_map', 'codebean_footer_options_map', codebean_set_options_map_position( 'footer' ) );
}