<?php

if ( ! function_exists( 'codebean_get_hide_dep_for_header_logo_area_meta_boxes' ) ) {
	function codebean_get_hide_dep_for_header_logo_area_meta_boxes() {
		$hide_dep_options = apply_filters( 'codebean_filter_header_logo_area_hide_meta_boxes', $hide_dep_options = array() );
		
		return $hide_dep_options;
	}
}

if ( ! function_exists( 'codebean_get_hide_dep_for_header_logo_area_widgets_meta_boxes' ) ) {
	function codebean_get_hide_dep_for_header_logo_area_widgets_meta_boxes() {
		$hide_dep_options = apply_filters( 'codebean_filter_header_logo_area_widgets_hide_meta_boxes', $hide_dep_options = array() );
		
		return $hide_dep_options;
	}
}

if ( ! function_exists( 'codebean_header_logo_area_meta_options_map' ) ) {
	function codebean_header_logo_area_meta_options_map( $header_meta_box ) {
		$hide_dep_options = codebean_get_hide_dep_for_header_logo_area_meta_boxes();
		$hide_dep_widgets = codebean_get_hide_dep_for_header_logo_area_widgets_meta_boxes();
		
		$logo_area_container = codebean_add_admin_container_no_style(
			array(
				'type'            => 'container',
				'name'            => 'logo_area_container',
				'parent'          => $header_meta_box,
				'dependency' => array(
					'hide' => array(
						'cdb_header_type_meta'  => $hide_dep_options
					)
				)
			)
		);
		
		codebean_add_admin_section_title(
			array(
				'parent' => $logo_area_container,
				'name'   => 'logo_area_style',
				'title'  => esc_html__( 'Logo Area Style', 'caledon' )
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_disable_header_widget_logo_area_meta',
				'type'          => 'yesno',
				'default_value' => 'no',
				'label'         => esc_html__( 'Disable Header Logo Area Widget', 'caledon' ),
				'description'   => esc_html__( 'Enabling this option will hide widget area from the logo area', 'caledon' ),
				'parent'        => $logo_area_container,
				'dependency' => array(
					'hide' => array(
						'cdb_header_type_meta' => $hide_dep_widgets
					)
				)
			)
		);
		
		$caledon_custom_sidebars = codebean_get_custom_sidebars();
		if ( count( $caledon_custom_sidebars ) > 0 ) {
			codebean_create_meta_box_field(
				array(
					'name'        => 'cdb_custom_logo_area_sidebar_meta',
					'type'        => 'selectblank',
					'label'       => esc_html__( 'Choose Custom Widget Area for Logo Area', 'caledon' ),
					'description' => esc_html__( 'Choose custom widget area to display in header logo area"', 'caledon' ),
					'parent'      => $logo_area_container,
					'options'     => $caledon_custom_sidebars,
					'dependency' => array(
						'hide' => array(
							'cdb_header_type_meta' => $hide_dep_widgets
						)
					)
				)
			);
		}
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_logo_area_in_grid_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Logo Area In Grid', 'caledon' ),
				'description'   => esc_html__( 'Set menu area content to be in grid', 'caledon' ),
				'parent'        => $logo_area_container,
				'default_value' => '',
				'options'       => codebean_get_yes_no_select_array()
			)
		);
		
		$logo_area_in_grid_container = codebean_add_admin_container(
			array(
				'type'            => 'container',
				'name'            => 'logo_area_in_grid_container',
				'parent'          => $logo_area_container,
				'dependency' => array(
					'show' => array(
						'cdb_logo_area_in_grid_meta'  => 'yes'
					)
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_grid_background_color_meta',
				'type'        => 'color',
				'label'       => esc_html__( 'Grid Background Color', 'caledon' ),
				'description' => esc_html__( 'Set grid background color for logo area', 'caledon' ),
				'parent'      => $logo_area_in_grid_container
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_grid_background_transparency_meta',
				'type'        => 'text',
				'label'       => esc_html__( 'Grid Background Transparency', 'caledon' ),
				'description' => esc_html__( 'Set grid background transparency for logo area (0 = fully transparent, 1 = opaque)', 'caledon' ),
				'parent'      => $logo_area_in_grid_container,
				'args'        => array(
					'col_width' => 2
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_logo_area_in_grid_border_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Grid Area Border', 'caledon' ),
				'description'   => esc_html__( 'Set border on grid logo area', 'caledon' ),
				'parent'        => $logo_area_in_grid_container,
				'default_value' => '',
				'options'       => codebean_get_yes_no_select_array()
			)
		);
		
		$logo_area_in_grid_border_container = codebean_add_admin_container(
			array(
				'type'            => 'container',
				'name'            => 'logo_area_in_grid_border_container',
				'parent'          => $logo_area_in_grid_container,
				'dependency' => array(
					'show' => array(
						'cdb_logo_area_in_grid_border_meta'  => 'yes'
					)
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_in_grid_border_color_meta',
				'type'        => 'color',
				'label'       => esc_html__( 'Border Color', 'caledon' ),
				'description' => esc_html__( 'Set border color for grid area', 'caledon' ),
				'parent'      => $logo_area_in_grid_border_container
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_background_color_meta',
				'type'        => 'color',
				'label'       => esc_html__( 'Background Color', 'caledon' ),
				'description' => esc_html__( 'Choose a background color for logo area', 'caledon' ),
				'parent'      => $logo_area_container
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_background_transparency_meta',
				'type'        => 'text',
				'label'       => esc_html__( 'Transparency', 'caledon' ),
				'description' => esc_html__( 'Choose a transparency for the logo area background color (0 = fully transparent, 1 = opaque)', 'caledon' ),
				'parent'      => $logo_area_container,
				'args'        => array(
					'col_width' => 2
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_logo_area_border_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Logo Area Border', 'caledon' ),
				'description'   => esc_html__( 'Set border on logo area', 'caledon' ),
				'parent'        => $logo_area_container,
				'default_value' => '',
				'options'       => codebean_get_yes_no_select_array()
			)
		);
		
		$logo_area_border_bottom_color_container = codebean_add_admin_container(
			array(
				'type'            => 'container',
				'name'            => 'logo_area_border_bottom_color_container',
				'parent'          => $logo_area_container,
				'dependency' => array(
					'show' => array(
						'cdb_logo_area_border_meta'  => 'yes'
					)
				)
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_border_color_meta',
				'type'        => 'color',
				'label'       => esc_html__( 'Border Color', 'caledon' ),
				'description' => esc_html__( 'Choose color of header bottom border', 'caledon' ),
				'parent'      => $logo_area_border_bottom_color_container
			)
		);

		codebean_create_meta_box_field(
			array(
				'name'        => 'cdb_logo_area_height_meta',
				'type'        => 'text',
				'label'       => esc_html__( 'Height', 'caledon' ),
				'description' => esc_html__( 'Enter logo area height (default is 90px)', 'caledon' ),
				'parent'      => $logo_area_container,
				'args'        => array(
					'col_width' => 3,
					'suffix'    => esc_html__( 'px', 'caledon' )
				)
			)
		);
		
		do_action( 'codebean_action_header_logo_area_additional_meta_boxes_map', $logo_area_container );
	}
	
	add_action( 'codebean_action_header_logo_area_meta_boxes_map', 'codebean_header_logo_area_meta_options_map', 10, 1 );
}