(function($) {
	"use strict";
	
	var header = {};
	cdbTheme.modules.header = header;
	
	header.dropdownMenuPosition     = dropdownMenuPosition;
	header.megaMenuOffsets = megaMenuOffsets;
	
	header.cdbThemeDocumentReady = cdbThemeDocumentReady;
	header.cdbThemeWindowLoad = cdbThemeWindowLoad;

    header.behaviour = '';
	
	$(document).ready(cdbThemeDocumentReady);
	$(window).load(cdbThemeWindowLoad);
	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function cdbThemeDocumentReady() {
		dropdownMenuPosition();
		setTimeout(function(){
			simpleDropDown();
		}, 100);

        if(cdbTheme.windowWidth > 1024) {
            fixedHeader();
        }
	}
	
	/*
	 All functions to be called on $(window).load() should be in this function
	 */
	function cdbThemeWindowLoad() {
		megaMenuOffsets();
	}
	
	/**
	 * Set dropdown position
	 */
	function dropdownMenuPosition() {
		var menuItems = $('.menu-dropdown > ul > li.simple-dropdown.menu-item-has-children');
		
		if (menuItems.length) {
			menuItems.each(function (i) {
				var thisItem = $(this),
					menuItemPosition = thisItem.offset().left,
					dropdownHolder = thisItem.find('.sub-menu-dropdown'),
					dropdownMenuItem = dropdownHolder.find('.sub-menu-holder ul'),
					dropdownMenuWidth = dropdownMenuItem.outerWidth(),
					menuItemFromLeft = cdbTheme.windowWidth - menuItemPosition;
				
				if (cdbTheme.body.hasClass('boxed-site-layout')) {
					menuItemFromLeft = cdbTheme.boxedLayoutWidth - (menuItemPosition - (cdbTheme.windowWidth - cdbTheme.boxedLayoutWidth ) / 2);
				}
				
				var dropDownMenuFromLeft; //has to stay undefined because 'dropDownMenuFromLeft < dropdownMenuWidth' conditional will be true
				
				if (thisItem.find('li.sub').length > 0) {
					dropDownMenuFromLeft = menuItemFromLeft - dropdownMenuWidth;
				}
				
				dropdownHolder.removeClass('right');
				dropdownMenuItem.removeClass('right');
				if (menuItemFromLeft < dropdownMenuWidth || dropDownMenuFromLeft < dropdownMenuWidth) {
					dropdownHolder.addClass('right');
					dropdownMenuItem.addClass('right');
				}
			});
		}
	}
	
	/**
	 * Set dropdown wide position
	 */
	function megaMenuOffsets(){
		var menuItems = $(".menu-dropdown > ul > li.megamenu-dropdown");
		
		if(menuItems.length) {
			menuItems.each( function(i) {
                var menuItem = $(this);
				var menuItemSubMenu = menuItem.find('.sub-menu-dropdown');
				
				if(menuItemSubMenu.length && !menuItemSubMenu.hasClass('left_position') && !menuItemSubMenu.hasClass('right_position')) {
					menuItemSubMenu.css('left', 0);
					
					var left_position = menuItemSubMenu.offset().left;
					
					if(cdbTheme.body.hasClass('boxed-site-layout')) {
                        //boxed layout case
                        var boxedWidth = $('.boxed-site-layout .site-wrapper .site-container').outerWidth();
						left_position = left_position - (cdbTheme.windowWidth - boxedWidth) / 2;
						menuItemSubMenu.css({'left': -left_position, 'width': boxedWidth});

					} else if(cdbTheme.body.hasClass('mega-dropdown-wrapper-in-container')) {
                        //wide dropdown in grid case
                        menuItemSubMenu.css({'left': -left_position + (cdbTheme.windowWidth - cdbTheme.gridWidth()) / 2 - 40, 'width': cdbTheme.gridWidth() - 80 });
                    }
                    else {
                        //wide dropdown full width case
                        menuItemSubMenu.css({'left': -left_position + 40, 'width': cdbTheme.windowWidth - 80});
					}
				}
			});
		}
	}
	
	function simpleDropDown() {
		var menu_items = $('.menu-dropdown > ul > li');
		
		menu_items.each(function() {
			var thisItem = $(this);
			
			if(thisItem.find('.sub-menu-dropdown').length) {
				thisItem.waitForImages(function(){
					var dropDownHolder = thisItem.find('.sub-menu-dropdown'),
						dropDownHolderHeight = !cdbTheme.dropDownMenuHeightSet ? dropDownHolder.outerHeight() : 0;

                    if(thisItem.hasClass('wide')) {
                        var tallest = 0,
                            dropDownSecondItem = dropDownHolder.find('> .inner > ul > li');

                        dropDownSecondItem.each(function() {
                            var thisHeight = $(this).outerHeight();

                            if(thisHeight > tallest) {
                                tallest = thisHeight;
                            }
                        });

                        dropDownSecondItem.css('height', '').height(tallest);

                        if (!cdbTheme.dropDownMenuHeightSet) {
                            dropDownHolderHeight = dropDownHolder.outerHeight();
                        }
                    }

                    if (!cdbTheme.dropDownMenuHeightSet) {
                        dropDownHolder.height(0);
                    }
					
					if(navigator.userAgent.match(/(iPod|iPhone|iPad)/)) {
						thisItem.on("touchstart mouseenter", function() {
							dropDownHolder.css({
								'height': dropDownHolderHeight,
								'overflow': 'visible',
								'visibility': 'visible',
								'opacity': '1'
							});
							menu_items.addClass('sub-menu-hover');
						}).on("mouseleave", function() {
							dropDownHolder.css({
								'height': '0px',
								'overflow': 'hidden',
								'visibility': 'hidden',
								'opacity': '0'
							});
                            menu_items.removeClass('sub-menu-hover');
						});
					} else {
						var config = {
							interval: 0,
							over: function () {
								setTimeout(function () {
									dropDownHolder.addClass('dropdown-visible');
                                    menu_items.addClass('sub-menu-hover');
								}, 150);
							},
							timeout: 150,
							out: function () {
								dropDownHolder.removeClass('dropdown-visible');
                                menu_items.removeClass('sub-menu-hover');
							}
						};

						thisItem.hoverIntent(config);
					}
				});
			}
		});
		
		$('.menu-dropdown ul li.megamenu-dropdown ul li a').on('click', function(e) {
			if (e.which === 1){
				var $this = $(this);
				
				setTimeout(function() {
					$this.mouseleave();
				}, 500);
			}
		});
		
		cdbTheme.dropDownMenuHeightSet = true;
	}

    /**
	 * Show/Hide header on sticky (fixed)
     */
    function fixedHeader() {
        var header = $('.main-header-wrapper'),
            fixedHeaderWrapper = $('.main-fixed-header'),
            fixedMenuArea = fixedHeaderWrapper.children('.row-menu-container'),
            fixedMenuAreaHeight = fixedMenuArea.outerHeight(),
            sliderHolder = $('.caledon-slider'),
            revSliderHeight = sliderHolder.length ? sliderHolder.outerHeight() : 0;

        var headerMenuAreaOffset = fixedHeaderWrapper.length ? fixedHeaderWrapper.offset().top - theme_global_vars.vars.cdb_admin_bar : 0;

        if (cdbTheme.body.hasClass('sticky-on-scroll')) {
            cdbTheme.modules.header.behaviour = 'sticky-on-scroll';
            var headerFixed = function(){

                if(cdbTheme.scroll <= headerMenuAreaOffset) {
                    fixedHeaderWrapper.removeClass('is-stuck');
                    cdbTheme.body.removeClass('fixed-header-active');
                    header.css('margin-bottom', '0');
                } else {
                    fixedHeaderWrapper.addClass('is-stuck');
                    cdbTheme.body.addClass('fixed-header-active');
                    header.css('margin-bottom', fixedMenuAreaHeight + 'px');
                }
            };

            headerFixed();

            $(window).scroll(function() {
                headerFixed();
            });
		}
    }
	
})(jQuery);