<?php

if ( ! function_exists( 'codebean_register_header_minimal_type' ) ) {
	/**
	 * This function is used to register header type class for header factory file
	 */
	function codebean_register_header_minimal_type( $header_types ) {
		$header_type = array(
			'header-minimal' => 'CaledonNamespace\Modules\Header\Types\HeaderMinimal'
		);
		
		$header_types = array_merge( $header_types, $header_type );
		
		return $header_types;
	}
}

if ( ! function_exists( 'codebean_init_register_header_minimal_type' ) ) {
	/**
	 * This function is used to wait header-function.php file to init header object and then to init hook registration function above
	 */
	function codebean_init_register_header_minimal_type() {
		add_filter( 'codebean_filter_register_header_type_class', 'codebean_register_header_minimal_type' );
	}
	
	add_action( 'codebean_action_before_header_function_init', 'codebean_init_register_header_minimal_type' );
}

if ( ! function_exists( 'codebean_include_header_minimal_full_screen_menu' ) ) {
	/**
	 * Registers additional menu navigation for theme
	 */
	function codebean_include_header_minimal_full_screen_menu( $menus ) {
		$menus['overlay-navigation'] = esc_html__( 'Full Screen Navigation', 'caledon' );
		
		return $menus;
	}
	
	if ( codebean_check_is_header_type_enabled( 'header-minimal' ) ) {
		add_filter( 'codebean_filter_register_headers_menu', 'codebean_include_header_minimal_full_screen_menu' );
	}
}

if ( ! function_exists( 'codebean_get_fullscreen_menu_icon_class' ) ) {
	/**
	 * Loads full screen menu icon class
	 */
	function codebean_get_fullscreen_menu_icon_class() {
		$classes = array(
			'full-screen-menu-button'
		);
		
		$classes[] = codebean_get_icon_sources_class( 'fullscreen_menu', 'full-screen-menu-button' );
		
		return $classes;
	}
}

if ( ! function_exists( 'codebean_register_header_minimal_full_screen_menu_widgets' ) ) {
	/**
	 * Registers additional widget areas for this header type
	 */
	function codebean_register_header_minimal_full_screen_menu_widgets() {
		
		register_sidebar(
			array(
				'id'            => 'fullscreen_menu_below',
				'name'          => esc_html__( 'Fullscreen Menu Bottom', 'caledon' ),
				'description'   => esc_html__( 'This widget area is rendered below full screen menu', 'caledon' ),
				'before_widget' => '<div class="%2$s widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5 class="widget-title">',
				'after_title'   => '</h5>'
			)
		);
	}
	
	if ( codebean_check_is_header_type_enabled( 'header-minimal' ) ) {
		add_action( 'widgets_init', 'codebean_register_header_minimal_full_screen_menu_widgets' );
	}
}