<?php

if ( ! function_exists( 'codebean_mobile_header_general_styles' ) ) {
	/**
	 * Generates general custom styles for mobile header
	 */
	function codebean_mobile_header_general_styles() {
		$item_styles      = array();
		$height           = codebean_options()->getOptionValue( 'mobile_header_height' );
		$background_color = codebean_options()->getOptionValue( 'mobile_header_background_color' );
		$border_color     = codebean_options()->getOptionValue( 'mobile_header_border_bottom_color' );
		
		if ( ! empty( $height ) ) {
			$item_styles['height'] = codebean_filter_px( $height ) . 'px';
		}
		
		if ( ! empty( $background_color ) ) {
			$item_styles['background-color'] = $background_color;
		}
		
		if ( ! empty( $border_color ) ) {
			$item_styles['border-color'] = $border_color;
		}
		
		echo codebean_dynamic_css( '.mobile-header .mobile-header-inner', $item_styles );
	}
	
	add_action( 'codebean_action_style_dynamic', 'codebean_mobile_header_general_styles' );
}

if ( ! function_exists( 'codebean_mobile_navigation_styles' ) ) {
	/**
	 * Generates styles for mobile navigation
	 */
	function codebean_mobile_navigation_styles() {
		$mobile_nav_styles = array();
		$background_color  = codebean_options()->getOptionValue( 'mobile_menu_background_color' );
		$border_color      = codebean_options()->getOptionValue( 'mobile_menu_border_bottom_color' );
		
		if ( ! empty( $background_color ) ) {
			$mobile_nav_styles['background-color'] = $background_color;
		}
		
		if ( ! empty( $border_color ) ) {
			$mobile_nav_styles['border-color'] = $border_color;
		}
		
		echo codebean_dynamic_css( '.mobile-header .mobile-menu', $mobile_nav_styles );
		
		$nav_item_styles          = array();
		$nav_border_color         = codebean_options()->getOptionValue( 'mobile_menu_separator_color' );
		$mobile_nav_item_selector = array(
			'.mobile-header .mobile-menu ul li a',
			'.mobile-header .mobile-menu ul li h6'
		);
		
		if ( ! empty( $nav_border_color ) ) {
			$nav_item_styles['border-bottom-color'] = $nav_border_color;
		}
		
		echo codebean_dynamic_css( $mobile_nav_item_selector, $nav_item_styles );
		
		
		// mobile dropdown 1st level menu style
		
		$mobile_menu_style = codebean_get_typography_styles( 'mobile_text' );
		
		$mobile_menu_selector = array(
			'.mobile-header .mobile-menu .container > ul > li > a',
			'.mobile-header .mobile-menu .container > ul > li > h6'
		);
		
		echo codebean_dynamic_css( $mobile_menu_selector, $mobile_menu_style );
		
		
		$mobile_nav_item_hover_styles = array();
		$mobile_text_hover_color      = codebean_options()->getOptionValue( 'mobile_text_hover_color' );
		
		if ( ! empty( $mobile_text_hover_color ) ) {
			$mobile_nav_item_hover_styles['color'] = $mobile_text_hover_color;
		}
		
		$mobile_nav_item_selector_hover = array(
			'.mobile-header .mobile-menu .container > ul > li.menu-active-unit > a',
			'.mobile-header .mobile-menu .container > ul > li.menu-active-unit > h6',
			'.mobile-header .mobile-menu .container > ul > li > a:hover',
			'.mobile-header .mobile-menu .container > ul > li > h6:hover'
		);
		
		echo codebean_dynamic_css( $mobile_nav_item_selector_hover, $mobile_nav_item_hover_styles );
		
		// mobile dropdown deeper levels menu style
		
		$mobile_dropdown_style = codebean_get_typography_styles( 'mobile_dropdown_text' );
		
		$mobile_dropdown_selector = array(
			'.mobile-header .mobile-menu ul ul li a',
			'.mobile-header .mobile-menu ul ul li h6'
		);
		
		echo codebean_dynamic_css( $mobile_dropdown_selector, $mobile_dropdown_style );
		
		
		$mobile_nav_dropdown_item_hover_styles = array();
		$mobile_nav_dropdown_hover_color       = codebean_options()->getOptionValue( 'mobile_dropdown_text_hover_color' );
		
		if ( ! empty( $mobile_nav_dropdown_hover_color ) ) {
			$mobile_nav_dropdown_item_hover_styles['color'] = $mobile_nav_dropdown_hover_color;
		}
		
		$mobile_nav_dropdown_item_selector_hover = array(
			'.mobile-header .mobile-menu ul ul li.current-menu-ancestor > a',
			'.mobile-header .mobile-menu ul ul li.current-menu-item > a',
			'.mobile-header .mobile-menu ul ul li.current-menu-ancestor > h6',
			'.mobile-header .mobile-menu ul ul li.current-menu-item > h6',
			'.mobile-header .mobile-menu ul ul li a:hover',
			'.mobile-header .mobile-menu ul ul li h6:hover'
		);
		
		echo codebean_dynamic_css( $mobile_nav_dropdown_item_selector_hover, $mobile_nav_dropdown_item_hover_styles );
	}
	
	add_action( 'codebean_action_style_dynamic', 'codebean_mobile_navigation_styles' );
}

if ( ! function_exists( 'codebean_mobile_logo_styles' ) ) {
	/**
	 * Generates styles for mobile logo
	 */
	function codebean_mobile_logo_styles() {
		$logo_height          = codebean_options()->getOptionValue( 'mobile_logo_height' );
		$mobile_logo_height   = codebean_options()->getOptionValue( 'mobile_logo_height_phones' );
		$mobile_header_height = codebean_options()->getOptionValue( 'mobile_header_height' );
		
		if ( ! empty( $logo_height ) ) { ?>
			@media only screen and (max-width: 1024px) {
			<?php echo codebean_dynamic_css(
				'.mobile-header .mobile-site-logo a',
				array( 'height' => codebean_filter_px( $logo_height ) . 'px !important' )
			); ?>
			}
		<?php }
		
		if ( ! empty( $mobile_logo_height ) ) { ?>
			@media only screen and (max-width: 480px) {
			<?php echo codebean_dynamic_css(
				'.mobile-header .mobile-site-logo a',
				array( 'height' => codebean_filter_px( $mobile_logo_height ) . 'px !important' )
			); ?>
			}
		<?php }
		
		if ( ! empty( $mobile_header_height ) ) {
			echo codebean_dynamic_css( '.mobile-header .mobile-site-logo a', array( 'max-height' => codebean_filter_px( $mobile_header_height ) . 'px' ) );
		}
	}
	
	add_action( 'codebean_action_style_dynamic', 'codebean_mobile_logo_styles' );
}

if ( ! function_exists( 'codebean_mobile_icon_styles' ) ) {
	/**
	 * Generates styles for mobile icon opener
	 */
	function codebean_mobile_icon_styles() {
		$icon_color       = codebean_options()->getOptionValue( 'mobile_icon_color' );
		$icon_hover_color = codebean_options()->getOptionValue( 'mobile_icon_hover_color' );
		
		if ( ! empty( $icon_color ) ) {
			echo codebean_dynamic_css( '.mobile-header .mobile-toggle-holder a', array( 'color' => $icon_color ) );
		}
		
		if ( ! empty( $icon_hover_color ) ) {
			echo codebean_dynamic_css( '.mobile-header .mobile-toggle-holder a:hover, .mobile-header .mobile-toggle-holder.active a', array( 'color' => $icon_hover_color ) );
		}
	}
	
	add_action( 'codebean_action_style_dynamic', 'codebean_mobile_icon_styles' );
}