(function ($) {
	"use strict";
	
	var mobileHeader = {};
	cdbTheme.modules.mobileHeader = mobileHeader;
	
	mobileHeader.cdbThemeDocumentReady = cdbThemeDocumentReady;
	mobileHeader.cdbThemeWindowResize = cdbThemeWindowResize;
	
	$(document).ready(cdbThemeDocumentReady);
	$(window).resize(cdbThemeWindowResize);
	
	/*
		All functions to be called on $(document).ready() should be in this function
	*/
	function cdbThemeDocumentReady() {
		mobileNavigation();
		mobileNavigationScroll();
		mobileHeaderFixed();
	}
	
	/*
        All functions to be called on $(window).resize() should be in this function
    */
	function cdbThemeWindowResize() {
		mobileNavigationScroll();
	}
	
	function mobileNavigation() {
		var navigationOpener = $('.mobile-header .mobile-toggle-holder'),
			navigationHolder = $('.mobile-header .mobile-menu'),
			dropdownOpener = $('.mobile-menu .dropdown-arrow, .mobile-menu h6, .mobile-menu a.empty-link');
		
		//whole mobile menu opening / closing
		if (navigationOpener.length && navigationHolder.length) {
			navigationOpener.on('tap click', function (e) {
				e.stopPropagation();
				e.preventDefault();

                if (!navigationHolder.hasClass('is-open')) {
                    navigationHolder.addClass('is-open');
                    navigationOpener.addClass('active');
                } else {
                    navigationHolder.removeClass('is-open');
                    navigationOpener.removeClass('active');
                }

			});
		}
		
		//dropdown opening / closing
		if (dropdownOpener.length) {
			dropdownOpener.each(function () {
				var thisItem = $(this);
				
				thisItem.on('tap click', function (e) {
                    e.stopPropagation();
                    e.preventDefault();

					var thisItemParent = thisItem.parent('li'),
						thisItemParentSiblingsWithDrop = thisItemParent.siblings('.menu-item-has-children');
					
					if (thisItemParent.hasClass('has_sub')) {
						var submenu = thisItemParent.find('> ul.dropdown-menu');
						
						if (submenu.is(':visible')) {
							submenu.slideUp(450, 'easeInOutQuint');
							thisItemParent.removeClass('open');
						} else {
							thisItemParent.addClass('open');
							
							if (thisItemParentSiblingsWithDrop.length === 0) {
								thisItemParent.find('.dropdown-menu').slideUp(400, 'easeInOutQuint', function () {
									submenu.slideDown(400, 'easeInOutQuint');
								});
							} else {
								thisItemParent.siblings().removeClass('open').find('.dropdown-menu').slideUp(400, 'easeInOutQuint', function () {
									submenu.slideDown(400, 'easeInOutQuint');
								});
							}
						}
					}
				});
			});
		}
		
		$('.mobile-menu a, .mobile-site-logo a').on('click tap', function (e) {
			if ($(this).attr('href') !== 'http://#' && $(this).attr('href') !== '#') {
				navigationHolder.slideUp(450, 'easeInOutQuint');
				navigationOpener.removeClass("active");
			}
		});
	}
	
	function mobileNavigationScroll() {
		if (cdbTheme.windowWidth <= 1024) {
			var mobileHeader = $('.mobile-header'),
				mobileHeaderHeight = mobileHeader.length ? mobileHeader.height() : 0,
				navigationHolder = mobileHeader.find('.mobile-menu'),
				navigationHeight = navigationHolder.outerHeight(),
				windowHeight = cdbTheme.windowHeight - 73;

			//init scrollable menu
			var scrollHeight = windowHeight;

			navigationHolder.height(scrollHeight);
			if(navigationHolder.length) {
                cdbTheme.modules.common.cdbThemeInitPerfectScrollbar().init(navigationHolder);
            }
		}
	}
	
	function mobileHeaderFixed() {
		var mobileHeader = $('.mobile-header'),
			mobileMenuOpener = mobileHeader.find('.mobile-toggle-holder'),
			mobileHeaderHeight = mobileHeader.length ? mobileHeader.outerHeight() : 0;
		
		if (cdbTheme.body.hasClass('page-wrap-is-behind-header') && mobileHeaderHeight > 0 && cdbTheme.windowWidth <= 1024) {
			$('.page-wrap').css('marginTop', -mobileHeaderHeight);
		}
		
		if (cdbTheme.body.hasClass('mobile-header-sticky')) {
			var stickyAppearAmount,
				adminBar = $('#wpadminbar');
			
			var docYScroll1 = $(document).scrollTop();
			stickyAppearAmount = mobileHeaderHeight + theme_global_vars.vars.cdb_admin_bar;
			
			$(window).scroll(function () {
				var docYScroll2 = $(document).scrollTop();
				
				if (docYScroll2 > stickyAppearAmount) {
					mobileHeader.addClass('is-scrolled-down');
				} else {
					mobileHeader.removeClass('is-scrolled-down');
				}
				
				if ((docYScroll2 > docYScroll1 && docYScroll2 > stickyAppearAmount && !mobileMenuOpener.hasClass('active')) || (docYScroll2 < stickyAppearAmount)) {
					mobileHeader.removeClass('is-scrolled-up');
					mobileHeader.css('margin-bottom', 0);
					
					if (adminBar.length) {
						mobileHeader.find('.mobile-header-inner').css('top', 0);
					}
				} else {
					mobileHeader.addClass('is-scrolled-up');
					mobileHeader.css('margin-bottom', stickyAppearAmount);
				}
				
				docYScroll1 = $(document).scrollTop();
			});
		}
	}
	
})(jQuery);