<?php

if ( ! function_exists( 'codebean_header_top_bar_styles' ) ) {
	/**
	 * Generates styles for header top bar
	 */
	function codebean_header_top_bar_styles() {
		$top_header_height = codebean_options()->getOptionValue( 'top_bar_height' );
		
		if ( ! empty( $top_header_height ) ) {
			echo codebean_dynamic_css( '.top-bar', array( 'height' => codebean_filter_px( $top_header_height ) . 'px' ) );
			echo codebean_dynamic_css( '.top-bar .site-logo a', array( 'max-height' => codebean_filter_px( $top_header_height ) . 'px' ) );
		}
		
		echo codebean_dynamic_css( '.top-bar .top-bar-background', array( 'height' => codebean_get_top_bar_background_height() . 'px' ) );
		
		$top_bar_container_selector = '.top-bar > .top-bar-inner';
		$top_bar_container_styles   = array();
		$container_side_padding     = codebean_options()->getOptionValue( 'top_bar_side_padding' );
		
		if ( $container_side_padding !== '' ) {
			if ( codebean_string_ends_with( $container_side_padding, 'px' ) || codebean_string_ends_with( $container_side_padding, '%' ) ) {
				$top_bar_container_styles['padding-left'] = $container_side_padding;
				$top_bar_container_styles['padding-right'] = $container_side_padding;
			} else {
				$top_bar_container_styles['padding-left'] = codebean_filter_px( $container_side_padding ) . 'px';
				$top_bar_container_styles['padding-right'] = codebean_filter_px( $container_side_padding ) . 'px';
			}
			
			echo codebean_dynamic_css( $top_bar_container_selector, $top_bar_container_styles );
		}
		
		if ( codebean_options()->getOptionValue( 'top_bar_in_grid' ) == 'yes' ) {
			$top_bar_grid_selector                = '.top-bar .container .top-bar-inner';
			$top_bar_grid_styles                  = array();
			$top_bar_grid_background_color        = codebean_options()->getOptionValue( 'top_bar_grid_background_color' );
			$top_bar_grid_background_transparency = codebean_options()->getOptionValue( 'top_bar_grid_background_transparency' );
			
			if ( !empty($top_bar_grid_background_color) ) {
				$grid_background_color        = $top_bar_grid_background_color;
				$grid_background_transparency = 1;
				
				if ( $top_bar_grid_background_transparency !== '' ) {
					$grid_background_transparency = $top_bar_grid_background_transparency;
				}
				
				$grid_background_color                   = codebean_rgba_color( $grid_background_color, $grid_background_transparency );
				$top_bar_grid_styles['background-color'] = $grid_background_color;
			}
			
			echo codebean_dynamic_css( $top_bar_grid_selector, $top_bar_grid_styles );
		}
		
		$top_bar_styles   = array();
		$background_color = codebean_options()->getOptionValue( 'top_bar_background_color' );
		$border_color     = codebean_options()->getOptionValue( 'top_bar_border_color' );
		
		if ( $background_color !== '' ) {
			$background_transparency = 1;
			if ( codebean_options()->getOptionValue( 'top_bar_background_transparency' ) !== '' ) {
				$background_transparency = codebean_options()->getOptionValue( 'top_bar_background_transparency' );
			}
			
			$background_color                   = codebean_rgba_color( $background_color, $background_transparency );
			$top_bar_styles['background-color'] = $background_color;
			
			echo codebean_dynamic_css( '.top-bar .top-bar-background', array( 'background-color' => $background_color ) );
		}
		
		if ( codebean_options()->getOptionValue( 'top_bar_border' ) == 'yes' && $border_color != '' ) {
			$top_bar_styles['border-bottom'] = '1px solid ' . $border_color;
		}
		
		echo codebean_dynamic_css( '.top-bar', $top_bar_styles );
	}
	
	add_action( 'codebean_action_style_dynamic', 'codebean_header_top_bar_styles' );
}