<?php

class CodeBeanClassLike {
	private static $instance;
	
	private function __construct() {
		add_action( 'wp_ajax_codebean_like', array( $this, 'ajax' ) );
		add_action( 'wp_ajax_nopriv_codebean_like', array( $this, 'ajax' ) );
	}
	
	public static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new self;
		}
		
		return self::$instance;
	}
	
	function ajax() {
		
		//update
		if ( isset( $_POST['likes_id'] ) ) {
			$post_id = str_replace( 'likes-', '', $_POST['likes_id'] );
			$post_id = substr( $post_id, 0, - 4 );
			$type    = isset( $_POST['type'] ) ? $_POST['type'] : '';
			
			echo wp_kses( $this->like_post( $post_id, 'update', $type ), array(
				'span' => array(
					'class'       => true,
					'aria-hidden' => true,
					'style'       => true,
					'id'          => true
				),
				'i'    => array(
					'class' => true,
					'style' => true,
					'id'    => true
				)
			) );
		} //get
		else {
			$post_id = str_replace( 'likes-', '', $_POST['likes_id'] );
			$post_id = substr( $post_id, 0, - 4 );
			echo wp_kses( $this->like_post( $post_id, 'get' ), array(
				'span' => array(
					'class'       => true,
					'aria-hidden' => true,
					'style'       => true,
					'id'          => true
				),
				'i'    => array(
					'class' => true,
					'style' => true,
					'id'    => true
				)
			) );
		}
		
		exit;
	}
	
	public function like_post( $post_id, $action = 'get', $type = '' ) {
		if ( ! is_numeric( $post_id ) ) {
			return;
		}
		
		switch ( $action ) {
			
			case 'get':
				$like_count = get_post_meta( $post_id, '_likes', true );
				
				if ( isset( $_COOKIE[ 'likes_' . $post_id ] ) ) {
					$icon = '<i class="icon_heart" aria-hidden="true"></i>';
				} else {
					$icon = '<i class="icon_heart_alt" aria-hidden="true"></i>';
				}
				
				if ( ! $like_count ) {
					$like_count = 0;
					add_post_meta( $post_id, '_likes', $like_count, true );
					$icon = '<i class="icon_heart_alt" aria-hidden="true"></i>';
				}
				
				$return_value = $icon . "<span>" ." ". esc_html__( 'Like', 'caledon' ) . "</span>";

				return $return_value;
				break;
			
			case 'update':
				$like_count = get_post_meta( $post_id, '_likes', true );
				
				if ( isset( $_COOKIE[ 'likes_' . $post_id ] ) ) {
					return $like_count;
				}
				
				$like_count ++;
				
				update_post_meta( $post_id, '_likes', $like_count );
				setcookie( 'likes_' . $post_id, $post_id, time() * 20, '/' );

                if ( $like_count == 1){
                    $like_text = esc_html__( 'Like', 'caledon' );
                } else{
                    $like_text = esc_html__( 'Likes', 'caledon' );
                }
				
				$return_value = "<i class='icon_heart' aria-hidden='true'></i><span>" ." ". esc_attr( $like_count ) ." ". esc_attr( $like_text ) ."</span>";
				
				return $return_value;
				
				break;
			default:
				return '';
				break;
		}
	}
	
	public function add_like() {
		global $post;
		
		$output = $this->like_post( $post->ID );
		
		$class       = 'likes';
		$rand_number = rand( 100, 999 );
		$title       = esc_html__( 'Like this', 'caledon' );
		
		if ( isset( $_COOKIE[ 'likes_' . $post->ID ] ) ) {
			$class = 'likes liked';
			$title = esc_html__( 'You already like this!', 'caledon' );
		}
		
		return '<a href="#" class="' . esc_attr( $class ) . '" id="likes-' . esc_attr( $post->ID ) . '-' . $rand_number . '" title="' . esc_attr( $title ) . '">' . $output . '</a>';
	}
}

if ( ! function_exists( 'codebean_create_like' ) ) {
	function codebean_create_like() {
		CodeBeanClassLike::get_instance();
	}
	
	add_action( 'after_setup_theme', 'codebean_create_like' );
}