<?php

if ( ! function_exists( 'codebean_include_search_types_before_load' ) ) {
    /**
     * Load's all header types before load files by going through all folders that are placed directly in header types folder.
     * Functions from this files before-load are used to set all hooks and variables before global options map are init
     */
    function codebean_include_search_types_before_load() {
        foreach ( glob( CODEBEAN_FRAMEWORK_SEARCH_ROOT_DIR . '/types/*/before-load.php' ) as $module_load ) {
            include_once $module_load;
        }
    }

    add_action( 'codebean_action_options_map', 'codebean_include_search_types_before_load', 1 ); // 1 is set to just be before header option map init
}

if ( ! function_exists( 'codebean_load_search' ) ) {
	function codebean_load_search() {
		$search_type_meta = codebean_options()->getOptionValue( 'search_type' );
		$search_type      = ! empty( $search_type_meta ) ? $search_type_meta : 'covers-header';
		
		if ( codebean_active_widget( false, false, 'codebean_search_opener' ) ) {
			include_once CODEBEAN_FRAMEWORK_MODULES_ROOT_DIR . '/search/types/' . $search_type . '/' . $search_type . '.php';
		}
	}
	
	add_action( 'init', 'codebean_load_search' );
}

if ( ! function_exists( 'codebean_get_holder_params_search' ) ) {
	/**
	 * Function which return holder class and holder inner class for blog pages
	 */
	function codebean_get_holder_params_search() {
		$params_list = array();
		
		$layout = codebean_options()->getOptionValue( 'search_page_layout' );
		if ( $layout == 'in-grid' ) {
			$params_list['holder'] = 'cdb-grid';
			$params_list['inner']  = 'cdb-grid-box clearfix';
		} else {
			$params_list['holder'] = 'fw-container';
			$params_list['inner']  = 'fw-container-inner';
		}
		
		/**
		 * Available parameters for holder params
		 * -holder
		 * -inner
		 */
		return apply_filters( 'codebean_filter_search_holder_params', $params_list );
	}
}

if ( ! function_exists( 'codebean_get_search_page' ) ) {
	function codebean_get_search_page() {
		$sidebar_layout = codebean_sidebar_layout();
		
		$params = array(
			'sidebar_layout' => $sidebar_layout
		);
		
		codebean_get_module_template_part( 'templates/holder', 'search', '', $params );
	}
}

if ( ! function_exists( 'codebean_get_search_page_layout' ) ) {
	/**
	 * Function which create query for blog lists
	 */
	function codebean_get_search_page_layout() {
		global $wp_query;
		$path   = apply_filters( 'codebean_filter_search_page_path', 'templates/page' );
		$type   = apply_filters( 'codebean_filter_search_page_layout', 'default' );
		$module = apply_filters( 'codebean_filter_search_page_module', 'search' );
		$plugin = apply_filters( 'codebean_filter_search_page_plugin_override', false );
		
		if ( get_query_var( 'paged' ) ) {
			$paged = get_query_var( 'paged' );
		} elseif ( get_query_var( 'page' ) ) {
			$paged = get_query_var( 'page' );
		} else {
			$paged = 1;
		}
		
		$params = array(
			'type'          => $type,
			'query'         => $wp_query,
			'paged'         => $paged,
			'max_num_pages' => codebean_get_max_number_of_pages(),
		);
		
		$params = apply_filters( 'codebean_filter_search_page_params', $params );
		
		codebean_get_module_template_part( $path . '/' . $type, $module, '', $params, $plugin );
	}
}

if ( ! function_exists( 'codebean_get_search_submit_icon_class' ) ) {
	/**
	 * Loads search submit icon class
	 */
	function codebean_get_search_submit_icon_class() {
		$classes = array(
			'search-submit'
		);
		
		$classes[] = codebean_get_icon_sources_class( 'search', 'search-submit' );

		return $classes;
	}
}

if ( ! function_exists( 'codebean_get_search_close_icon_class' ) ) {
	/**
	 * Loads search close icon class
	 */
	function codebean_get_search_close_icon_class() {
		$classes = array(
			'search-close-button'
		);
		
		$classes[] = codebean_get_icon_sources_class( 'search', 'search-close-button' );

		return $classes;
	}
}