<?php

if ( ! function_exists( 'codebean_sidearea_options_map' ) ) {
	function codebean_sidearea_options_map() {

        codebean_add_admin_page(
            array(
                'slug'  => '_side_area_page',
                'title' => esc_html__('Off Canvas Sidebar', 'caledon'),
                'icon'  => 'fa fa-indent'
            )
        );

        $side_area_panel = codebean_add_admin_panel(
            array(
                'title' => esc_html__('Off Canvas Sidebar', 'caledon'),
                'name'  => 'side_area',
                'page'  => '_side_area_page'
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'select',
                'name'          => 'side_area_type',
                'default_value' => 'slide-from-right',
                'label'         => esc_html__('Off Canvas Sidebar Type', 'caledon'),
                'description'   => esc_html__('Choose a type of Off Canvas Sidebar', 'caledon'),
                'options'       => array(
                    'slide-from-right'       => esc_html__('Slide from Right Over Content', 'caledon'),
                    'slide-with-content'     => esc_html__('Slide from Right With Content', 'caledon'),
                    'uncovered-from-content' => esc_html__('Off Canvas Sidebar Uncovered from Content', 'caledon'),
                ),
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'text',
                'name'          => 'side_area_width',
                'default_value' => '',
                'label'         => esc_html__('Off Canvas Sidebar Width', 'caledon'),
                'description'   => esc_html__('Enter a width for Off Canvas Sidebar (px or %). Default width: 405px.', 'caledon'),
                'args'          => array(
                    'col_width' => 3,
                )
            )
        );

        $side_area_width_container = codebean_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_width_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_type' => 'side-menu-slide-from-right',
                    )
                )
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_width_container,
                'type'          => 'color',
                'name'          => 'side_area_content_overlay_color',
                'default_value' => '',
                'label'         => esc_html__('Content Overlay Background Color', 'caledon'),
                'description'   => esc_html__('Choose a background color for a content overlay', 'caledon'),
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_width_container,
                'type'          => 'text',
                'name'          => 'side_area_content_overlay_opacity',
                'default_value' => '',
                'label'         => esc_html__('Content Overlay Background Transparency', 'caledon'),
                'description'   => esc_html__('Choose a transparency for the content overlay background color (0 = fully transparent, 1 = opaque)', 'caledon'),
                'args'          => array(
                    'col_width' => 3
                )
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'select',
                'name'          => 'side_area_icon_source',
                'default_value' => 'predefined',
                'label'         => esc_html__('Select Off Canvas Sidebar Icon Source', 'caledon'),
                'description'   => esc_html__('Choose whether you would like to use icons from an icon pack or SVG icons', 'caledon'),
                'options'       => codebean_get_icon_sources_array()
            )
        );

        $side_area_icon_pack_container = codebean_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_icon_pack_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_icon_source' => 'icon_pack'
                    )
                )
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_icon_pack_container,
                'type'          => 'select',
                'name'          => 'side_area_icon_pack',
                'default_value' => 'font_elegant',
                'label'         => esc_html__('Off Canvas Sidebar Icon Pack', 'caledon'),
                'description'   => esc_html__('Choose icon pack for Off Canvas Sidebar icon', 'caledon'),
                'options'       => codebean_icon_collections()->getIconCollectionsExclude(array('linea_icons', 'dripicons', 'simple_line_icons'))
            )
        );

        $side_area_svg_icons_container = codebean_add_admin_container(
            array(
                'parent'     => $side_area_panel,
                'name'       => 'side_area_svg_icons_container',
                'dependency' => array(
                    'show' => array(
                        'side_area_icon_source' => 'svg_path'
                    )
                )
            )
        );

        codebean_add_admin_field(
            array(
                'parent'      => $side_area_svg_icons_container,
                'type'        => 'textarea',
                'name'        => 'side_area_icon_svg_path',
                'label'       => esc_html__('Off Canvas Sidebar Icon SVG Path', 'caledon'),
                'description' => esc_html__('Enter your Off Canvas Sidebar icon SVG path here. Please remove version and id attributes from your SVG path because of HTML validation', 'caledon'),
            )
        );

        codebean_add_admin_field(
            array(
                'parent'      => $side_area_svg_icons_container,
                'type'        => 'textarea',
                'name'        => 'side_area_close_icon_svg_path',
                'label'       => esc_html__('Off Canvas Sidebar Close Icon SVG Path', 'caledon'),
                'description' => esc_html__('Enter your Off Canvas Sidebar close icon SVG path here. Please remove version and id attributes from your SVG path because of HTML validation', 'caledon'),
            )
        );

        $side_area_icon_style_group = codebean_add_admin_group(
            array(
                'parent'      => $side_area_panel,
                'name'        => 'side_area_icon_style_group',
                'title'       => esc_html__('Off Canvas Sidebar Icon Style', 'caledon'),
                'description' => esc_html__('Define styles for Off Canvas Sidebar icon', 'caledon')
            )
        );

        $side_area_icon_style_row1 = codebean_add_admin_row(
            array(
                'parent' => $side_area_icon_style_group,
                'name'   => 'side_area_icon_style_row1'
            )
        );

        codebean_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row1,
                'type'   => 'colorsimple',
                'name'   => 'side_area_icon_color',
                'label'  => esc_html__('Color', 'caledon')
            )
        );

        codebean_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row1,
                'type'   => 'colorsimple',
                'name'   => 'side_area_icon_hover_color',
                'label'  => esc_html__('Hover Color', 'caledon')
            )
        );

        $side_area_icon_style_row2 = codebean_add_admin_row(
            array(
                'parent' => $side_area_icon_style_group,
                'name'   => 'side_area_icon_style_row2',
                'next'   => true
            )
        );

        codebean_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row2,
                'type'   => 'colorsimple',
                'name'   => 'side_area_close_icon_color',
                'label'  => esc_html__('Close Icon Color', 'caledon')
            )
        );

        codebean_add_admin_field(
            array(
                'parent' => $side_area_icon_style_row2,
                'type'   => 'colorsimple',
                'name'   => 'side_area_close_icon_hover_color',
                'label'  => esc_html__('Close Icon Hover Color', 'caledon')
            )
        );

        codebean_add_admin_field(
            array(
                'parent'      => $side_area_panel,
                'type'        => 'color',
                'name'        => 'side_area_background_color',
                'label'       => esc_html__('Background Color', 'caledon'),
                'description' => esc_html__('Choose a background color for Off Canvas Sidebar', 'caledon')
            )
        );

        codebean_add_admin_field(
            array(
                'parent'      => $side_area_panel,
                'type'        => 'text',
                'name'        => 'side_area_padding',
                'label'       => esc_html__('Padding', 'caledon'),
                'description' => esc_html__('Define padding for Off Canvas Sidebar in format top right bottom left', 'caledon'),
                'args'        => array(
                    'col_width' => 3
                )
            )
        );

        codebean_add_admin_field(
            array(
                'parent'        => $side_area_panel,
                'type'          => 'selectblank',
                'name'          => 'side_area_aligment',
                'default_value' => '',
                'label'         => esc_html__('Text Alignment', 'caledon'),
                'description'   => esc_html__('Choose text alignment for Off Canvas Sidebar', 'caledon'),
                'options'       => array(
                    ''       => esc_html__('Default', 'caledon'),
                    'left'   => esc_html__('Left', 'caledon'),
                    'center' => esc_html__('Center', 'caledon'),
                    'right'  => esc_html__('Right', 'caledon')
                )
            )
        );
    }

    add_action('codebean_action_options_map', 'codebean_sidearea_options_map', codebean_set_options_map_position( 'sidearea' ) );
}