<?php

if ( ! function_exists( 'codebean_register_side_area_sidebar' ) ) {
	/**
	 * Register Off Canvas Sidebar sidebar
	 */
	function codebean_register_side_area_sidebar() {
		register_sidebar(
			array(
				'id'            => 'sidearea',
				'name'          => esc_html__( 'Off Canvas Sidebar', 'caledon' ),
				'description'   => esc_html__( 'Off Canvas Sidebar', 'caledon' ),
				'before_widget' => '<div id="%1$s" class="widget offcanvas-sidebar-widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5 class="widget-title">',
				'after_title'   => '</h5>'
			)
		);
	}
	
	add_action( 'widgets_init', 'codebean_register_side_area_sidebar' );
}

if ( ! function_exists( 'codebean_side_menu_body_class' ) ) {
	/**
	 * Function that adds body classes for different side menu styles
	 *
	 * @param $classes array original array of body classes
	 *
	 * @return array modified array of classes
	 */
	function codebean_side_menu_body_class( $classes ) {
		
		if ( is_active_widget( false, false, 'codebean_sidearea_opener' ) ) {
			
			if ( codebean_options()->getOptionValue( 'side_area_type' ) ) {
				$classes[] = 'off-canvas-sidebar-' . codebean_options()->getOptionValue( 'side_area_type' );
			}
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_side_menu_body_class' );
}

if ( ! function_exists( 'codebean_get_side_area' ) ) {
	/**
	 * Loads Off Canvas Sidebar HTML
	 */
	function codebean_get_side_area() {
		
		if ( is_active_widget( false, false, 'codebean_sidearea_opener' ) ) {
			$parameters = array(
				'close_icon_classes' => codebean_get_side_area_close_icon_class()
			);
			
			codebean_get_module_template_part( 'templates/sidearea', 'sidearea', '', $parameters );
		}
	}
	
	add_action( 'codebean_action_after_body_tag', 'codebean_get_side_area', 10 );
}

if ( ! function_exists( 'codebean_get_side_area_close_class' ) ) {
	/**
	 * Loads Off Canvas Sidebar close icon class
	 */
	function codebean_get_side_area_close_icon_class() {
		$classes = array(
			'off-canvas-sidebar-close'
		);
		
		$classes[] = codebean_get_icon_sources_class( 'side_area', 'off-canvas-sidebar-close' );
		
		return $classes;
	}
}