<?php

if ( ! function_exists( 'codebean_get_title_types_meta_boxes' ) ) {
	function codebean_get_title_types_meta_boxes() {
		$title_type_options = apply_filters( 'codebean_filter_title_type_meta_boxes', $title_type_options = array( '' => esc_html__( 'Default', 'caledon' ) ) );
		
		return $title_type_options;
	}
}

foreach ( glob( CODEBEAN_FRAMEWORK_MODULES_ROOT_DIR . '/title/types/*/admin/meta-boxes/*.php' ) as $meta_box_load ) {
	include_once $meta_box_load;
}

if ( ! function_exists( 'codebean_map_title_meta' ) ) {
	function codebean_map_title_meta() {
		$title_type_meta_boxes = codebean_get_title_types_meta_boxes();
		
		$title_meta_box = codebean_create_meta_box(
			array(
				'scope' => apply_filters( 'codebean_filter_set_scope_for_meta_boxes', array( 'page', 'post' ), 'title_meta' ),
				'title' => esc_html__( 'Title', 'caledon' ),
				'name'  => 'title_meta'
			)
		);
		
		codebean_create_meta_box_field(
			array(
				'name'          => 'cdb_show_title_area_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'caledon' ),
				'description'   => esc_html__( 'Disabling this option will turn off page title area', 'caledon' ),
				'parent'        => $title_meta_box,
				'options'       => codebean_get_yes_no_select_array()
			)
		);
		
			$show_title_area_meta_container = codebean_add_admin_container(
				array(
					'parent'          => $title_meta_box,
					'name'            => 'cdb_show_title_area_meta_container',
					'dependency' => array(
						'hide' => array(
							'cdb_show_title_area_meta' => 'no'
						)
					)
				)
			);
		
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_type_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Title Area Type', 'caledon' ),
						'description'   => esc_html__( 'Choose title type', 'caledon' ),
						'parent'        => $show_title_area_meta_container,
						'options'       => $title_type_meta_boxes
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_in_grid_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Title Area In Grid', 'caledon' ),
						'description'   => esc_html__( 'Set title area content to be in grid', 'caledon' ),
						'options'       => codebean_get_yes_no_select_array(),
						'parent'        => $show_title_area_meta_container
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_title_area_height_meta',
						'type'        => 'text',
						'label'       => esc_html__( 'Height', 'caledon' ),
						'description' => esc_html__( 'Set a height for Title Area', 'caledon' ),
						'parent'      => $show_title_area_meta_container,
						'args'        => array(
							'col_width' => 2,
							'suffix'    => 'px'
						)
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_title_area_background_color_meta',
						'type'        => 'color',
						'label'       => esc_html__( 'Background Color', 'caledon' ),
						'description' => esc_html__( 'Choose a background color for title area', 'caledon' ),
						'parent'      => $show_title_area_meta_container
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_title_area_background_image_meta',
						'type'        => 'image',
						'label'       => esc_html__( 'Background Image', 'caledon' ),
						'description' => esc_html__( 'Choose an Image for title area', 'caledon' ),
						'parent'      => $show_title_area_meta_container
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_background_image_behavior_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Background Image Behavior', 'caledon' ),
						'description'   => esc_html__( 'Choose title area background image behavior', 'caledon' ),
						'parent'        => $show_title_area_meta_container,
						'options'       => array(
							''                    => esc_html__( 'Default', 'caledon' ),
							'hide'                => esc_html__( 'Hide Image', 'caledon' ),
							'responsive'          => esc_html__( 'Enable Responsive Image', 'caledon' ),
							'responsive-disabled' => esc_html__( 'Disable Responsive Image', 'caledon' ),
							'parallax'            => esc_html__( 'Enable Parallax Image', 'caledon' ),
							'parallax-zoom-out'   => esc_html__( 'Enable Parallax With Zoom Out Image', 'caledon' ),
							'parallax-disabled'   => esc_html__( 'Disable Parallax Image', 'caledon' )
						)
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_vertical_alignment_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Vertical Alignment', 'caledon' ),
						'description'   => esc_html__( 'Specify title area content vertical alignment', 'caledon' ),
						'parent'        => $show_title_area_meta_container,
						'options'       => array(
							''              => esc_html__( 'Default', 'caledon' ),
							'header' => esc_html__( 'From Bottom of Header', 'caledon' ),
							'window'    => esc_html__( 'From Window Top', 'caledon' )
						)
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_title_tag_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Title Tag', 'caledon' ),
						'options'       => codebean_get_title_tag( true ),
						'parent'        => $show_title_area_meta_container
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_title_text_color_meta',
						'type'        => 'color',
						'label'       => esc_html__( 'Title Color', 'caledon' ),
						'description' => esc_html__( 'Choose a color for title text', 'caledon' ),
						'parent'      => $show_title_area_meta_container
					)
				);

                codebean_create_meta_box_field(
                    array(
                        'name'        => 'cdb_title_area_title_width_meta',
                        'type'        => 'text',
                        'label'       => esc_html__('Title Width', 'caledon'),
                        'description' => esc_html__('Set a width for Title Area. Meant to be used with Standard type.', 'caledon'),
                        'parent'      => $show_title_area_meta_container,
                        'args'        => array(
                            'col_width' => 2,
                            'suffix'    => '%'
                        )
                    )
                );
				
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_subtitle_meta',
						'type'          => 'text',
						'default_value' => '',
						'label'         => esc_html__( 'Subtitle Text', 'caledon' ),
						'description'   => esc_html__( 'Enter your subtitle text', 'caledon' ),
						'parent'        => $show_title_area_meta_container,
						'args'          => array(
							'col_width' => 6
						)
					)
				);
		
				codebean_create_meta_box_field(
					array(
						'name'          => 'cdb_title_area_subtitle_tag_meta',
						'type'          => 'select',
						'default_value' => '',
						'label'         => esc_html__( 'Subtitle Tag', 'caledon' ),
						'options'       => codebean_get_title_tag( true, array( 'p' => 'p', 'span' => 'span' ) ),
						'parent'        => $show_title_area_meta_container
					)
				);
				
				codebean_create_meta_box_field(
					array(
						'name'        => 'cdb_subtitle_color_meta',
						'type'        => 'color',
						'label'       => esc_html__( 'Subtitle Color', 'caledon' ),
						'description' => esc_html__( 'Choose a color for subtitle text', 'caledon' ),
						'parent'      => $show_title_area_meta_container
					)
				);

                codebean_create_meta_box_field(
                    array(
                        'name'        => 'cdb_title_area_subtitle_width_meta',
                        'type'        => 'text',
                        'label'       => esc_html__('Subtitle Width', 'caledon'),
                        'description' => esc_html__('Set a width for Subtitle Area. Meant to be used with Standard type', 'caledon'),
                        'parent'      => $show_title_area_meta_container,
                        'args'        => array(
                            'col_width' => 2,
                            'suffix'    => '%'
                        )
                    )
                );
		
		/***************** Additional Title Area Layout - start *****************/
		
		do_action( 'codebean_action_additional_title_area_meta_boxes', $show_title_area_meta_container );
		
		/***************** Additional Title Area Layout - end *****************/
		
	}
	
	add_action( 'codebean_action_meta_boxes_map', 'codebean_map_title_meta', 60 );
}