<?php

/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( true );
}

/**
 * Change path for overridden templates
 */
if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
	$dir = CODEBEAN_ROOT_DIR . '/vc-templates';
	vc_set_shortcodes_templates_dir( $dir );
}

if ( ! function_exists( 'codebean_configure_visual_composer_frontend_editor' ) ) {
	/**
	 * Configuration for Visual Composer FrontEnd Editor
	 * Hooks on vc_after_init action
	 */
	function codebean_configure_visual_composer_frontend_editor() {
		/**
		 * Remove frontend editor
		 */
		if ( function_exists( 'vc_disable_frontend' ) ) {
			vc_disable_frontend();
		}
	}
	
	add_action( 'vc_after_init', 'codebean_configure_visual_composer_frontend_editor' );
}

if ( ! function_exists( 'codebean_vc_row_map' ) ) {
	/**
	 * Map VC Row shortcode
	 * Hooks on vc_after_init action
	 */
	function codebean_vc_row_map() {
		
		/******* VC Row shortcode - begin *******/
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Caledon Row Content Width', 'caledon' ),
				'value'      => array(
					esc_html__( 'Full Width', 'caledon' ) => 'full-width',
					esc_html__( 'In Grid', 'caledon' )    => 'grid'
				),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'anchor',
				'heading'     => esc_html__( 'Caledon Anchor ID', 'caledon' ),
				'description' => esc_html__( 'For example "home"', 'caledon' ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Caledon Background Color', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);

		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'section_divider',
				'heading'    => esc_html__( 'Enable Row Divider', 'caledon' ),
				'value'      => array(
					esc_html__( 'No Divider', 'caledon' ) => '',
					esc_html__( 'Top Divider', 'caledon' ) => 'top',
					esc_html__( 'Bottom Divider', 'caledon' ) => 'bottom',
					esc_html__( 'Top and Bottom Divider', 'caledon' ) => 'top-bottom'
				),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);

		vc_add_param( 'vc_row',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'divider_background_color',
				'heading'    => esc_html__( 'Caledon Row Divider Color', 'caledon' ),
				'dependency'  => array( 'element' => 'section_divider', 'not_empty' => true ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);

		vc_add_param( 'vc_row',
			array(
				'type'          => 'textfield',
				'param_name'    => 'divider_height',
				'heading'       => esc_html__( 'Divider Height in PX', 'caledon' ),
				'dependency'    => array( 'element' => 'section_divider', 'not_empty' => true ),
				'group'         => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Caledon Background Image', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'background_image_position',
				'heading'     => esc_html__( 'Caledon Background Position', 'caledon' ),
				'description' => esc_html__( 'Set the starting position of a background image, default value is top left', 'caledon' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Caledon Disable Background Image', 'caledon' ),
				'value'       => array(
					esc_html__( 'Never', 'caledon' )        => '',
					esc_html__( 'Below 1280px', 'caledon' ) => '1280',
					esc_html__( 'Below 1024px', 'caledon' ) => '1024',
					esc_html__( 'Below 768px', 'caledon' )  => '768',
					esc_html__( 'Below 680px', 'caledon' )  => '680',
					esc_html__( 'Below 480px', 'caledon' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'caledon' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'parallax_background_image',
				'heading'    => esc_html__( 'Caledon Parallax Background Image', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'parallax_bg_speed',
				'heading'     => esc_html__( 'Caledon Parallax Speed', 'caledon' ),
				'description' => esc_html__( 'Set your parallax speed. Default value is 1.', 'caledon' ),
				'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'textfield',
				'param_name' => 'parallax_bg_height',
				'heading'    => esc_html__( 'Caledon Parallax Section Height (px)', 'caledon' ),
				'dependency' => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);

		vc_add_param( 'vc_row',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'dynamic_background_color_value',
				'heading'    => esc_html__( 'Dynamic Background Color Value', 'caledon' ),
				'description' => esc_html__( 'This color value will be used if Dynamic Background Color metabox is set to Yes on this page.', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Caledon Content Aligment', 'caledon' ),
				'value'      => array(
					esc_html__( 'Default', 'caledon' ) => '',
					esc_html__( 'Left', 'caledon' )    => 'left',
					esc_html__( 'Center', 'caledon' )  => 'center',
					esc_html__( 'Right', 'caledon' )   => 'right'
				),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		
		/******* VC Row shortcode - end *******/
		
		/******* VC Row Inner shortcode - begin *******/
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Caledon Row Content Width', 'caledon' ),
				'value'      => array(
					esc_html__( 'Full Width', 'caledon' ) => 'full-width',
					esc_html__( 'In Grid', 'caledon' )    => 'grid'
				),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Caledon Background Color', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Caledon Background Image', 'caledon' ),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'        => 'textfield',
				'param_name'  => 'background_image_position',
				'heading'     => esc_html__( 'Caledon Background Position', 'caledon' ),
				'description' => esc_html__( 'Set the starting position of a background image, default value is top left', 'caledon' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Caledon Disable Background Image', 'caledon' ),
				'value'       => array(
					esc_html__( 'Never', 'caledon' )        => '',
					esc_html__( 'Below 1280px', 'caledon' ) => '1280',
					esc_html__( 'Below 1024px', 'caledon' ) => '1024',
					esc_html__( 'Below 768px', 'caledon' )  => '768',
					esc_html__( 'Below 680px', 'caledon' )  => '680',
					esc_html__( 'Below 480px', 'caledon' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'caledon' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Caledon Content Aligment', 'caledon' ),
				'value'      => array(
					esc_html__( 'Default', 'caledon' ) => '',
					esc_html__( 'Left', 'caledon' )    => 'left',
					esc_html__( 'Center', 'caledon' )  => 'center',
					esc_html__( 'Right', 'caledon' )   => 'right'
				),
				'group'      => esc_html__( 'Caledon Settings', 'caledon' )
			)
		);
		
		/******* VC Row Inner shortcode - end *******/
		
		/******* VC Revolution Slider shortcode - begin *******/
		
		if ( codebean_revolution_slider_installed() ) {
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'enable_paspartu',
					'heading'     => esc_html__( 'Caledon Enable Passepartout', 'caledon' ),
					'value'       => array_flip( codebean_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'group'       => esc_html__( 'Caledon Settings', 'caledon' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'paspartu_size',
					'heading'     => esc_html__( 'Caledon Passepartout Size', 'caledon' ),
					'value'       => array(
						esc_html__( 'Tiny', 'caledon' )   => 'tiny',
						esc_html__( 'Small', 'caledon' )  => 'small',
						esc_html__( 'Normal', 'caledon' ) => 'normal',
						esc_html__( 'Large', 'caledon' )  => 'large'
					),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Caledon Settings', 'caledon' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_side_paspartu',
					'heading'     => esc_html__( 'Caledon Disable Side Passepartout', 'caledon' ),
					'value'       => array_flip( codebean_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Caledon Settings', 'caledon' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_top_paspartu',
					'heading'     => esc_html__( 'Caledon Disable Top Passepartout', 'caledon' ),
					'value'       => array_flip( codebean_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Caledon Settings', 'caledon' )
				)
			);
		}
		
		/******* VC Revolution Slider shortcode - end *******/
	}
	
	add_action( 'vc_after_init', 'codebean_vc_row_map' );
}