<?php

class CodeBeanClassImageGalleryWidget extends CodeBeanClassWidget {
	public function __construct() {
		parent::__construct(
			'codebean_image_gallery_widget',
			esc_html__( 'Caledon Image Gallery', 'caledon' ),
			array( 'description' => esc_html__( 'Add image gallery element to widget areas', 'caledon' ) )
		);
		
		$this->setParams();
	}
	
	protected function setParams() {
		$this->params = array(
			array(
				'type'  => 'textfield',
				'name'  => 'extra_class',
				'title' => esc_html__( 'Custom CSS Class', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'widget_bottom_margin',
				'title' => esc_html__( 'Widget Bottom Margin (px)', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'widget_title',
				'title' => esc_html__( 'Widget Title', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'widget_title_bottom_margin',
				'title' => esc_html__( 'Widget Title Bottom Margin (px)', 'caledon' )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'type',
				'title'   => esc_html__( 'Gallery Type', 'caledon' ),
				'options' => array(
					'grid'   => esc_html__( 'Image Grid', 'caledon' ),
					'slider' => esc_html__( 'Slider', 'caledon' ),
                    'carousel' => esc_html__( 'Carousel', 'caledon' ),
                    'masonry' => esc_html__( 'Masonry', 'caledon' )
				)
			),
			array(
				'type'        => 'textfield',
				'name'        => 'images',
				'title'       => esc_html__( 'Image ID\'s', 'caledon' ),
				'description' => esc_html__( 'Add images id for your image gallery widget, separate id\'s with comma', 'caledon' )
			),
			array(
				'type'        => 'textfield',
				'name'        => 'image_size',
				'title'       => esc_html__( 'Image Size', 'caledon' ),
				'description' => esc_html__( 'Enter image size. Example: thumbnail, medium, large, full or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use "thumbnail" size', 'caledon' )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'enable_image_shadow',
				'title'   => esc_html__( 'Enable Image Shadow', 'caledon' ),
				'options' => codebean_get_yes_no_select_array()
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'image_behavior',
				'title'   => esc_html__( 'Image Behavior', 'caledon' ),
				'options' => array(
					''            => esc_html__( 'None', 'caledon' ),
					'lightbox'    => esc_html__( 'Open Lightbox', 'caledon' ),
					'custom-link' => esc_html__( 'Open Custom Link', 'caledon' ),
					'grayscale'   => esc_html__( 'Grayscale', 'caledon' )
				)
			),
			array(
				'type'        => 'textarea',
				'name'        => 'custom_links',
				'title'       => esc_html__( 'Custom Links', 'caledon' ),
				'description' => esc_html__( 'Delimit links by comma', 'caledon' )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'custom_link_target',
				'title'   => esc_html__( 'Custom Link Target', 'caledon' ),
				'options' => codebean_get_link_target_array()
			),
			array(
				'type'      => 'dropdown',
				'name'      => 'number_of_visible_items',
				'title'     => esc_html__( 'Number Of Visible Items', 'caledon' ),
				'options'       => array(
                    '1' => esc_html__( 'One', 'caledon' ),
                    '2' => esc_html__( 'Two', 'caledon' ),
                    '3' => esc_html__( 'Three', 'caledon' ),
                    '4' => esc_html__( 'Four', 'caledon' ),
                    '5' => esc_html__( 'Five', 'caledon' ),
				),
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'number_of_columns',
				'title'   => esc_html__( 'Number of Columns', 'caledon' ),
				'options' => codebean_get_number_of_columns_array( false, array( 'six' ) )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'columns_gutter',
				'title'   => esc_html__( 'Space Between Items', 'caledon' ),
				'options' => codebean_get_columns_gutter_array()
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'slider_navigation',
				'title'   => esc_html__( 'Enable Slider Navigation Arrows', 'caledon' ),
				'options' => codebean_get_yes_no_select_array( false )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'slider_pagination',
				'title'   => esc_html__( 'Enable Slider Pagination', 'caledon' ),
				'options' => codebean_get_yes_no_select_array( false )
			)
		);
	}
	
	public function widget( $args, $instance ) {
		if ( ! is_array( $instance ) ) {
			$instance = array();
		}
		
		$extra_class      = ! empty( $instance['extra_class'] ) ? $instance['extra_class'] : '';
		$instance['type'] = ! empty( $instance['type'] ) ? $instance['type'] : 'grid';
		
		//prepare variables
		$params = '';
		
		//is instance empty?
		if ( is_array( $instance ) && count( $instance ) ) {
			//generate shortcode params
			foreach ( $instance as $key => $value ) {
				$params .= " $key='$value' ";
			}
		}
		
		$widget_styles = array();
		if ( isset( $instance['widget_bottom_margin'] ) && $instance['widget_bottom_margin'] !== '' ) {
			$widget_styles[] = 'margin-bottom: ' . codebean_filter_px( $instance['widget_bottom_margin'] ) . 'px';
		}
		
		$widget_title_styles = array();
		if ( isset( $instance['widget_title_bottom_margin'] ) && $instance['widget_title_bottom_margin'] !== '' ) {
			$widget_title_styles[] = 'margin-bottom: ' . codebean_filter_px( $instance['widget_title_bottom_margin'] ) . 'px';
		}
		?>
		
		<div class="widget images-gallery-widget <?php echo esc_html( $extra_class ); ?>" <?php echo codebean_get_inline_style( $widget_styles ); ?>>
			<?php
			if ( ! empty( $instance['widget_title'] ) ) {
				if ( ! empty( $widget_title_styles ) ) {
					$args['before_title'] = codebean_widget_modified_before_title( $args['before_title'], $widget_title_styles ) ;
				}
				
				echo wp_kses_post( $args['before_title'] ) . esc_html( $instance['widget_title'] ) . wp_kses_post( $args['after_title'] );
			}
			echo do_shortcode( "[cdb_image_gallery $params]" ); // XSS OK
			?>
		</div>
		<?php
	}
}