<?php

class CodeBeanClassInstagramWidget extends CodeBeanClassWidget {
	public function __construct() {
		parent::__construct(
			'codebean_instagram_widget',
			esc_html__( 'Caledon Instagram Widget', 'caledon' ),
			array( 'description' => esc_html__( 'Add instagram photos to widget areas', 'caledon' ) )
		);

		$this->setParams();
	}

	protected function setParams() {
		$this->params = array(
			array(
				'type'  => 'textfield',
				'name'  => 'widget_bottom_margin',
				'title' => esc_html__( 'Widget Bottom Margin (px)', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'widget_title',
				'title' => esc_html__( 'Widget Title', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'widget_title_bottom_margin',
				'title' => esc_html__( 'Widget Title Bottom Margin (px)', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'username',
				'title' => esc_html__( 'Username', 'caledon' )
			),
			array(
				'type'  => 'textfield',
				'name'  => 'number',
				'title' => esc_html__( 'Number of photos', 'caledon' )
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'design',
				'title'   => esc_html__( 'Design', 'caledon' ),
				'options' => array(
                    ''             => esc_html__( 'Default', 'caledon' ),
					'grid'         => esc_html__( 'Grid', 'caledon' ),
					'slider'       => esc_html__( 'Slider', 'caledon' ),
				)
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'size',
				'title'   => esc_html__( 'Photo size', 'caledon' ),
				'options' => array(
					'thumbnail'   => esc_html__( 'Thumbnail', 'caledon' ),
					'large'       => esc_html__( 'Large', 'caledon' ),
				)
			),
            array(
                'type'      => 'dropdown',
                'name'      => 'target',
                'title'     => esc_html__( 'Open Link in', 'caledon' ),
                'options'   => array(
                    '_self' => esc_html__( 'Current window', 'caledon' ),
                    '_blank' => esc_html__( 'New window', 'caledon' )
                )
            ),
			array(
                'type'      => 'textfield',
                'name'      => 'link',
                'title'     => esc_html__( 'Link Text', 'caledon' )
            ),
			array(
				'name'    => 'per_row',
				'type'    => 'dropdown',
				'title'   => esc_html__( 'Photos per row', 'caledon' ),
				'options' => codebean_get_number_of_columns_array(),
                'description' => esc_html__('Number of photos per row for grid design or items in slider per view.', 'caledon' ),
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'space_between_columns',
				'title'   => esc_html__( 'Space Between Items', 'caledon' ),
				'options' => codebean_get_columns_gutter_array()
			),
			array(
				'type'    => 'dropdown',
				'name'    => 'hide_mask',
				'title'   => esc_html__( 'Hide likes and comments', 'caledon' ),
				'options' => codebean_get_yes_no_select_array()
			),
		);
	}

	public function widget( $args, $instance ) {
		$params = '';

		if ( ! is_array( $instance ) ) {
			$instance = array();
		}

		// Filter out all empty params
		$instance = array_filter( $instance, function ( $array_value ) {
			return trim( $array_value ) != '';
		} );

		// Generate shortcode params
		foreach ( $instance as $key => $value ) {
			$params .= " $key='$value' ";
		}

		$widget_styles = array();
		if ( isset( $instance['widget_bottom_margin'] ) && $instance['widget_bottom_margin'] !== '' ) {
			$widget_styles[] = 'margin-bottom: ' . codebean_filter_px( $instance['widget_bottom_margin'] ) . 'px';
		}

		$widget_title_styles = array();
		if ( isset( $instance['widget_title_bottom_margin'] ) && $instance['widget_title_bottom_margin'] !== '' ) {
			$widget_title_styles[] = 'margin-bottom: ' . codebean_filter_px( $instance['widget_title_bottom_margin'] ) . 'px';
		}
		?>

		<div class="widget cdb-instagram-widget" <?php echo codebean_get_inline_style( $widget_styles ); ?>>
			<?php
			if ( ! empty( $instance['widget_title'] ) ) {
				if ( ! empty( $widget_title_styles ) ) {
					$args['before_title'] = codebean_widget_modified_before_title( $args['before_title'], $widget_title_styles ) ;
				}

				echo wp_kses_post( $args['before_title'] ) . esc_html( $instance['widget_title'] ) . wp_kses_post( $args['after_title'] );
			}
			echo do_shortcode( "[codebean_instagram $params]" ); // XSS OK
			?>
		</div>
		<?php
	}
}