<?php

class CodeBeanClassRecentPosts extends CodeBeanClassWidget
{
    public function __construct() {
        parent::__construct(
            'codebean_recent_posts',
            esc_html__('Caledon Recent Posts', 'caledon'),
            array('description' => esc_html__('Select recent posts that you would like to display', 'caledon'))
        );

        $this->setParams();
    }

    protected function setParams() {
        $post_types = apply_filters('codebean_filter_search_post_type_widget_params_post_type', array('post' => esc_html__('Post', 'caledon')));

        $this->params = array(
            array(
                'type'  => 'textfield',
                'name'  => 'widget_bottom_margin',
                'title' => esc_html__('Widget Bottom Margin (px)', 'caledon')
            ),
            array(
                'type'  => 'textfield',
                'name'  => 'widget_title',
                'title' => esc_html__('Widget Title', 'caledon')
            ),
            array(
                'type'  => 'textfield',
                'name'  => 'widget_title_bottom_margin',
                'title' => esc_html__('Widget Title Bottom Margin (px)', 'caledon')
            ),
            array(
                'type'  => 'textfield',
                'name'  => 'category',
                'title' => esc_html__('Category', 'caledon'),
                'description' => esc_html__('Category ID or comma-separated list of IDs', 'caledon'),
            ),
            array(
                'type' => 'textfield',
	            'name' => 'limit',
	            'title' => esc_html__( 'Show Posts', 'caledon' ),
	            'description' => esc_html__( 'Type number of posts to show on widget.', 'caledon' ),
            ),
            array(
                'type'        => 'dropdown',
                'name'        => 'post_type',
                'title'       => esc_html__('Post Type', 'caledon'),
                'description' => esc_html__('Choose post type that you want to be searched for', 'caledon'),
                'options'     => $post_types
            ),
            array(
                'type'    => 'dropdown',
                'name'    => 'title_tag',
                'title'   => esc_html__('Title Tag', 'caledon'),
                'options' => codebean_get_title_tag(true, array('p' => 'p'))
            )
        );
    }

    public function widget($args, $instance) {

        if (!is_array($instance)) {
            $instance = array();
        }

        $widget_styles = array();
        if (isset($instance['widget_bottom_margin']) && $instance['widget_bottom_margin'] !== '') {
            $widget_styles[] = 'margin-bottom: ' . codebean_filter_px($instance['widget_bottom_margin']) . 'px';
        }

        $widget_title_styles = array();
        if (isset($instance['widget_title_bottom_margin']) && $instance['widget_title_bottom_margin'] !== '') {
            $widget_title_styles[] = 'margin-bottom: ' . codebean_filter_px($instance['widget_title_bottom_margin']) . 'px';
        }

        $type = $instance['post_type'] !== '' ? $instance['post_type'] : 'post';

        if (empty($instance['title_tag'])) {
            $instance['title_tag'] = 'h6';
        }

	    $posts_per_page      = ( isset( $instance['limit'] ) ) ? $instance['limit'] : 3;

        $params = array(
            'post_type'      => $type,
            'post_status'    => 'publish',
            'order'          => 'DESC',
            'orderby'        => 'date',
            'posts_per_page' => $posts_per_page,
            'cat'            => $instance['category']
        );

        $query = new WP_Query($params); ?>

        <div class="widget caledon-recent-posts" <?php echo codebean_get_inline_style($widget_styles); ?>>

            <?php if (!empty($instance['widget_title'])) {
		        if (!empty($widget_title_styles)) {
			        $args['before_title'] = codebean_widget_modified_before_title( $args['before_title'], $widget_title_styles );
		        }?>

                <?php echo wp_kses_post($args['before_title']); echo esc_html($instance['widget_title']); echo wp_kses_post($args['after_title']); ?>
            <?php } ?>

            <?php if ($query->have_posts()) { ?>
                <ul class="caledon-recent-posts-list">
                <?php while ($query->have_posts()) { $query->the_post(); ?>
                    <li>
                        <a href="<?php echo esc_url(get_the_permalink()); ?>">
                            <div class="recent-posts-thumbnail"><?php echo get_the_post_thumbnail(get_the_ID(), array(60, 60)); ?></div>
                            <div class="recent-posts-info">
                                <<?php echo esc_attr($instance['title_tag']); ?> class="entry-title"><?php echo get_the_title();?></<?php echo esc_attr($instance['title_tag']) ?>>
                                <span class="recent-posts-time"><?php echo get_the_date(); ?></span>
                            </div>
                        </a>
                    </li>
                <?php } ?>
                </ul>
            <?php } else { ?>
                <p><?php esc_html_e('Sorry, there are no posts matching your criteria', 'caledon'); ?></p>
            <?php } ?>

        </div>

        <?php wp_reset_postdata();
    }
}