<?php

class CodeBeanClassWoocommerceDropdownCart extends CodeBeanClassWidget {
    public function __construct() {
        parent::__construct(
            'codebean_woocommerce_dropdown_cart',
            esc_html__('Caledon Woocommerce Dropdown Cart', 'caledon'),
            array('description' => esc_html__('Display a shop cart icon with a dropdown that shows products that are in the cart', 'caledon'),)
        );

        $this->setParams();
    }

    protected function setParams() {
        $this->params = array(
            array(
                'type'        => 'textfield',
                'name'        => 'woocommerce_dropdown_cart_margin',
                'title'       => esc_html__('Icon Margin', 'caledon'),
                'description' => esc_html__('Insert margin in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'caledon')
            )
        );
    }

    public function widget($args, $instance) {
        extract($args);

        global $woocommerce;

        $icon_styles = array();

        if ($instance['woocommerce_dropdown_cart_margin'] !== '') {
            $icon_styles[] = 'margin: ' . $instance['woocommerce_dropdown_cart_margin'];
        }

        $cart_is_empty = sizeof($woocommerce->cart->get_cart()) <= 0;

        $dropdown_cart_icon_class = codebean_get_dropdown_cart_icon_class();
        ?>
        <div class="mini-cart-wrapper" <?php codebean_inline_style($icon_styles) ?>>
            <div class="mini-cart-inner">
                <a itemprop="url" <?php codebean_class_attribute( $dropdown_cart_icon_class ); ?> href="<?php echo esc_url(wc_get_cart_url()); ?>">
                    <span class="mini-cart-icon"><?php echo codebean_get_icon_sources_html( 'dropdown_cart', false, array( 'dropdown_cart' => 'yes' ) ); ?></span>
                    <span class="cart-items-count"><?php echo sprintf(_n('%d', '%d', WC()->cart->cart_contents_count, 'caledon'), WC()->cart->cart_contents_count); ?></span>
                </a>
                <div class="mini-cart-dropdown">
                    <ul>
                        <?php if (!$cart_is_empty) : ?>
                            <?php foreach ($woocommerce->cart->get_cart() as $cart_item_key => $cart_item) :
                                $_product = $cart_item['data'];
                                // Only display if allowed
                                if (!$_product->exists() || $cart_item['quantity'] == 0) {
                                    continue;
                                }
                                // Get price
                                $product_price = get_option('woocommerce_tax_display_cart') == 'excl' ? wc_get_price_excluding_tax($_product) : wc_get_price_including_tax($_product);
                                ?>
                                <li>
                                    <div class="product-img">
                                        <a itemprop="url" href="<?php echo esc_url(get_permalink($cart_item['product_id'])); ?>">
                                            <?php echo wp_kses($_product->get_image(), array(
                                                'img' => array(
                                                    'src'    => true,
                                                    'width'  => true,
                                                    'height' => true,
                                                    'class'  => true,
                                                    'alt'    => true,
                                                    'title'  => true,
                                                    'id'     => true
                                                )
                                            )); ?>
                                        </a>
                                    </div>
                                    <div class="product-details">
                                        <h5 itemprop="name" class="product-name">
	                                        <a itemprop="url" href="<?php echo esc_url(get_permalink($cart_item['product_id'])); ?>"><?php echo apply_filters('codebean_woo_widget_cart_product_title', $_product->get_name(), $_product); ?></a>
                                        </h5>
                                        <?php if(apply_filters('codebean_woo_cart_enable_quantity', true)) { ?>
                                            <span class="quantity"><?php echo esc_html($cart_item['quantity']); esc_html_e(' x ', 'caledon'); ?><?php echo apply_filters( 'codebean_woo_cart_item_price_html', wc_price( $product_price ), $cart_item, $cart_item_key ); ?></span>
                                        <?php } ?>
                                        <?php echo apply_filters('codebean_woo_cart_item_remove_link', sprintf('<a href="%s" class="remove" title="%s"><span class="icon-arrows-remove"></span></a>', esc_url( wc_get_cart_remove_url( $cart_item_key ) ), esc_attr__('Remove this item', 'caledon')), $cart_item_key); ?>
                                    </div>
                                </li>
                            <?php endforeach; ?>
                            <li class="cart-bottom">
                                <div class="cart-subtotal-wrapper clearfix">
                                    <span class="total-label"><?php esc_html_e('Order total:', 'caledon'); ?></span>
                                    <span class="total-label-amount">
										<?php echo wp_kses($woocommerce->cart->get_cart_subtotal(), array(
                                            'span' => array(
                                                'class' => true,
                                                'id'    => true
                                            )
                                        )); ?>
									</span>
                                </div>
                                <div class="mini-cart-buttons clearfix">
	                                <?php echo codebean_get_button_html(array(
		                                'link' => $woocommerce->cart->get_checkout_url(),
		                                'custom_class' => 'checkout',
		                                'text' => esc_html__('Checkout', 'caledon'),
		                                'size' => 'small',
		                                'type' => 'solid'
	                                )); ?>
	                                <?php echo codebean_get_button_html(array(
		                                'link' => $woocommerce->cart->get_cart_url(),
		                                'custom_class' => 'view-cart',
		                                'text' => esc_html__('View Cart', 'caledon'),
		                                'size' => 'small',
		                                'type' => 'solid'
	                                )); ?>
                                </div>
                            </li>
                        <?php else : ?>
                            <li class="empty-cart"><?php esc_html_e('No products in the cart.', 'caledon'); ?></li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        </div>
        <?php
    }
}

add_filter('woocommerce_add_to_cart_fragments', 'codebean_woocommerce_header_add_to_cart_fragment');

function codebean_woocommerce_header_add_to_cart_fragment($fragments) {
    global $woocommerce;

    ob_start();

    $cart_is_empty = sizeof($woocommerce->cart->get_cart()) <= 0;
    
    $dropdown_cart_icon_class = codebean_get_dropdown_cart_icon_class();

    ?>
    <div class="mini-cart-inner">
        <a itemprop="url" <?php codebean_class_attribute( $dropdown_cart_icon_class ); ?> href="<?php echo esc_url(wc_get_cart_url()); ?>">
            <span class="mini-cart-icon"><?php echo codebean_get_icon_sources_html( 'dropdown_cart', false, array( 'dropdown_cart' => 'yes' ) ); ?></span>
            <span class="cart-items-count"><?php echo sprintf(_n('%d', '%d', WC()->cart->cart_contents_count, 'caledon'), WC()->cart->cart_contents_count); ?></span>
        </a>
        <div class="mini-cart-dropdown">
            <ul>
                <?php if (!$cart_is_empty) : ?>
                    <?php foreach ($woocommerce->cart->get_cart() as $cart_item_key => $cart_item) :
                        $_product = $cart_item['data'];
                        // Only display if allowed
                        if (!$_product->exists() || $cart_item['quantity'] == 0) {
                            continue;
                        }
                        // Get price
                        $product_price = get_option('woocommerce_tax_display_cart') == 'excl' ? wc_get_price_excluding_tax($_product) : wc_get_price_including_tax($_product);
                        ?>
                        <li>
                            <div class="product-img">
                                <a itemprop="url" href="<?php echo esc_url(get_permalink($cart_item['product_id'])); ?>">
                                    <?php echo wp_kses($_product->get_image(), array(
                                        'img' => array(
                                            'src'    => true,
                                            'width'  => true,
                                            'height' => true,
                                            'class'  => true,
                                            'alt'    => true,
                                            'title'  => true,
                                            'id'     => true
                                        )
                                    )); ?>
                                </a>
                            </div>
                            <div class="product-details">
                                <h5 itemprop="name" class="product-name">
	                                <a itemprop="url" href="<?php echo esc_url(get_permalink($cart_item['product_id'])); ?>"><?php echo apply_filters('codebean_woo_widget_cart_product_title', $_product->get_name(), $_product); ?></a>
                                </h5>
	                            <?php if(apply_filters('codebean_woo_cart_enable_quantity', true)) { ?>
                                    <span class="quantity"><?php echo esc_html($cart_item['quantity']); esc_html_e(' x ', 'caledon'); ?><?php echo apply_filters( 'codebean_woo_cart_item_price_html', wc_price( $product_price ), $cart_item, $cart_item_key ); ?></span>
	                            <?php } ?>
                                <?php echo apply_filters('codebean_woo_cart_item_remove_link', sprintf('<a href="%s" class="remove" title="%s"><span class="icon-arrows-remove"></span></a>', esc_url( wc_get_cart_remove_url( $cart_item_key ) ), esc_attr__('Remove this item', 'caledon')), $cart_item_key); ?>
                            </div>
                        </li>
                    <?php endforeach; ?>
                    <li class="cart-bottom">
                        <div class="cart-subtotal-wrapper clearfix">
                            <span class="total-label"><?php esc_html_e('Order total:', 'caledon'); ?></span>
                            <span class="total-label-amount">
								<?php echo wp_kses($woocommerce->cart->get_cart_subtotal(), array(
                                    'span' => array(
                                        'class' => true,
                                        'id'    => true
                                    )
                                )); ?>
							</span>
                        </div>
                        <div class="mini-cart-buttons clearfix">
	                        <?php echo codebean_get_button_html(array(
		                        'link' => $woocommerce->cart->get_checkout_url(),
		                        'custom_class' => 'checkout',
		                        'text' => esc_html__('Checkout', 'caledon'),
		                        'size' => 'small',
		                        'type' => 'solid'
	                        )); ?>
	                        <?php echo codebean_get_button_html(array(
		                        'link' => $woocommerce->cart->get_cart_url(),
		                        'custom_class' => 'view-cart',
		                        'text' => esc_html__('View Cart', 'caledon'),
		                        'size' => 'small',
		                        'type' => 'solid'
	                        )); ?>
                        </div>
                    </li>
                <?php else : ?>
                    <li class="empty-cart"><?php esc_html_e('No products in the cart.', 'caledon'); ?></li>
                <?php endif; ?>
            </ul>
        </div>
    </div>

    <?php
    $fragments['div.mini-cart-inner'] = ob_get_clean();

    return $fragments;
}

?>