<?php

if ( ! function_exists( 'codebean_theme_version_class' ) ) {
	/**
	 * Function that adds classes on body for version of theme
	 */
	function codebean_theme_version_class( $classes ) {
		$current_theme = wp_get_theme();
		
		//is child theme activated?
		if ( $current_theme->parent() ) {
			//add child theme version
			$classes[] = strtolower( $current_theme->get( 'Name' ) ) . '-child-ver-' . $current_theme->get( 'Version' );
			
			//get parent theme
			$current_theme = $current_theme->parent();
		}
		
		if ( $current_theme->exists() && $current_theme->get( 'Version' ) != '' ) {
			$classes[] = strtolower( $current_theme->get( 'Name' ) ) . '-ver-' . $current_theme->get( 'Version' );
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_theme_version_class' );
}

if ( ! function_exists( 'codebean_boxed_class' ) ) {
	/**
	 * Function that adds classes on body for boxed layout
	 */
	function codebean_boxed_class( $classes ) {
		$allow_boxed_layout = true;
		$allow_boxed_layout = apply_filters( 'codebean_filter_allow_content_boxed_layout', $allow_boxed_layout );
		
		if ( $allow_boxed_layout && codebean_get_meta_field_intersect( 'boxed' ) === 'yes' ) {
			$classes[] = 'boxed-site-layout';
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_boxed_class' );
}

if ( ! function_exists( 'codebean_paspartu_class' ) ) {
	/**
	 * Function that adds classes on body for paspartu layout
	 */
	function codebean_paspartu_class( $classes ) {
		$id = codebean_get_page_id();
		
		//is paspartu layout turned on?
		if ( codebean_get_meta_field_intersect( 'paspartu', $id ) === 'yes' ) {
			$classes[] = 'site-borders-on';
			
			if ( codebean_get_meta_field_intersect( 'disable_top_paspartu', $id ) === 'yes' ) {
				$classes[] = 'site-top-border-off';
			}
			
			if ( codebean_get_meta_field_intersect( 'enable_fixed_paspartu', $id ) === 'yes' ) {
				$classes[] = 'site-borders-fixed-on';
			}
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_paspartu_class' );
}

if ( ! function_exists( 'codebean_page_smooth_scroll_class' ) ) {
	/**
	 * Function that adds classes on body for page smooth scroll
	 */
	function codebean_page_smooth_scroll_class( $classes ) {
		//is smooth scroll enabled enabled?
		if ( codebean_options()->getOptionValue( 'page_smooth_scroll' ) == 'yes' ) {
			$classes[] = 'smooth-scroll-on';
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_page_smooth_scroll_class' );
}

if ( ! function_exists( 'codebean_smooth_page_transitions_class' ) ) {
	/**
	 * Function that adds classes on body for smooth page transitions
	 */
	function codebean_smooth_page_transitions_class( $classes ) {
		$id = codebean_get_page_id();
		
		if ( codebean_get_meta_field_intersect( 'smooth_page_transitions', $id ) == 'yes' ) {
			$classes[] = 'smooth-page-shifts';
			
			if ( codebean_get_meta_field_intersect( 'page_transition_preloader', $id ) == 'yes' ) {
				$classes[] = 'smooth-page-shifts-preloader';
			}
			
			if ( codebean_get_meta_field_intersect( 'page_transition_fadeout', $id ) == 'yes' ) {
				$classes[] = 'smooth-page-shifts-fadeout';
			}
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_smooth_page_transitions_class' );
}

if ( ! function_exists( 'codebean_content_initial_width_body_class' ) ) {
	/**
	 * Function that adds transparent content class to body.
	 *
	 * @param $classes array of body classes
	 *
	 * @return array with transparent content body class added
	 */
	function codebean_content_initial_width_body_class( $classes ) {
		$initial_content_width = codebean_get_meta_field_intersect( 'initial_content_width', codebean_get_page_id() );
		
		if ( ! empty( $initial_content_width ) ) {
			$classes[] = $initial_content_width;
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_content_initial_width_body_class' );
}

if ( ! function_exists( 'codebean_set_content_behind_header_class' ) ) {
	function codebean_set_content_behind_header_class( $classes ) {
		$id = codebean_get_page_id();
		
		if ( get_post_meta( $id, 'cdb_page_content_behind_header_meta', true ) === 'yes' ) {
			$classes[] = 'page-wrap-is-behind-header';
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_set_content_behind_header_class' );
}

if ( ! function_exists( 'codebean_set_no_google_api_class' ) ) {
	function codebean_set_no_google_api_class( $classes ) {
		$google_map_api = codebean_options()->getOptionValue( 'google_maps_api_key' );
		
		if ( empty( $google_map_api ) ) {
			$classes[] = 'missing-google-api';
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_set_no_google_api_class' );
}

if ( ! function_exists( 'codebean_wide_menu_body_class' ) ) {
	/**
	 * Function that adds wide menu width control classes to body.
	 *
	 * @param $classes array of body classes
	 *
	 * @return array with wide menu width control body classes added
	 */
	function codebean_wide_menu_body_class( $classes ) {
		$wide_dropdown_menu_in_grid      = codebean_get_meta_field_intersect( 'wide_dropdown_menu_in_grid', codebean_get_page_id() );
		$wide_dropdown_menu_in_grid_meta = get_post_meta( codebean_get_page_id(), 'cdb_wide_dropdown_menu_in_grid_meta', true );
		
		$wide_dropdown_menu_content_in_grid        = codebean_get_meta_field_intersect( 'wide_dropdown_menu_content_in_grid', codebean_get_page_id() );
		$wide_dropdown_menu_content_in_grid_global = codebean_options()->getOptionValue( 'wide_dropdown_menu_content_in_grid' );
		
		if ( $wide_dropdown_menu_in_grid === 'yes' ) {
			$classes[] = 'mega-dropdown-wrapper-in-container';
		} else if ( ! empty( $wide_dropdown_menu_in_grid_meta ) && $wide_dropdown_menu_content_in_grid === 'yes' || $wide_dropdown_menu_content_in_grid_global === 'yes' ) {
			$classes[] = 'megamenu-dropdown-in-container';
		}
		
		return $classes;
	}
	
	add_filter( 'body_class', 'codebean_wide_menu_body_class' );
}


if(!function_exists('codebean_dynamic_background')) {
    /**
     * Function that adds classes on body for one scroll slide to content
     */
    function codebean_dynamic_background($classes) {
        $id =  codebean_get_page_id();

        if(get_post_meta($id, 'cdb_page_dynamic_background_color', true) == 'yes') {
            $classes[] = 'active-bg-color';
        }

        return $classes;
    }

    add_filter('body_class', 'codebean_dynamic_background');
}